@@ -48,69 +48,59 @@
  * under the connection table lock. This should move the allocation algorithm from O(n) worst case
  * to O(1) worst case as we always recieve and empty slot *or* ct full. It also reduces lock/atomic
  * contention on the CPU to improve things.
+ * Lastly a change was done: Instead of having a sliding windows that tend to get a never used
+ * slot for each new connection, it nows reuse last freed one. That has several benefits:
+ *  - Fix a bug because the last free list slots may not be alloced.
+ *  - Avoid to grow the memory footprint when there is no much load
+ *  - Simplify the code (as only a single is needed. )
  *
- * The freelist is a ringbuffer of pointers to the connection table. On a small scale it looks like:
+ * The freelist is a stack of pointers to the connection table.
+ * It is NULL terminated. On a small scale it looks like:
  *
  *  |--------------------------------------------|
- *  | slot 1 | slot 2 | slot 3 | slot 4 | slot 5 |
- *  | _ ptr  | _ ptr  | _ ptr  | _ ptr  | _ ptr  |
+ *  | slot 0 | slot 1 | slot 2 | slot 3 | slot 4 |
+ *  | _ ptr  | _ ptr  | _ ptr  | _ ptr  | NULL   |
  *  |--------------------------------------------|
- *     ^  ^- conn_next
- *     |
- *     \-- conn_free
+ *        ^- conn_next
  *
- * As we allocate, we shift conn_next through the list, yielding the ptr that was stored (and
- * setting it to NULL as we proceed)
+ * To allocate, we pop one of the stored connection ptr out of the stack (yield the ptr, set
+ * its slot to NULL then increase conn_next)
  *
  *  |--------------------------------------------|
- *  | slot 1 | slot 2 | slot 3 | slot 4 | slot 5 |
- *  | _NULL  | _NULL  | _ ptr  | _ ptr  | _ ptr  |
+ *  | slot 0 | slot 1 | slot 2 | slot 3 | slot 4 |
+ *  | _NULL  | _NULL  | _ ptr  | _ ptr  | NULL   |
  *  |--------------------------------------------|
- *     ^                  ^- conn_next
- *     |
- *     \-- conn_free
+ *                        ^- conn_next
  *
- * When a connection is "freed" we return it to conn_free, which is then also slid up.
+ * When a connection is "freed" we push it back in the stack after decreasing conn_next
  *
  *  |--------------------------------------------|
- *  | slot 1 | slot 2 | slot 3 | slot 4 | slot 5 |
- *  | _ ptr  | _NULL  | _ ptr  | _ ptr  | _ ptr  |
+ *  | slot 0 | slot 1 | slot 2 | slot 3 | slot 4 |
+ *  | _NULL  | _ ptr  | _ ptr  | _ ptr  | NULL   |
  *  |--------------------------------------------|
- *              ^         ^- conn_next
- *              |
- *              \-- conn_free
+ *              ^- conn_next
  *
- * If all connections are exhausted, conn_next will == conn_next, as conn_next must have proceeded
- * to the end of the ring, and then wrapped back allocating all previous until we meet with conn_free.
+ * If all connections are exhausted, freelist[conn_next] is NULL
  *
  *  |--------------------------------------------|
- *  | slot 1 | slot 2 | slot 3 | slot 4 | slot 5 |
+ *  | slot 0 | slot 1 | slot 2 | slot 3 | slot 4 |
  *  | _NULL  | _NULL  | _NULL  | _NULL  | _NULL  |
  *  |--------------------------------------------|
- *              ^ ^- conn_next
- *              |
- *              \-- conn_free
+ *                                          ^- conn_next
  *
  * This means allocations of conns will keep failing until a connection is returned.
  *
  *  |--------------------------------------------|
- *  | slot 1 | slot 2 | slot 3 | slot 4 | slot 5 |
- *  | _NULL  | _ ptr  | _NULL  | _NULL  | _NULL  |
+ *  | slot 0 | slot 1 | slot 2 | slot 3 | slot 4 |
+ *  | _NULL  | _NULL  | _NULL  | _ ptr  | NULL   |
  *  |--------------------------------------------|
- *             ^- conn_next ^
- *                          |
- *                          \-- conn_free
+ *                                 ^- conn_next
  *
  * And now conn_next can begin to allocate again.
  *
  *
  *  -- invariants
- * * when conn_free is slid back to meet conn_next, there can be no situation where another
- *   connection is returned, as none must allocated  -if they were allocated, conn_free would have
- *   moved_along.
- * * the ring buffer must be as large as conntable.
- * * We do not check conn_next == conn_free (that's the starting state), but we check if the
- *   slot at conn_next is NULL, which must imply that conn_free has nothing to return.
+ * * the stack must be as large as conntable.
  * * connection_table_move_connection_out_of_active_list is the only function able to return a
  *   connection to the freelist, as it is the function that is called when the event system has
  *   determined all IO's are complete, or unable to complete. This function is what prepares the
@@ -136,11 +126,9 @@ connection_table_new(int table_size)
     ct->c = (Connection **)slapi_ch_calloc(1, ct->size * sizeof(Connection *));
     ct->fd = (struct POLL_STRUCT **)slapi_ch_calloc(1, ct->list_num * sizeof(struct POLL_STRUCT*));
     ct->table_mutex = PR_NewLock();
-    /* Allocate the freelist */
-    ct->c_freelist = (Connection **)slapi_ch_calloc(1, ct->size * sizeof(Connection *));
-    /* NEVER use slot 0, this is a list pointer */
-    ct->conn_next_offset = 1;
-    ct->conn_free_offset = 1;
+    /* Allocate the freelist (a slot for each connection plus another slot for the final NULL pointer) */
+    ct->c_freelist = (Connection **)slapi_ch_calloc(1, (ct->size+1) * sizeof(Connection *));
+    ct->conn_next_offset = 0;
 
     slapi_log_err(SLAPI_LOG_INFO, "connection_table_new", "Number of connection sub-tables %d, each containing %d slots.\n",
         ct->list_num, ct->list_size);
@@ -172,9 +160,9 @@ connection_table_new(int table_size)
             /* all connections start out invalid */
             ct->fd[ct_list][i].fd = SLAPD_INVALID_SOCKET;
 
-            /* The connection table has a double linked list running through it.
+            /* The connection sub-tables have a double linked list running through them.
             * This is used to find out which connections should be looked at
-            * in the poll loop.  Slot 0 in the table is always the head of
+            * in the poll loop.  Slot 0 in each sub-table is always the head of
             * the linked list.  Each slot has a c_next and c_prev which are
             * pointers back into the array of connection slots. */
             ct->c[ct_list][i].c_next = NULL;
@@ -196,8 +184,10 @@ connection_table_new(int table_size)
             /* Ready to rock, mark as such. */
             ct->c[ct_list][i].c_state = CONN_STATE_INIT;
 
-            /* Map multiple ct lists to a single freelist. */
-            ct->c_freelist[free_idx++] = &(ct->c[ct_list][i]);
+            /* Map multiple ct lists to a single freelist, but skip slot 0 of each list. */
+            if (i != 0) {
+                ct->c_freelist[free_idx++] = &(ct->c[ct_list][i]);
+            }
         }
     }
 
@@ -271,22 +261,22 @@ connection_table_get_connection(Connection_Table *ct, int sd)
 {
     PR_Lock(ct->table_mutex);
 
-    PR_ASSERT(ct->conn_next_offset != 0);
     Connection *c = ct->c_freelist[ct->conn_next_offset];
     if (c != NULL) {
         /* We allocated it, so now NULL the slot and move forward. */
-        ct->c_freelist[ct->conn_next_offset] = NULL;
-        /* Handle overflow. */
-        ct->conn_next_offset = (ct->conn_next_offset + 1) % ct->size;
-        if (ct->conn_next_offset == 0) {
-            /* Never use slot 0 */
-            ct->conn_next_offset += 1;
-        }
+        PR_ASSERT(ct->conn_next_offset>=0 && ct->conn_next_offset<ct->size);
+        ct->c_freelist[ct->conn_next_offset++] = NULL;
         PR_Unlock(ct->table_mutex);
     } else {
         /* couldn't find a Connection, table must be full */
-        slapi_log_err(SLAPI_LOG_CONNS, "connection_table_get_connection", "Max open connections reached\n");
         PR_Unlock(ct->table_mutex);
+        static time_t last_err_msg_time = 0;
+        time_t curtime = slapi_current_utc_time();
+        /* Logs the message only once per seconds */
+        if (curtime != last_err_msg_time) {
+            slapi_log_err(SLAPI_LOG_ERR, "connection_table_get_connection", "Max open connections reached\n");
+            last_err_msg_time = curtime;
+        }
         return NULL;
     }
 
@@ -459,14 +449,10 @@ connection_table_move_connection_out_of_active_list(Connection_Table *ct, Connec
 
     /* Finally, place the connection back into the freelist for use */
     PR_ASSERT(c->c_refcnt == 0);
-    PR_ASSERT(ct->conn_free_offset != 0);
-    PR_ASSERT(ct->c_freelist[ct->conn_free_offset] == NULL);
-    ct->c_freelist[ct->conn_free_offset] = c;
-    ct->conn_free_offset = (ct->conn_free_offset + 1) % ct->size;
-    if (ct->conn_free_offset == 0) {
-        /* Never use slot 0 */
-        ct->conn_free_offset += 1;
-    }
+    PR_ASSERT(ct->conn_next_offset != 0);
+    ct->conn_next_offset--;
+    PR_ASSERT(ct->c_freelist[ct->conn_next_offset] == NULL);
+    ct->c_freelist[ct->conn_next_offset] = c;
 
     PR_Unlock(ct->table_mutex);
 
