@@ -32,6 +32,8 @@ ER2(SLAPD_DISCONNECT_UNBIND, "Cleanly Closed Connection - U1")
 ER2(SLAPD_DISCONNECT_POLL, "Poll - P2")
 ER2(SLAPD_DISCONNECT_NTSSL_TIMEOUT, "NTSSL Timeout - T2")
 ER2(SLAPD_DISCONNECT_SASL_FAIL, "SASL Failure - S1")
+ER2(SLAPD_DISCONNECT_PROXY_INVALID_HEADER, "Invalid Proxy Header - P3")
+ER2(SLAPD_DISCONNECT_PROXY_UNKNOWN, "Unknown Proxy - P4")
 
 
 #endif /* __DISCONNECT_ERROR_STRINGS_H_ */
