@@ -33,6 +33,8 @@
 #define SLAPD_DISCONNECT_POLL SLAPD_DISCONNECT_ERROR_BASE + 10
 #define SLAPD_DISCONNECT_NTSSL_TIMEOUT SLAPD_DISCONNECT_ERROR_BASE + 11
 #define SLAPD_DISCONNECT_SASL_FAIL SLAPD_DISCONNECT_ERROR_BASE + 12
+#define SLAPD_DISCONNECT_PROXY_INVALID_HEADER SLAPD_DISCONNECT_ERROR_BASE + 13
+#define SLAPD_DISCONNECT_PROXY_UNKNOWN SLAPD_DISCONNECT_ERROR_BASE + 14
 
 
 #endif /* __DISCONNECT_ERRORS_H_ */
