@@ -1712,11 +1712,24 @@ mozldap_ldap_explode_rdn(const char *rdn, const int notypes)
 }
 
 int
-slapi_is_ipv6_addr(const char *hostname)
+slapi_is_ipv4_addr(const char *ipAddress)
 {
     PRNetAddr addr;
 
-    if (PR_StringToNetAddr(hostname, &addr) == PR_SUCCESS &&
+    if (PR_StringToNetAddr(ipAddress, &addr) == PR_SUCCESS &&
+        PR_IsNetAddrType(&addr, PR_IpAddrV4Mapped) &&
+        addr.raw.family == PR_AF_INET) {
+        return 1;
+    }
+    return 0;
+}
+
+int
+slapi_is_ipv6_addr(const char *ipAddress)
+{
+    PRNetAddr addr;
+
+    if (PR_StringToNetAddr(ipAddress, &addr) == PR_SUCCESS &&
         !PR_IsNetAddrType(&addr, PR_IpAddrV4Mapped) &&
         addr.raw.family == PR_AF_INET6) {
         return 1;
@@ -1724,6 +1737,25 @@ slapi_is_ipv6_addr(const char *hostname)
     return 0;
 }
 
+/* For debug purpose */
+void
+slapi_log_prnetaddr(const PRNetAddr *addr) {
+    char ip_str[INET6_ADDRSTRLEN] = {0};
+    uint16_t port = 0;
+
+    if (addr->inet.family == PR_AF_INET) {
+        PR_NetAddrToString(addr, ip_str, sizeof(ip_str));
+        port = PR_ntohs(addr->inet.port);
+        slapi_log_error(SLAPI_LOG_ERR, "slapi_log_prnetaddr", "IPv4: %s:%u\n", ip_str, port);
+    } else if (addr->raw.family == PR_AF_INET6) {
+        PR_NetAddrToString(addr, ip_str, sizeof(ip_str));
+        port = PR_ntohs(addr->ipv6.port);
+        slapi_log_error(SLAPI_LOG_ERR, "slapi_log_prnetaddr", "IPv6: %s:%u\n", ip_str, port);
+    } else {
+        slapi_log_error(SLAPI_LOG_ERR, "slapi_log_prnetaddr", "Unknown address family\n");
+    }
+}
+
 /*
  * Get the length of the ber-encoded ldap message.  Note, only the length of
  * the LDAP operation is returned, not the length of the entire berval.
