@@ -1,5 +1,5 @@
 /* --- BEGIN COPYRIGHT BLOCK ---
- * Copyright (C) 2005 Red Hat, Inc.
+ * Copyright (C) 2021 Red Hat, Inc.
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
@@ -15,6 +15,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <inttypes.h>
 #include <signal.h>
 #include <sys/stat.h>
 #include "ldap-agent.h"
@@ -101,6 +102,7 @@ main(int argc, char *argv[])
     }
 
     load_config(config_file);
+    free(config_file);
 
     /* check if we're already running as another process */
     if ((pid_fp = fopen(pidfile, "r")) != NULL) {
@@ -148,7 +150,7 @@ main(int argc, char *argv[])
             /* agent-logdir setting looks ok */
             if ((log_hdl->token = malloc(strlen(agent_logdir) +
                                          strlen(LDAP_AGENT_LOGFILE) + 2)) != NULL) {
-                strncpy((char *)log_hdl->token, agent_logdir, strlen(agent_logdir) + 1);
+                memcpy((char *)log_hdl->token, agent_logdir, strlen(agent_logdir) + 1);
                 /* add a trailing slash if needed */
                 if (*(agent_logdir + strlen(agent_logdir)) != '/')
                     strcat((char *)log_hdl->token, "/");
@@ -247,13 +249,11 @@ main(int argc, char *argv[])
 }
 
 /* ldif_read_record lineno argument type depends on openldap version */
-#if defined(USE_OPENLDAP)
 #if LDAP_VENDOR_VERSION >= 20434 /* changed in 2.4.34 */
 typedef unsigned long int ldif_record_lineno_t;
 #else
 typedef int ldif_record_lineno_t;
 #endif
-#endif
 
 /************************************************************************
  * load_config
@@ -265,14 +265,9 @@ load_config(char *conf_path)
 {
     server_instance *serv_p = NULL;
     FILE *conf_file = NULL;
-#if defined(USE_OPENLDAP)
     LDIFFP *dse_fp = NULL;
     int buflen = 0;
     ldif_record_lineno_t lineno = 0;
-#else
-    FILE *dse_fp = NULL;
-    int lineno = 0;
-#endif
     char line[MAXLINE];
     char *p = NULL;
     int error = 0;
@@ -293,14 +288,14 @@ load_config(char *conf_path)
     }
 
     /* set pidfile path */
-    if ((pidfile = malloc(strlen(LOCALSTATEDIR) + strlen("/run/") +
+    if ((pidfile = malloc(strlen(LOCALRUNDIR) + strlen("/dirsrv/") +
                           strlen(LDAP_AGENT_PIDFILE) + 1)) != NULL) {
-        strncpy(pidfile, LOCALSTATEDIR, strlen(LOCALSTATEDIR) + 1);
+        strncpy(pidfile, LOCALRUNDIR, strlen(LOCALRUNDIR) + 1);
         /* The above will likely not be NULL terminated, but we need to
          * be sure that we're properly NULL terminated for the below
          * strcat() to work properly. */
-        pidfile[strlen(LOCALSTATEDIR)] = (char)0;
-        strcat(pidfile, "/run/");
+        pidfile[strlen(LOCALRUNDIR)] = (char)0;
+        strcat(pidfile, "/dirsrv/");
         strcat(pidfile, LDAP_AGENT_PIDFILE);
     } else {
         printf("ldap-agent: malloc error processing config file\n");
@@ -406,13 +401,9 @@ load_config(char *conf_path)
                 goto close_and_exit;
             }
 
-/* Open dse.ldif */
-#if defined(USE_OPENLDAP)
+            /* Open dse.ldif */
             dse_fp = ldif_open(serv_p->dse_ldif, "r");
             buflen = 0;
-#else
-            dse_fp = fopen(serv_p->dse_ldif, "r");
-#endif
             if (dse_fp == NULL) {
                 printf("ldap-agent: Error opening server config file: %s\n",
                        serv_p->dse_ldif);
@@ -422,26 +413,18 @@ load_config(char *conf_path)
                 goto close_and_exit;
             }
 
-/* ldif_get_entry will realloc the entry if it's not null,
+            /* ldif_get_entry will realloc the entry if it's not null,
              * so we can just free it when we're done fetching entries
              * from the dse.ldif.  Unfortunately, ldif_getline moves
              * the pointer that is passed to it, so we need to save a
              * pointer to the beginning of the entry so we can free it
              * later. */
-#if defined(USE_OPENLDAP)
             while (ldif_read_record(dse_fp, &lineno, &entry, &buflen))
-#else
-            while ((entry = ldif_get_entry(dse_fp, &lineno)) != NULL)
-#endif
             {
                 char *entryp = entry;
                 char *attr = NULL;
                 char *val = NULL;
-#if defined(USE_OPENLDAP)
                 ber_len_t vlen;
-#else
-                int vlen;
-#endif
                 /* Check if this is the cn=config entry */
                 if (ldif_parse_line(ldif_getline(&entryp), &attr, &val, &vlen)) {
                     printf("ldap-agent: error parsing ldif line from [%s]\n", serv_p->dse_ldif);
@@ -554,11 +537,7 @@ close_and_exit:
     if (conf_file)
         fclose(conf_file);
     if (dse_fp) {
-#if defined(USE_OPENLDAP)
         ldif_close(dse_fp);
-#else
-        fclose(dse_fp);
-#endif
     }
     if (error)
         exit(error);
