@@ -41,15 +41,17 @@ import {
     KeyIcon,
     UsersIcon,
 } from '@patternfly/react-icons';
-import PropTypes from "prop-types";
-import ExclamationCircleIcon from '@patternfly/react-icons/dist/js/icons/exclamation-circle-icon';
-
+import { PropTypes } from "prop-types";
+import { ExclamationCircleIcon } from '@patternfly/react-icons/dist/js/icons/exclamation-circle-icon';
+import { PlusIcon } from '@patternfly/react-icons/dist/js/icons/plus-icon';
 const DB_CONFIG = "dbconfig";
 const CHAINING_CONFIG = "chaining-config";
 const BACKUP_CONFIG = "backups";
 const PWP_CONFIG = "pwpolicy";
 const LOCAL_PWP_CONFIG = "localpwpolicy";
 
+const _ = cockpit.gettext;
+
 export class Database extends React.Component {
     constructor(props) {
         super(props);
@@ -62,7 +64,7 @@ export class Database extends React.Component {
             dbtype: "",
             activeItems: [
                 {
-                    name: "Global Database Configuration",
+                    name: _("Global Database Configuration"),
                     icon: <CogIcon />,
                     id: "dbconfig",
                 }
@@ -100,6 +102,7 @@ export class Database extends React.Component {
             BackupRows: [],
             backupRefreshing: false,
             suffixList: [],
+            pwdStorageSchemes: [],
             loaded: false,
         };
 
@@ -111,6 +114,7 @@ export class Database extends React.Component {
         this.loadLDIFs = this.loadLDIFs.bind(this);
         this.loadBackups = this.loadBackups.bind(this);
         this.loadSuffixList = this.loadSuffixList.bind(this);
+        this.loadPwdStorageSchemes = this.loadPwdStorageSchemes.bind(this);
 
         // Suffix
         this.handleShowSuffixModal = this.handleShowSuffixModal.bind(this);
@@ -144,6 +148,7 @@ export class Database extends React.Component {
                     this.loadLDIFs();
                     this.loadBackups();
                     this.loadSuffixList();
+                    this.loadPwdStorageSchemes();
                 }
                 this.loadSuffixTree(false);
             } else {
@@ -170,6 +175,22 @@ export class Database extends React.Component {
                 });
     }
 
+    loadPwdStorageSchemes () {
+        const cmd = [
+            "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
+            "pwpolicy", "list-schemes"
+        ];
+        log_cmd("loadPwdStorageSchemes", "Get a list of all the password storage sehemes", cmd);
+        cockpit
+                .spawn(cmd, { superuser: true, err: "message" })
+                .done(content => {
+                    const schemes = JSON.parse(content);
+                    this.setState(() => (
+                        { pwdStorageSchemes: schemes.items }
+                    ));
+                });
+    }
+
     loadNDN() {
         this.setState({
             loaded: false,
@@ -197,7 +218,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading server configuration for database- ${errMsg.desc}`
+                        cockpit.format(_("Error loading server configuration for database- $0"), errMsg.desc)
                     );
                     this.setState({
                         loaded: true,
@@ -242,9 +263,9 @@ export class Database extends React.Component {
                             globalDBConfig:
                                 {
                                     loading: false,
-                                    activeTab: activeTab,
-                                    db_cache_auto: db_cache_auto,
-                                    import_cache_auto: import_cache_auto,
+                                    activeTab,
+                                    db_cache_auto,
+                                    import_cache_auto,
                                     looklimit: attrs['nsslapd-lookthroughlimit'][0],
                                     idscanlimit: attrs['nsslapd-idlistscanlimit'][0],
                                     pagelooklimit: attrs['nsslapd-pagedlookthroughlimit'][0],
@@ -256,7 +277,7 @@ export class Database extends React.Component {
                                     txnlogdir: attrs['nsslapd-db-logdirectory'][0],
                                     dbhomedir: dbhome,
                                     dblocks: attrs['nsslapd-db-locks'][0],
-                                    dblocksMonitoring: dblocksMonitoring,
+                                    dblocksMonitoring,
                                     dblocksMonitoringThreshold: attrs['nsslapd-db-locks-monitoring-threshold'][0],
                                     dblocksMonitoringPause: attrs['nsslapd-db-locks-monitoring-pause'][0],
                                     chxpoint: attrs['nsslapd-db-checkpoint-interval'][0],
@@ -272,7 +293,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading database configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading database configuration - $0"), errMsg.desc)
                     );
                 });
     }
@@ -293,7 +314,7 @@ export class Database extends React.Component {
                         {
                             chainingConfig: {
                                 ...this.state.chainingConfig,
-                                availableOids: availableOids,
+                                availableOids,
                             },
                             chainingUpdated: 1
                         }
@@ -359,7 +380,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading default chaining configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading default chaining configuration - $0"), errMsg.desc)
                     );
                     this.setState({
                         loading: false
@@ -396,9 +417,9 @@ export class Database extends React.Component {
                         {
                             chainingConfig: {
                                 ...this.state.chainingConfig,
-                                oidList: oidList,
-                                compList: compList,
-                                availableComps: availableComps
+                                oidList,
+                                compList,
+                                availableComps
                             },
                             chainingActiveKey: activeKey,
                         }
@@ -439,32 +460,32 @@ export class Database extends React.Component {
                     }
                     const treeData = [
                         {
-                            name: "Global Database Configuration",
+                            name: _("Global Database Configuration"),
                             icon: <CogIcon />,
                             id: "dbconfig",
                         },
                         {
-                            name: "Chaining Configuration",
+                            name: _("Chaining Configuration"),
                             icon: <ExternalLinkAltIcon />,
                             id: "chaining-config",
                         },
                         {
-                            name: "Backups & LDIFs",
+                            name: _("Backups & LDIFs"),
                             icon: <CopyIcon />,
                             id: "backups",
                         },
                         {
-                            name: "Password Policies",
+                            name: _("Password Policies"),
                             id: "pwp",
                             icon: <KeyIcon />,
                             children: [
                                 {
-                                    name: "Global Policy",
+                                    name: _("Global Policy"),
                                     icon: <HomeIcon />,
                                     id: "pwpolicy",
                                 },
                                 {
-                                    name: "Local Policies",
+                                    name: _("Local Policies"),
                                     icon: <UsersIcon />,
                                     id: "localpwpolicy",
                                 },
@@ -472,11 +493,21 @@ export class Database extends React.Component {
                             defaultExpanded: true
                         },
                         {
-                            name: "Suffixes",
+                            name: _("Suffixes"),
                             icon: <CatalogIcon />,
                             id: "suffixes-tree",
                             children: suffixData,
-                            defaultExpanded: true
+                            defaultExpanded: true,
+                            action: (
+                                <Button
+                                    onClick={this.handleShowSuffixModal}
+                                    variant="plain"
+                                    aria-label="Create new suffix"
+                                    title={_("Create new suffix")}
+                                >
+                                    <PlusIcon />
+                                </Button>
+                            ),
                         }
                     ];
                     let current_node = this.state.node_name;
@@ -559,7 +590,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error getting chaining link configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error getting chaining link configuration - $0"), errMsg.desc)
                     );
                 });
     }
@@ -703,8 +734,8 @@ export class Database extends React.Component {
         errObj[e.target.id] = valueErr;
         this.setState({
             [e.target.id]: value,
-            errObj: errObj,
-            createNotOK: createNotOK
+            errObj,
+            createNotOK
         });
     }
 
@@ -726,7 +757,7 @@ export class Database extends React.Component {
         if (this.state.createSuffix === "") {
             this.props.addNotification(
                 "warning",
-                `Missing the suffix DN`
+                _("Missing the suffix DN")
             );
             missingArgs.createSuffix = true;
             errors = true;
@@ -734,7 +765,7 @@ export class Database extends React.Component {
         if (this.state.createBeName === "") {
             this.props.addNotification(
                 "warning",
-                `Missing the suffix backend name`
+                _("Missing the suffix backend name")
             );
             missingArgs.createBeName = true;
             errors = true;
@@ -769,7 +800,7 @@ export class Database extends React.Component {
                     this.closeSuffixModal();
                     this.props.addNotification(
                         "success",
-                        `Successfully create new suffix`
+                        _("Successfully create new suffix")
                     );
                     // Refresh tree
                     this.loadSuffixTree(false);
@@ -782,7 +813,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error creating suffix - ${errMsg.desc}`
+                        cockpit.format(_("Error creating suffix - $0"), errMsg.desc)
                     );
                     this.closeSuffixModal();
                     this.setState({
@@ -907,7 +938,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading indexes for ${suffix} - ${errMsg.desc}`
+                        cockpit.format(_("Error loading indexes for $0 - $1"), suffix, errMsg.desc)
                     );
                 });
     }
@@ -1063,7 +1094,7 @@ export class Database extends React.Component {
                                                         const errMsg = JSON.parse(err);
                                                         this.props.addNotification(
                                                             "error",
-                                                            `Error loading indexes for ${suffix} - ${errMsg.desc}`
+                                                            cockpit.format(_("Error loading indexes for $0 - $1"), suffix, errMsg.desc)
                                                         );
                                                         this.setState({
                                                             suffixLoading: false
@@ -1074,7 +1105,7 @@ export class Database extends React.Component {
                                             const errMsg = JSON.parse(err);
                                             this.props.addNotification(
                                                 "error",
-                                                `Error attribute encryption for ${suffix} - ${errMsg.desc}`
+                                                cockpit.format(_("Error attribute encryption for $0 - $1"), suffix, errMsg.desc)
                                             );
                                             this.setState({
                                                 suffixLoading: false
@@ -1085,7 +1116,7 @@ export class Database extends React.Component {
                                 const errMsg = JSON.parse(err);
                                 this.props.addNotification(
                                     "error",
-                                    `Error loading VLV indexes for ${suffix} - ${errMsg.desc}`
+                                    cockpit.format(_("Error loading VLV indexes for $0 - $1"), suffix, errMsg.desc)
                                 );
                                 this.setState({
                                     suffixLoading: false
@@ -1096,7 +1127,7 @@ export class Database extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading config for ${suffix} - ${errMsg.desc}`
+                        cockpit.format(_("Error loading config for $0 - $1"), suffix, errMsg.desc)
                     );
                     this.setState({
                         suffixLoading: false
@@ -1186,7 +1217,7 @@ export class Database extends React.Component {
 
         if (this.state.loaded) {
             if (this.state.node_name === DB_CONFIG || this.state.node_name === "") {
-                db_element =
+                db_element = (
                     <GlobalDatabaseConfig
                         serverId={this.props.serverId}
                         addNotification={this.props.addNotification}
@@ -1194,9 +1225,10 @@ export class Database extends React.Component {
                         data={this.state.globalDBConfig}
                         enableTree={this.enableTree}
                         key={this.state.configUpdated}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === CHAINING_CONFIG) {
-                db_element =
+                db_element = (
                     <ChainingDatabaseConfig
                         serverId={this.props.serverId}
                         addNotification={this.props.addNotification}
@@ -1205,25 +1237,30 @@ export class Database extends React.Component {
                         enableTree={this.enableTree}
                         activeKey={this.state.chainingActiveKey}
                         key={this.state.chainingUpdated}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === PWP_CONFIG) {
-                db_element =
+                db_element = (
                     <GlobalPwPolicy
                         serverId={this.props.serverId}
                         addNotification={this.props.addNotification}
                         attrs={this.state.attributes}
+                        pwdStorageSchemes={this.state.pwdStorageSchemes}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === LOCAL_PWP_CONFIG) {
-                db_element =
+                db_element = (
                     <LocalPwPolicy
                         serverId={this.props.serverId}
                         addNotification={this.props.addNotification}
                         attrs={this.state.attributes}
+                        pwdStorageSchemes={this.state.pwdStorageSchemes}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === BACKUP_CONFIG) {
-                db_element =
+                db_element = (
                     <Backups
                         serverId={this.props.serverId}
                         addNotification={this.props.addNotification}
@@ -1231,24 +1268,26 @@ export class Database extends React.Component {
                         suffixes={this.state.suffixList}
                         ldifs={this.state.LDIFRows}
                         enableTree={this.enableTree}
-                        reload={this.loadBackups}
+                        handleReload={this.loadBackups}
                         refreshing={this.state.backupRefreshing}
-                    />;
+                    />
+                );
             } else if (this.state.node_name !== "") {
                 // We have a suffix, or database link
                 if (this.state.dbtype === "suffix" || this.state.dbtype === "subsuffix") {
                     if (this.state.suffixLoading) {
-                        db_element =
+                        db_element = (
                             <div className="ds-margin-top-xlg ds-loading-spinner ds-center">
                                 <TextContent>
                                     <Text className="ds-margin-top-xlg" component={TextVariants.h3}>
-                                        Loading suffix configuration for <b>{this.state.node_text} ...</b>
+                                        {_("Loading suffix configuration for ")}<b>{this.state.node_text} ...</b>
                                     </Text>
                                 </TextContent>
                                 <Spinner className="ds-margin-top-lg" size="xl" />
-                            </div>;
+                            </div>
+                        );
                     } else {
-                        db_element =
+                        db_element = (
                             <Suffix
                                 serverId={this.props.serverId}
                                 suffix={this.state.node_text}
@@ -1268,22 +1307,24 @@ export class Database extends React.Component {
                                 attrs={this.state.attributes}
                                 enableTree={this.enableTree}
                                 key={this.state.node_text}
-                            />;
+                            />
+                        );
                     }
                 } else {
                     // Chaining
                     if (this.state.chainingLoading) {
-                        db_element =
+                        db_element = (
                             <div className="ds-margin-top ds-loading-spinner ds-center">
                                 <TextContent>
                                     <Text className="ds-margin-top-xlg" component={TextVariants.h2}>
-                                        Loading Chaining configuration for <b>{this.state.node_text} ...</b>
+                                        {_("Loading Chaining configuration for ")}<b>{this.state.node_text} ...</b>
                                     </Text>
                                 </TextContent>
                                 <Spinner className="ds-margin-top-lg" size="xl" />
-                            </div>;
+                            </div>
+                        );
                     } else {
-                        db_element =
+                        db_element = (
                             <ChainingConfig
                                 serverId={this.props.serverId}
                                 suffix={this.state.node_text}
@@ -1293,11 +1334,12 @@ export class Database extends React.Component {
                                 data={this.state[this.state.node_text]}
                                 enableTree={this.enableTree}
                                 reload={this.loadChainingLink}
-                            />;
+                            />
+                        );
                     }
                 }
             }
-            body =
+            body = (
                 <div className="ds-container">
                     <div>
                         <div className="ds-tree">
@@ -1310,28 +1352,23 @@ export class Database extends React.Component {
                                 />
                             </div>
                         </div>
-                        <Button
-                            className="ds-left-margin-md"
-                            variant="primary"
-                            onClick={this.handleShowSuffixModal}
-                        >
-                            Create Suffix
-                        </Button>
                     </div>
                     <div className="ds-tree-content">
                         {db_element}
                     </div>
-                </div>;
+                </div>
+            );
         } else {
-            body =
+            body = (
                 <div className="ds-center">
                     <TextContent>
                         <Text className="ds-margin-top-xlg" component={TextVariants.h3}>
-                            Loading Database Configuration ...
+                            {_("Loading Database Configuration ...")}
                         </Text>
                     </TextContent>
                     <Spinner className="ds-margin-top" size="xl" />
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -1367,17 +1404,17 @@ class CreateSuffixModal extends React.Component {
             error
         } = this.props;
 
-        let saveBtnName = "Create Suffix";
+        let saveBtnName = _("Create Suffix");
         const extraPrimaryProps = {};
         if (modalSpinning) {
-            saveBtnName = "Creating ...";
-            extraPrimaryProps.spinnerAriaValueText = "Creating";
+            saveBtnName = _("Creating ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Creating");
         }
 
         return (
             <Modal
                 variant={ModalVariant.medium}
-                title="Create New Suffix"
+                title={_("Create New Suffix")}
                 isOpen={showModal}
                 aria-labelledby="ds-modal"
                 onClose={closeHandler}
@@ -1388,22 +1425,22 @@ class CreateSuffixModal extends React.Component {
                         onClick={saveHandler}
                         isDisabled={createNotOK || modalSpinning}
                         isLoading={modalSpinning}
-                        spinnerAriaValueText={modalSpinning ? "Creating Suffix" : undefined}
+                        spinnerAriaValueText={modalSpinning ? _("Creating Suffix") : undefined}
                         {...extraPrimaryProps}
                     >
                         {saveBtnName}
                     </Button>,
                     <Button key="cancel" variant="link" onClick={closeHandler}>
-                        Cancel
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form isHorizontal autoComplete="off">
                     <FormGroup
-                        label="Suffix DN"
+                        label={_("Suffix DN")}
                         fieldId="createSuffix"
-                        title="Database suffix, like 'dc=example,dc=com'.  The suffix must be a valid LDAP Distiguished Name (DN)."
-                        helperTextInvalid="The DN of the suffix is invalid"
+                        title={_("Database suffix, like 'dc=example,dc=com'.  The suffix must be a valid LDAP Distiguished Name (DN).")}
+                        helperTextInvalid={_("The DN of the suffix is invalid")}
                         helperTextInvalidIcon={<ExclamationCircleIcon />}
                         validated={error.createSuffix ? "error" : "noval"}
                     >
@@ -1417,14 +1454,14 @@ class CreateSuffixModal extends React.Component {
                             validated={error.createSuffix ? "error" : "noval"}
                         />
                         <FormHelperText isError isHidden={!error.createSuffix}>
-                            Required field
+                            {_("Required field")}
                         </FormHelperText>
                     </FormGroup>
                     <FormGroup
-                        label="Database Name"
+                        label={_("Database Name")}
                         fieldId="suffixName"
-                        title="The name for the backend database, like 'userroot'.  The name can be a combination of alphanumeric characters, dashes (-), and underscores (_). No other characters are allowed, and the name must be unique across all backends."
-                        helperTextInvalid="You must enter a name for the database"
+                        title={_("The name for the backend database, like 'userroot'.  The name can be a combination of alphanumeric characters, dashes (-), and underscores (_). No other characters are allowed, and the name must be unique across all backends.")}
+                        helperTextInvalid={_("You must enter a name for the database")}
                         helperTextInvalidIcon={<ExclamationCircleIcon />}
                         validated={error.createBeName ? "error" : "noval"}
                     >
@@ -1438,17 +1475,17 @@ class CreateSuffixModal extends React.Component {
                             validated={error.createBeName ? "error" : "noval"}
                         />
                         <FormHelperText isError isHidden={!error.createBeName}>
-                            Required field
+                            {_("Required field")}
                         </FormHelperText>
                     </FormGroup>
                     <FormGroup
-                        label="Initialization Option"
+                        label={_("Initialization Option")}
                         fieldId="initOptions"
                     >
                         <FormSelect value={initOption} onChange={handleSelectChange} aria-label="FormSelect Input">
-                            <FormSelectOption key={1} value="noInit" label="Do Not Initialize Database" />
-                            <FormSelectOption key={2} value="addSuffix" label="Create The Top Suffix Entry" />
-                            <FormSelectOption key={3} value="addSample" label="Add Sample Entries" />
+                            <FormSelectOption key={1} value="noInit" label={_("Do Not Initialize Database")} />
+                            <FormSelectOption key={2} value="addSuffix" label={_("Create The Top Suffix Entry")} />
+                            <FormSelectOption key={3} value="addSample" label={_("Add Sample Entries")} />
                         </FormSelect>
                     </FormGroup>
                 </Form>
@@ -1471,8 +1508,8 @@ Database.defaultProps = {
 CreateSuffixModal.propTypes = {
     showModal: PropTypes.bool,
     closeHandler: PropTypes.func,
-    onHandleChange: PropTypes.func,
-    onHandleSelectChange: PropTypes.func,
+    handleChange: PropTypes.func,
+    handleSelectChange: PropTypes.func,
     saveHandler: PropTypes.func,
     modalSpinning: PropTypes.bool,
     error: PropTypes.object,
