@@ -23,9 +23,7 @@ import {
 } from "@patternfly/react-core";
 import PropTypes from "prop-types";
 
-const edit_attrs = ['mrs', 'indexTypeEq', 'indexTypeSub',
-    'indexTypePres', 'indexTypeApprox',
-];
+const _ = cockpit.gettext;
 
 export class SuffixIndexes extends React.Component {
     constructor (props) {
@@ -73,7 +71,7 @@ export class SuffixIndexes extends React.Component {
         };
 
         // Select Attribute
-        this.onAttributeSelect = (event, selection) => {
+        this.handleAttributeSelect = (event, selection) => {
             if (this.state.indexName.includes(selection)) {
                 this.setState(
                     (prevState) => ({
@@ -90,36 +88,36 @@ export class SuffixIndexes extends React.Component {
                 );
             }
         };
-        this.onAttributeToggle = isAttributeOpen => {
+        this.handleAttributeToggle = isAttributeOpen => {
             this.setState({
                 isAttributeOpen
             });
         };
-        this.onAttributeClear = () => {
+        this.handleAttributeClear = () => {
             this.setState({
                 indexName: [],
                 isAttributeOpen: false
             });
         };
 
-        this.onMatchingruleAddToggle = isMatchingruleOpen => {
+        this.handleMatchingruleAddToggle = isMatchingruleOpen => {
             this.setState({
                 isMatchingruleOpen
             });
         };
-        this.onMatchingruleAddClear = () => {
+        this.handleMatchingruleAddClear = () => {
             this.setState({
                 mrs: [],
                 isMatchingruleOpen: false
             });
         };
 
-        this.onMatchingruleEditToggle = isMatchingruleOpen => {
+        this.handleMatchingruleEditToggle = isMatchingruleOpen => {
             this.setState({
                 isMatchingruleOpen
             });
         };
-        this.onMatchingruleEditClear = () => {
+        this.handleMatchingruleEditClear = () => {
             this.setState({
                 mrs: [],
                 isMatchingruleOpen: false
@@ -127,9 +125,9 @@ export class SuffixIndexes extends React.Component {
         };
 
         this.loadIndexes = this.loadIndexes.bind(this);
-        this.showIndexModal = this.showIndexModal.bind(this);
+        this.handleShowIndexModal = this.handleShowIndexModal.bind(this);
         this.closeIndexModal = this.closeIndexModal.bind(this);
-        this.handleChange = this.handleChange.bind(this);
+        this.onChange = this.onChange.bind(this);
         this.onSelectToggle = this.onSelectToggle.bind(this);
         this.onSelectClear = this.onSelectClear.bind(this);
         this.saveIndex = this.saveIndex.bind(this);
@@ -143,7 +141,7 @@ export class SuffixIndexes extends React.Component {
         this.showConfirmDeleteIndex = this.showConfirmDeleteIndex.bind(this);
         this.closeConfirmDeleteIndex = this.closeConfirmDeleteIndex.bind(this);
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
-        this.onMatchingruleSelect = this.onMatchingruleSelect.bind(this);
+        this.handleMatchingruleSelect = this.handleMatchingruleSelect.bind(this);
     }
 
     componentDidMount () {
@@ -151,7 +149,9 @@ export class SuffixIndexes extends React.Component {
     }
 
     componentWillUnmount() {
-        this.state._isMounted = false;
+        this.setState({
+            _isMounted: false
+        });
     }
 
     loadIndexes () {
@@ -167,7 +167,7 @@ export class SuffixIndexes extends React.Component {
                     const mrContent = JSON.parse(content);
                     const mrs = [];
                     for (let i = 0; i < mrContent.items.length; i++) {
-                        if (mrContent.items[i].name[0] != "") {
+                        if (mrContent.items[i].name[0] !== "") {
                             mrs.push(mrContent.items[i].name[0]);
                         }
                     }
@@ -193,7 +193,7 @@ export class SuffixIndexes extends React.Component {
                                             const attrContent = JSON.parse(content);
                                             const attrs = [];
                                             for (const content of attrContent.items) {
-                                                if (indexList.indexOf(content.name[0]) == -1) {
+                                                if (indexList.indexOf(content.name[0]) === -1) {
                                                     // Attribute is not a current index, add it to the list
                                                     // of available attributes to index
                                                     attrs.push(content.name[0]);
@@ -211,7 +211,7 @@ export class SuffixIndexes extends React.Component {
                                             const errMsg = JSON.parse(err);
                                             this.props.addNotification(
                                                 "error",
-                                                `Failed to get attributes - ${errMsg.desc}`
+                                                cockpit.format(_("Failed to get attributes - $0"), errMsg.desc)
                                             );
                                         });
                             });
@@ -220,7 +220,7 @@ export class SuffixIndexes extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Failed to get matching rules - ${errMsg.desc}`
+                        cockpit.format(_("Failed to get matching rules - $0"), errMsg.desc)
                     );
                 });
     }
@@ -228,7 +228,7 @@ export class SuffixIndexes extends React.Component {
     //
     // Index Modal functions
     //
-    showIndexModal() {
+    handleShowIndexModal() {
         this.setState({
             showIndexModal: true,
             errObj: {},
@@ -267,30 +267,30 @@ export class SuffixIndexes extends React.Component {
 
         // Check if a setting was changed, if so enable the save button
         for (const config_attr of check_attrs) {
-            if (this.state[config_attr] != this.state['_' + config_attr]) {
+            if (this.state[config_attr] !== this.state['_' + config_attr]) {
                 saveBtnDisabled = false;
                 break;
             }
         }
 
-        if (JSON.stringify(this.state._mrs) != JSON.stringify(this.state.mrs)) {
+        if (JSON.stringify(this.state._mrs) !== JSON.stringify(this.state.mrs)) {
             saveBtnDisabled = false;
         }
 
         // We must have at least one index type set
-        if (!this.state.indexTypeEq && !this.state.indexTypeSub &&
-            !this.state.indexTypePres && !this.state.indexTypeApprox ||
-            (this.state.indexName.length === 0 || this.state.indexName[0] === "")) {
+        if ((!this.state.indexTypeEq && !this.state.indexTypeSub &&
+             !this.state.indexTypePres && !this.state.indexTypeApprox) ||
+            this.state.indexName.length === 0 || this.state.indexName[0] === "") {
             // Must always have one index type
             saveBtnDisabled = true;
         }
 
         this.setState({
-            saveBtnDisabled: saveBtnDisabled,
+            saveBtnDisabled,
         });
     }
 
-    handleChange(e) {
+    onChange(e) {
         // Handle the modal changes
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
@@ -299,7 +299,7 @@ export class SuffixIndexes extends React.Component {
     }
 
     // Edit Matching Rules
-    onMatchingruleSelect(event, selection) {
+    handleMatchingruleSelect(event, selection) {
         const new_mrs = [...this.state.mrs];
         if (new_mrs.includes(selection)) {
             const index = new_mrs.indexOf(selection);
@@ -315,10 +315,10 @@ export class SuffixIndexes extends React.Component {
                 isMatchingruleOpen: false,
             }, () => { this.validateSaveBtn() });
         }
-    };
+    }
 
     saveIndex() {
-        let cmd = [
+        const cmd = [
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "backend", "index", "add", "--attr=" + this.state.indexName[0],
             this.props.suffix,
@@ -359,7 +359,7 @@ export class SuffixIndexes extends React.Component {
                     }
                     this.props.addNotification(
                         "success",
-                        `Successfully created new index`
+                        _("Successfully created new index")
                     );
                     this.setState({
                         saving: false,
@@ -372,7 +372,7 @@ export class SuffixIndexes extends React.Component {
                     this.closeIndexModal();
                     this.props.addNotification(
                         "error",
-                        `Error creating index - ${errMsg.desc}`
+                        cockpit.format(_("Error creating index - $0"), errMsg.desc)
                     );
                     this.setState({
                         saving: false,
@@ -452,7 +452,7 @@ export class SuffixIndexes extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error indexing attribute ${attr} - ${errMsg.desc}`
+                        cockpit.format(_("Error indexing attribute $0 - $1"), attr, errMsg.desc)
                     );
                     this.setState({
                         saving: false,
@@ -465,7 +465,7 @@ export class SuffixIndexes extends React.Component {
     saveEditIndex() {
         const origMRS = this.state._mrs;
         const newMRS = this.state.mrs;
-        let cmd = [
+        const cmd = [
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "backend", "index", "set", "--attr=" + this.state.indexName,
             this.props.suffix,
@@ -475,7 +475,7 @@ export class SuffixIndexes extends React.Component {
         for (const newMR of newMRS) {
             let found = false;
             for (const origMR of origMRS) {
-                if (origMR == newMR) {
+                if (origMR === newMR) {
                     found = true;
                     break;
                 }
@@ -488,7 +488,7 @@ export class SuffixIndexes extends React.Component {
         for (const origMR of origMRS) {
             let found = false;
             for (const newMR of newMRS) {
-                if (newMR == origMR) {
+                if (newMR === origMR) {
                     found = true;
                     break;
                 }
@@ -533,7 +533,7 @@ export class SuffixIndexes extends React.Component {
                         this.closeEditIndexModal();
                         this.props.addNotification(
                             "success",
-                            `Successfully edited index`
+                            _("Successfully edited index")
                         );
                         if (this.state.reindexOnAdd) {
                             this.reindexAttr(this.state.indexName);
@@ -549,7 +549,7 @@ export class SuffixIndexes extends React.Component {
                         this.closeEditIndexModal();
                         this.props.addNotification(
                             "error",
-                            `Error editing index - ${errMsg.desc}`
+                            cockpit.format(_("Error editing index - $0"), errMsg.desc)
                         );
                         this.setState({
                             saving: false,
@@ -622,7 +622,7 @@ export class SuffixIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Error deleting index - ${errMsg.desc}`
+                        cockpit.format(_("Error deleting index - $0"), errMsg.desc)
                     );
                     this.closeConfirmDeleteIndex();
                 });
@@ -632,7 +632,7 @@ export class SuffixIndexes extends React.Component {
         this.setState({
             [toggleId]: isExpanded
         });
-    }
+    };
 
     onSelectClear = item => event => {
         switch (item) {
@@ -657,13 +657,13 @@ export class SuffixIndexes extends React.Component {
         default:
             break;
         }
-    }
+    };
 
     render() {
         return (
             <div className="ds-margin-top-xlg ds-left-indent">
                 <Tabs isSecondary isBox activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
-                    <Tab eventKey={0} title={<TabTitleText>Database Indexes <font size="2">({this.props.indexRows.length})</font></TabTitleText>}>
+                    <Tab eventKey={0} title={<TabTitleText>{_("Database Indexes ")}<font size="2">({this.props.indexRows.length})</font></TabTitleText>}>
                         <div className="ds-left-indent ds-margin-bottom-md">
                             <IndexTable
                                 editable
@@ -676,13 +676,13 @@ export class SuffixIndexes extends React.Component {
                             <Button
                                 variant="primary"
                                 type="button"
-                                onClick={this.showIndexModal}
+                                onClick={this.handleShowIndexModal}
                             >
-                                Add Index
+                                {_("Add Index")}
                             </Button>
                         </div>
                     </Tab>
-                    <Tab eventKey={1} title={<TabTitleText>System Indexes <font size="2">({this.props.systemIndexRows.length})</font></TabTitleText>}>
+                    <Tab eventKey={1} title={<TabTitleText>{_("System Indexes ")}<font size="2">({this.props.systemIndexRows.length})</font></TabTitleText>}>
                         <div className="ds-left-indent">
                             <IndexTable
                                 rows={this.props.systemIndexRows}
@@ -694,7 +694,7 @@ export class SuffixIndexes extends React.Component {
                 <AddIndexModal
                     showModal={this.state.showIndexModal}
                     closeHandler={this.closeIndexModal}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     saveHandler={this.saveIndex}
                     matchingRules={this.state.matchingRules}
                     attributes={this.state.attributes}
@@ -705,13 +705,13 @@ export class SuffixIndexes extends React.Component {
                     indexTypeSub={this.state.indexTypeSub}
                     indexTypeApprox={this.state.indexTypeApprox}
                     reindexOnAdd={this.state.reindexOnAdd}
-                    onAttributeSelect={this.onAttributeSelect}
-                    onAttributeToggle={this.onAttributeToggle}
-                    onAttributeClear={this.onAttributeClear}
+                    onAttributeSelect={this.handleAttributeSelect}
+                    onAttributeToggle={this.handleAttributeToggle}
+                    onAttributeClear={this.handleAttributeClear}
                     isAttributeOpen={this.state.isAttributeOpen}
-                    onMatchingruleSelect={this.onMatchingruleSelect}
-                    onMatchingruleAddToggle={this.onMatchingruleAddToggle}
-                    onMatchingruleAddClear={this.onMatchingruleAddClear}
+                    onMatchingruleSelect={this.handleMatchingruleSelect}
+                    onMatchingruleAddToggle={this.handleMatchingruleAddToggle}
+                    onMatchingruleAddClear={this.handleMatchingruleAddClear}
                     isMatchingruleOpen={this.state.isMatchingruleOpen}
                     saving={this.state.saving}
                     saveBtnDisabled={this.state.saveBtnDisabled}
@@ -719,7 +719,7 @@ export class SuffixIndexes extends React.Component {
                 <EditIndexModal
                     showModal={this.state.showEditIndexModal}
                     closeHandler={this.closeEditIndexModal}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     saveHandler={this.saveEditIndex}
                     types={this.state.types}
                     mrs={this.state.mrs}
@@ -730,9 +730,9 @@ export class SuffixIndexes extends React.Component {
                     indexTypeSub={this.state.indexTypeSub}
                     indexTypeApprox={this.state.indexTypeApprox}
                     reindexOnAdd={this.state.reindexOnAdd}
-                    onMatchingruleSelect={this.onMatchingruleSelect}
-                    onMatchingruleEditToggle={this.onMatchingruleEditToggle}
-                    onMatchingruleEditClear={this.onMatchingruleEditClear}
+                    onMatchingruleSelect={this.handleMatchingruleSelect}
+                    onMatchingruleEditToggle={this.handleMatchingruleEditToggle}
+                    onMatchingruleEditClear={this.handleMatchingruleEditClear}
                     isMatchingruleOpen={this.state.isMatchingruleOpen}
                     saving={this.state.saving}
                     saveBtnDisabled={this.state.saveBtnDisabled}
@@ -740,28 +740,28 @@ export class SuffixIndexes extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmReindex}
                     closeHandler={this.closeConfirmReindex}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.reindexIndex}
                     spinning={this.state.modalSpinning}
                     item={this.state.reindexAttrName}
                     checked={this.state.modalChecked}
-                    mTitle="Reindex Attribute"
-                    mMsg="Are you sure you want to reindex this attribute?"
-                    mSpinningMsg="Reindexing ..."
-                    mBtnName="Reindex"
+                    mTitle={_("Reindex Attribute")}
+                    mMsg={_("Are you sure you want to reindex this attribute?")}
+                    mSpinningMsg={_("Reindexing ...")}
+                    mBtnName={_("Reindex")}
                 />
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmDeleteIndex}
                     closeHandler={this.closeConfirmDeleteIndex}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.deleteIndex}
                     spinning={this.state.modalSpinning}
                     item={this.state.deleteAttrName}
                     checked={this.state.modalChecked}
-                    mTitle="Delete Index"
-                    mMsg="Are you sure you want to delete this index?"
-                    mSpinningMsg="Deleting ..."
-                    mBtnName="Delete"
+                    mTitle={_("Delete Index")}
+                    mMsg={_("Are you sure you want to delete this index?")}
+                    mSpinningMsg={_("Deleting ...")}
+                    mBtnName={_("Delete")}
                 />
             </div>
         );
@@ -799,17 +799,17 @@ class AddIndexModal extends React.Component {
         for (const attr of attributes) {
             availAttrs.push(attr);
         }
-        let saveBtnName = "Create Index";
+        let saveBtnName = _("Create Index");
         const extraPrimaryProps = {};
         if (saving) {
-            saveBtnName = "Creating ...";
-            extraPrimaryProps.spinnerAriaValueText = "Creating";
+            saveBtnName = _("Creating ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Creating");
         }
 
         return (
             <Modal
                 variant={ModalVariant.medium}
-                title="Add Database Index"
+                title={_("Add Database Index")}
                 isOpen={showModal}
                 onClose={closeHandler}
                 aria-labelledby="ds-modal"
@@ -819,34 +819,34 @@ class AddIndexModal extends React.Component {
                         variant="primary"
                         onClick={saveHandler}
                         isLoading={saving}
-                        spinnerAriaValueText={saving ? "Creating" : undefined}
+                        spinnerAriaValueText={saving ? _("Creating") : undefined}
                         {...extraPrimaryProps}
                         isDisabled={saveBtnDisabled || saving}
                     >
                         {saveBtnName}
                     </Button>,
                     <Button key="cancel" variant="link" onClick={closeHandler}>
-                        Cancel
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form isHorizontal autoComplete="off">
-                    <TextContent title="Select an attribute to index">
+                    <TextContent title={_("Select an attribute to index")}>
                         <Text component={TextVariants.h4}>
-                            Select An Attribute
+                            {_("Select An Attribute")}
                         </Text>
                     </TextContent>
                     <Select
                         variant={SelectVariant.typeahead}
-                        typeAheadAriaLabel="Type a attribute name to index"
+                        typeAheadAriaLabel={_("Type a attribute name to index")}
                         onToggle={onAttributeToggle}
                         onClear={onAttributeClear}
                         onSelect={onAttributeSelect}
                         selections={attributeName}
                         isOpen={isAttributeOpen}
                         aria-labelledby="typeAhead-attr-add"
-                        placeholderText="Type a attribute name to index.."
-                        noResultsFoundText="There are no matching entries"
+                        placeholderText={_("Type a attribute name to index..")}
+                        noResultsFoundText={_("There are no matching entries")}
                         validated={attributeName.length === 0 || attributeName[0] === "" ? "error" : "default"}
                     >
                         {availAttrs.map((attr, index) => (
@@ -858,7 +858,7 @@ class AddIndexModal extends React.Component {
                     </Select>
                     <TextContent className="ds-margin-top">
                         <Text component={TextVariants.h4}>
-                            Index Types
+                            {_("Index Types")}
                         </Text>
                     </TextContent>
                     <div className="ds-indent">
@@ -870,7 +870,7 @@ class AddIndexModal extends React.Component {
                                     onChange={(checked, e) => {
                                         handleChange(e);
                                     }}
-                                    label="Equailty Indexing"
+                                    label={_("Equailty Indexing")}
                                 />
                             </GridItem>
                         </Grid>
@@ -882,7 +882,7 @@ class AddIndexModal extends React.Component {
                                     onChange={(checked, e) => {
                                         handleChange(e);
                                     }}
-                                    label="Presence Indexing"
+                                    label={_("Presence Indexing")}
                                 />
                             </GridItem>
                         </Grid>
@@ -894,7 +894,7 @@ class AddIndexModal extends React.Component {
                                     onChange={(checked, e) => {
                                         handleChange(e);
                                     }}
-                                    label="Substring Indexing"
+                                    label={_("Substring Indexing")}
                                 />
                             </GridItem>
                         </Grid>
@@ -906,16 +906,16 @@ class AddIndexModal extends React.Component {
                                     onChange={(checked, e) => {
                                         handleChange(e);
                                     }}
-                                    label="Approximate Indexing"
+                                    label={_("Approximate Indexing")}
                                 />
                             </GridItem>
                         </Grid>
                     </div>
                     <Grid className="ds-margin-top-lg">
-                        <GridItem span={12} title="List of matching rules separated by a 'space'">
+                        <GridItem span={12} title={_("List of matching rules separated by a 'space'")}>
                             <TextContent>
                                 <Text component={TextVariants.h4}>
-                                    Matching Rules
+                                    {_("Matching Rules")}
                                 </Text>
                             </TextContent>
                             <div className="ds-indent ds-margin-top">
@@ -929,8 +929,8 @@ class AddIndexModal extends React.Component {
                                     selections={mrs}
                                     isOpen={isMatchingruleOpen}
                                     aria-labelledby="typeAhead-mr-add"
-                                    placeholderText="Type a matching rule name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type a matching rule name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                 >
                                     {availMR.map((mrs, index) => (
                                         <SelectOption
@@ -950,7 +950,7 @@ class AddIndexModal extends React.Component {
                                 onChange={(checked, e) => {
                                     handleChange(e);
                                 }}
-                                label="Index attribute after creation"
+                                label={_("Index attribute after creation")}
                             />
                         </GridItem>
                     </Grid>
@@ -987,15 +987,15 @@ class EditIndexModal extends React.Component {
             saveBtnDisabled
         } = this.props;
 
-        let saveBtnName = "Save Index";
+        let saveBtnName = _("Save Index");
         const extraPrimaryProps = {};
         if (saving) {
-            saveBtnName = "Saving index ...";
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            saveBtnName = _("Saving index ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         }
 
         let attrTypes = "";
-        if (types != "" && types.length > 0) {
+        if (types !== "" && types.length > 0) {
             attrTypes = types.split(",").map(item => item.trim());
         }
 
@@ -1003,97 +1003,113 @@ class EditIndexModal extends React.Component {
         const availMR = matchingRules;
 
         // Default settings
-        let eq = <div>
-            <Checkbox
+        let eq = (
+            <div>
+                <Checkbox
                 id="indexTypeEq"
                 isChecked={this.props.indexTypeEq}
                 onChange={(checked, e) => {
                     handleChange(e);
                 }}
-                label="Equailty Indexing"
-            />
-        </div>;
-        let pres = <div>
-            <Checkbox
+                label={_("Equailty Indexing")}
+                />
+            </div>
+        );
+        let pres = (
+            <div>
+                <Checkbox
                 id="indexTypePres"
                 isChecked={this.props.indexTypePres}
                 onChange={(checked, e) => {
                     handleChange(e);
                 }}
-                label="Presence Indexing"
-            />
-        </div>;
-        let sub = <div>
-            <Checkbox
+                label={_("Presence Indexing")}
+                />
+            </div>
+        );
+        let sub = (
+            <div>
+                <Checkbox
                 id="indexTypeSub"
                 isChecked={this.props.indexTypeSub}
                 onChange={(checked, e) => {
                     handleChange(e);
                 }}
-                label="Substring Indexing"
-            />
-        </div>;
-        let approx = <div>
-            <Checkbox
+                label={_("Substring Indexing")}
+                />
+            </div>
+        );
+        let approx = (
+            <div>
+                <Checkbox
                 id="indexTypeApprox"
                 isChecked={this.props.indexTypeApprox}
                 onChange={(checked, e) => {
                     handleChange(e);
                 }}
-                label="Approximate Indexing"
-            />
-        </div>;
+                label={_("Approximate Indexing")}
+                />
+            </div>
+        );
 
         if (attrTypes.includes('eq')) {
-            eq = <div>
-                <Checkbox
+            eq = (
+                <div>
+                    <Checkbox
                     id="indexTypeEq"
                     isChecked={this.props.indexTypeEq}
                     onChange={(checked, e) => {
                         handleChange(e);
                     }}
-                    label="Equality Indexing"
-                />
-            </div>;
+                    label={_("Equality Indexing")}
+                    />
+                </div>
+            );
         }
         if (attrTypes.includes('pres')) {
-            pres = <div>
-                <Checkbox
+            pres = (
+                <div>
+                    <Checkbox
                     id="indexTypePres"
                     isChecked={this.props.indexTypePres}
                     onChange={(checked, e) => {
                         handleChange(e);
                     }}
-                    label="Presence Indexing"
-                />
-            </div>;
+                    label={_("Presence Indexing")}
+                    />
+                </div>
+            );
         }
         if (attrTypes.includes('sub')) {
-            sub = <div>
-                <Checkbox
+            sub = (
+                <div>
+                    <Checkbox
                     id="indexTypeSub"
                     isChecked={this.props.indexTypeSub}
                     onChange={(checked, e) => {
                         handleChange(e);
                     }}
-                    label="Substring Indexing"
-                />
-            </div>;
+                    label={_("Substring Indexing")}
+                    />
+                </div>
+            );
         }
         if (attrTypes.includes('approx')) {
-            approx = <div>
-                <Checkbox
+            approx = (
+                <div>
+                    <Checkbox
                     id="indexTypeApprox"
                     isChecked={this.props.indexTypeApprox}
                     onChange={(checked, e) => {
                         handleChange(e);
                     }}
-                    label="Approximate Indexing"
-                />
-            </div>;
+                    label={_("Approximate Indexing")}
+                    />
+                </div>
+            );
         }
 
-        const title = <div>Edit Database Index (<b>{indexName[0]}</b>)</div>;
+        const title = <div>{_("Edit Database Index (")}<b>{indexName[0]}</b>)</div>;
 
         return (
             <Modal
@@ -1108,21 +1124,21 @@ class EditIndexModal extends React.Component {
                         variant="primary"
                         onClick={saveHandler}
                         isLoading={saving}
-                        spinnerAriaValueText={saving ? "Saving" : undefined}
+                        spinnerAriaValueText={saving ? _("Saving") : undefined}
                         {...extraPrimaryProps}
                         isDisabled={saveBtnDisabled || saving}
                     >
                         {saveBtnName}
                     </Button>,
                     <Button key="cancel" variant="link" onClick={closeHandler}>
-                        Cancel
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form isHorizontal autoComplete="off">
                     <TextContent>
                         <Text className="ds-margin-top" component={TextVariants.h4}>
-                            Index Types
+                            {_("Index Types")}
                         </Text>
                     </TextContent>
                     <div className="ds-indent">
@@ -1151,7 +1167,7 @@ class EditIndexModal extends React.Component {
                         <GridItem span={12}>
                             <TextContent>
                                 <Text component={TextVariants.h4}>
-                                    Matching Rules
+                                    {_("Matching Rules")}
                                 </Text>
                             </TextContent>
                             <div className="ds-indent ds-margin-top">
@@ -1164,8 +1180,8 @@ class EditIndexModal extends React.Component {
                                     selections={currentMrs}
                                     isOpen={isMatchingruleOpen}
                                     aria-labelledby="typeAhead-mr-edit"
-                                    placeholderText="Type a matching rule name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type a matching rule name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                 >
                                     {availMR.map((mr, index) => (
                                         <SelectOption
@@ -1185,7 +1201,7 @@ class EditIndexModal extends React.Component {
                                 onChange={(checked, e) => {
                                     handleChange(e);
                                 }}
-                                label="Reindex Attribute After Saving"
+                                label={_("Reindex Attribute After Saving")}
                             />
                         </GridItem>
                     </Grid>
