@@ -17,6 +17,8 @@ import {
 import { log_cmd, valid_port, valid_dn } from "../tools.jsx";
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 export class SuffixReferrals extends React.Component {
     constructor (props) {
         super(props);
@@ -45,22 +47,22 @@ export class SuffixReferrals extends React.Component {
         this.deleteRef = this.deleteRef.bind(this);
         this.saveRef = this.saveRef.bind(this);
         // Referral modal
-        this.showRefModal = this.showRefModal.bind(this);
+        this.handleShowRefModal = this.handleShowRefModal.bind(this);
         this.closeRefModal = this.closeRefModal.bind(this);
-        this.handleRefChange = this.handleRefChange.bind(this);
+        this.onRefChange = this.onRefChange.bind(this);
         this.buildRef = this.buildRef.bind(this);
-        this.handleChange = this.handleChange.bind(this);
-        this.handleScopeChange = this.handleScopeChange.bind(this);
-        this.handleLdapChange = this.handleLdapChange.bind(this);
+        this.onChange = this.onChange.bind(this);
+        this.onScopeChange = this.onScopeChange.bind(this);
+        this.onLdapChange = this.onLdapChange.bind(this);
     }
 
-    handleScopeChange(value, event) {
+    onScopeChange(value, event) {
         this.setState({
             refScope: value,
         });
     }
 
-    handleLdapChange(value, event) {
+    onLdapChange(value, event) {
         this.setState({
             refProtocol: value,
         });
@@ -75,7 +77,7 @@ export class SuffixReferrals extends React.Component {
         });
     }
 
-    showRefModal() {
+    handleShowRefModal() {
         this.setState({
             showRefModal: true,
             errObj: {},
@@ -113,7 +115,7 @@ export class SuffixReferrals extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        `Referral successfully deleted`
+                        _("Referral successfully deleted")
                     );
                     this.setState({
                         modalSpinning: false,
@@ -125,7 +127,7 @@ export class SuffixReferrals extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Failure deleting referral - ${errMsg.desc}`
+                        cockpit.format(_("Failure deleting referral - $0"), errMsg.desc)
                     );
                     this.setState({
                         modalSpinning: false,
@@ -153,7 +155,7 @@ export class SuffixReferrals extends React.Component {
                     this.closeRefModal();
                     this.props.addNotification(
                         "success",
-                        `Referral successfully created`
+                        _("Referral successfully created")
                     );
                     this.setState({
                         saving: false
@@ -165,7 +167,7 @@ export class SuffixReferrals extends React.Component {
                     this.closeRefModal();
                     this.props.addNotification(
                         "error",
-                        `Failure creating referral - ${errMsg.desc}`
+                        cockpit.format(_("Failure creating referral - $0"), errMsg.desc)
                     );
                     this.setState({
                         saving: false
@@ -181,22 +183,22 @@ export class SuffixReferrals extends React.Component {
         const ref_filter = this.state.refFilter;
         const ref_scope = this.state.refScope;
 
-        if (ref_port != "") {
+        if (ref_port !== "") {
             previewRef += ":" + ref_port;
         }
-        if (ref_suffix != "" || ref_attrs != "" || ref_filter != "" || ref_scope != "") {
+        if (ref_suffix !== "" || ref_attrs !== "" || ref_filter !== "" || ref_scope !== "") {
             previewRef += "/" + encodeURIComponent(ref_suffix);
-            if (ref_attrs != "") {
+            if (ref_attrs !== "") {
                 previewRef += "?" + encodeURIComponent(ref_attrs);
-            } else if (ref_filter != "" || ref_scope != "") {
+            } else if (ref_filter !== "" || ref_scope !== "") {
                 previewRef += "?";
             }
-            if (ref_scope != "") {
+            if (ref_scope !== "") {
                 previewRef += "?" + encodeURIComponent(ref_scope);
-            } else if (ref_filter != "") {
+            } else if (ref_filter !== "") {
                 previewRef += "?";
             }
-            if (ref_filter != "") {
+            if (ref_filter !== "") {
                 previewRef += "?" + encodeURIComponent(ref_filter);
             }
         }
@@ -207,7 +209,7 @@ export class SuffixReferrals extends React.Component {
         });
     }
 
-    handleRefChange(e) {
+    onRefChange(e) {
         const value = e.target.value;
         const attr = e.target.id;
         const errObj = this.state.errObj;
@@ -217,22 +219,22 @@ export class SuffixReferrals extends React.Component {
         // Check previously set values
         const check_attrs = ['refHost', 'refPort'];
         for (const check_attr of check_attrs) {
-            if (attr != check_attr) {
-                if (this.state[check_attr] == "") {
+            if (attr !== check_attr) {
+                if (this.state[check_attr] === "") {
                     saveBtnDisabled = true;
                 }
             }
         }
         // Check changes
-        if (attr == "refHost" && value == "") {
+        if (attr === "refHost" && value === "") {
             saveBtnDisabled = true;
             valueErr = true;
         }
-        if (attr == "refPort" && (value == "" || !valid_port(value))) {
+        if (attr === "refPort" && (value === "" || !valid_port(value))) {
             saveBtnDisabled = true;
             valueErr = true;
         }
-        if (attr == "refSuffix" && (value != "" && !valid_dn(value))) {
+        if (attr === "refSuffix" && (value !== "" && !valid_dn(value))) {
             saveBtnDisabled = true;
             valueErr = true;
         }
@@ -240,12 +242,12 @@ export class SuffixReferrals extends React.Component {
         errObj[e.target.id] = valueErr;
         this.setState({
             [e.target.id]: value,
-            errObj: errObj,
-            saveBtnDisabled: saveBtnDisabled
+            errObj,
+            saveBtnDisabled
         }, this.buildRef);
     }
 
-    handleChange(e) {
+    onChange(e) {
         // Basic handler, no error checking
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
@@ -261,28 +263,28 @@ export class SuffixReferrals extends React.Component {
                     rows={this.props.rows}
                     deleteRef={this.showConfirmRefDelete}
                 />
-                <Button variant="primary" onClick={this.showRefModal}>
-                    Create Referral
+                <Button variant="primary" onClick={this.handleShowRefModal}>
+                    {_("Create Referral")}
                 </Button>
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmRefDelete}
                     closeHandler={this.closeConfirmRefDelete}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.deleteRef}
                     spinning={this.state.modalSpinning}
                     item={this.state.removeRef}
                     checked={this.state.modalChecked}
-                    mTitle="Delete Referral"
-                    mMsg="Are you sure you want to delete this referral?"
-                    mSpinningMsg="Deleting ..."
-                    mBtnName="Delete"
+                    mTitle={_("Delete Referral")}
+                    mMsg={_("Are you sure you want to delete this referral?")}
+                    mSpinningMsg={_("Deleting ...")}
+                    mBtnName={_("Delete")}
                 />
                 <AddReferralModal
                     showModal={this.state.showRefModal}
                     closeHandler={this.closeRefModal}
-                    handleChange={this.handleRefChange}
-                    handleScopeChange={this.handleScopeChange}
-                    handleLdapChange={this.handleLdapChange}
+                    handleChange={this.onRefChange}
+                    handleScopeChange={this.onScopeChange}
+                    handleLdapChange={this.onLdapChange}
                     saveHandler={this.saveRef}
                     previewValue={this.state.refValue}
                     refProtocol={this.state.refProtocol}
@@ -313,19 +315,19 @@ class AddReferralModal extends React.Component {
             refScope,
         } = this.props;
 
-        if (previewValue == "") {
+        if (previewValue === "") {
             previewValue = "ldap://";
         }
-        let saveBtnName = "Create Referral";
+        let saveBtnName = _("Create Referral");
         const extraPrimaryProps = {};
         if (saving) {
-            saveBtnName = "Creating ...";
-            extraPrimaryProps.spinnerAriaValueText = "Creating";
+            saveBtnName = _("Creating ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Creating");
         }
         return (
             <Modal
                 variant={ModalVariant.medium}
-                title="Add Database Referral"
+                title={_("Add Database Referral")}
                 isOpen={showModal}
                 onClose={closeHandler}
                 actions={[
@@ -335,20 +337,20 @@ class AddReferralModal extends React.Component {
                         onClick={saveHandler}
                         isDisabled={saveBtnDisabled || saving}
                         isLoading={saving}
-                        spinnerAriaValueText={saving ? "Saving" : undefined}
+                        spinnerAriaValueText={saving ? _("Saving") : undefined}
                         {...extraPrimaryProps}
                     >
                         {saveBtnName}
                     </Button>,
                     <Button key="cancel" variant="link" onClick={closeHandler}>
-                        Cancel
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form className="ds-margin-top" isHorizontal autoComplete="off">
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Protocol
+                            {_("Protocol")}
                         </GridItem>
                         <GridItem span={9}>
                             <FormSelect id="refProtocol" value={refProtocol} onChange={handleLdapChange} aria-label="FormSelect Input">
@@ -359,7 +361,7 @@ class AddReferralModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Host Name
+                            {_("Host Name")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -376,7 +378,7 @@ class AddReferralModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Port Number
+                            {_("Port Number")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -393,7 +395,7 @@ class AddReferralModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Suffix
+                            {_("Suffix")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -408,9 +410,9 @@ class AddReferralModal extends React.Component {
                             />
                         </GridItem>
                     </Grid>
-                    <Grid title="Comma separated list of attributes to return">
+                    <Grid title={_("Comma separated list of attributes to return")}>
                         <GridItem className="ds-label" span={3}>
-                            Attributes
+                            {_("Attributes")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -426,7 +428,7 @@ class AddReferralModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Filter
+                            {_("Filter")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -442,7 +444,7 @@ class AddReferralModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={3}>
-                            Scope
+                            {_("Scope")}
                         </GridItem>
                         <GridItem span={9}>
                             <FormSelect id="refScope" value={refScope} onChange={handleScopeChange} aria-label="FormSelect Input">
@@ -455,7 +457,7 @@ class AddReferralModal extends React.Component {
                     <hr />
                     <Grid>
                         <GridItem span={3}>
-                            Computed Referral
+                            {_("Computed Referral")}
                         </GridItem>
                         <GridItem span={9}>
                             <b>{previewValue}</b>
