@@ -24,6 +24,8 @@ import {
 } from "@patternfly/react-core";
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 export class VLVIndexes extends React.Component {
     constructor (props) {
         super(props);
@@ -58,10 +60,10 @@ export class VLVIndexes extends React.Component {
         };
 
         // Create VLV Modal
-        this.showVLVModal = this.showVLVModal.bind(this);
+        this.handleShowVLVModal = this.handleShowVLVModal.bind(this);
         this.closeVLVModal = this.closeVLVModal.bind(this);
-        this.handleModalChange = this.handleModalChange.bind(this);
-        this.handleVLVChange = this.handleVLVChange.bind(this);
+        this.onModalChange = this.onModalChange.bind(this);
+        this.onVLVChange = this.onVLVChange.bind(this);
         this.saveVLV = this.saveVLV.bind(this);
         this.deleteVLV = this.deleteVLV.bind(this);
         this.reindexVLV = this.reindexVLV.bind(this);
@@ -70,8 +72,8 @@ export class VLVIndexes extends React.Component {
         this.showReindexConfirm = this.showReindexConfirm.bind(this);
         this.closeReindexConfirm = this.closeReindexConfirm.bind(this);
         // Select typeahead
-        this.onSelectToggle = this.onSelectToggle.bind(this);
-        this.onSelectClear = this.onSelectClear.bind(this);
+        this.handleSelectToggle = this.handleSelectToggle.bind(this);
+        this.handleSelectClear = this.handleSelectClear.bind(this);
         this.deleteSortIndex = this.deleteSortIndex.bind(this);
         this.createSortIndex = this.createSortIndex.bind(this);
         // Sort index
@@ -84,7 +86,7 @@ export class VLVIndexes extends React.Component {
     //
     // VLV index functions
     //
-    showVLVModal() {
+    handleShowVLVModal() {
         this.setState({
             showVLVModal: true,
             errObj: {},
@@ -103,7 +105,7 @@ export class VLVIndexes extends React.Component {
         });
     }
 
-    handleVLVChange(e) {
+    onVLVChange(e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         let valueErr = false;
         const errObj = this.state.errObj;
@@ -112,11 +114,11 @@ export class VLVIndexes extends React.Component {
         const vlvCreateAttrs = ['vlvName', 'vlvBase', 'vlvFilter'];
 
         for (const createAttr of vlvCreateAttrs) {
-            if (attr != createAttr && this.state[createAttr] == "") {
+            if (attr !== createAttr && this.state[createAttr] === "") {
                 saveBtnDisabled = true;
             }
         }
-        if (value == "") {
+        if (value === "") {
             valueErr = true;
             saveBtnDisabled = true;
         }
@@ -124,12 +126,12 @@ export class VLVIndexes extends React.Component {
         errObj[e.target.id] = valueErr;
         this.setState({
             [e.target.id]: value,
-            errObj: errObj,
-            saveBtnDisabled: saveBtnDisabled
+            errObj,
+            saveBtnDisabled
         });
     }
 
-    handleModalChange(e) {
+    onModalChange(e) {
         // Basic handler, no error checking
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
@@ -184,7 +186,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        "Successfully added VLV sort index"
+                        _("Successfully added VLV sort index")
                     );
                     this.setState({
                         updating: false,
@@ -196,7 +198,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Failed to add VLV index entry - ${errMsg.desc}`
+                        cockpit.format(_("Failed to add VLV index entry - $0"), errMsg.desc)
                     );
                     this.setState({
                         updating: false,
@@ -238,7 +240,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        "Successfully removed VLV sort index"
+                        _("Successfully removed VLV sort index")
                     );
                     this.setState({
                         updating: false,
@@ -251,7 +253,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Failed to delete VLV sort index - ${errMsg.desc}`
+                        cockpit.format(_("Failed to delete VLV sort index - $0"), errMsg.desc)
                     );
                     this.setState({
                         updating: false,
@@ -282,7 +284,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        "Successfully added VLV search: " + this.state.vlvName
+                        _("Successfully added VLV search: ") + this.state.vlvName
                     );
                     this.setState({
                         saving: false
@@ -293,7 +295,7 @@ export class VLVIndexes extends React.Component {
                     this.closeVLVModal();
                     this.props.addNotification(
                         "error",
-                        `Failed create VLV search entry - ${errMsg.desc}`
+                        cockpit.format(_("Failed create VLV search entry - $0"), errMsg.desc)
                     );
                     this.setState({
                         saving: false
@@ -329,7 +331,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        `Successfully deleted VLV index`
+                        _("Successfully deleted VLV index")
                     );
                     this.setState({
                         modalSpinning: false
@@ -340,7 +342,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Failed to deletre VLV index - ${errMsg.desc}`
+                        cockpit.format(_("Failed to deletre VLV index - $0"), errMsg.desc)
                     );
                     this.setState({
                         modalSpinning: false
@@ -376,7 +378,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "success",
-                        `Successfully completed VLV indexing`
+                        _("Successfully completed VLV indexing")
                     );
                     this.setState({
                         modalSpinning: false
@@ -387,7 +389,7 @@ export class VLVIndexes extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         "error",
-                        `Failed to index VLV index - ${errMsg.desc}`
+                        cockpit.format(_("Failed to index VLV index - $0"), errMsg.desc)
                     );
                     this.setState({
                         modalSpinning: false
@@ -395,18 +397,18 @@ export class VLVIndexes extends React.Component {
                 });
     }
 
-    onSelectToggle = (isExpanded, toggleId) => {
+    handleSelectToggle = (isExpanded, toggleId) => {
         this.setState({
             [toggleId]: isExpanded
         });
-    }
+    };
 
-    onSelectClear = item => event => {
+    handleSelectClear = item => event => {
         this.setState({
             sortValue: [],
             isVlvSortIndexSelectOpen: false
         });
-    }
+    };
 
     render() {
         return (
@@ -422,18 +424,18 @@ export class VLVIndexes extends React.Component {
                 />
                 <Button
                     variant="primary"
-                    onClick={this.showVLVModal}
+                    onClick={this.handleShowVLVModal}
                 >
-                    Create VLV Index
+                    {_("Create VLV Index")}
                 </Button>
                 <AddVLVIndexModal
                     showModal={this.state.showCreateSortIndex}
-                    closeHandler={this.closeCreateSortIndex}
-                    handleChange={this.handleModalChange}
+                    handleClose={this.closeCreateSortIndex}
+                    handleChange={this.onModalChange}
                     saveHandler={this.createSortIndex}
-                    onSelectToggle={this.onSelectToggle}
-                    onSelectClear={this.onSelectClear}
-                    handleTypeaheadChange={this.handleTypeaheadChange}
+                    onSelectToggle={this.handleSelectToggle}
+                    onSelectClear={this.handleSelectClear}
+                    handleTypeaheadChange={this.onTypeaheadChange}
                     attrs={this.props.attrs}
                     reindexVLV={this.state.reindexVLV}
                     vlvSortList={this.state.vlvSortList}
@@ -443,7 +445,7 @@ export class VLVIndexes extends React.Component {
                 <AddVLVModal
                     showModal={this.state.showVLVModal}
                     closeHandler={this.closeVLVModal}
-                    handleChange={this.handleVLVChange}
+                    handleChange={this.onVLVChange}
                     saveHandler={this.saveVLV}
                     error={this.state.errObj}
                     vlvName={this.state.vlvName}
@@ -456,41 +458,41 @@ export class VLVIndexes extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showDeleteConfirm}
                     closeHandler={this.closeDeleteConfirm}
-                    handleChange={this.handleModalChange}
+                    handleChange={this.onModalChange}
                     actionHandler={this.deleteVLV}
                     spinning={this.state.modalSpinning}
                     item={this.state.deleteVLVName}
                     checked={this.state.modalChecked}
-                    mTitle="Delete VLV Index"
-                    mMsg="Are you sure you want to delete this VLV index??"
-                    mSpinningMsg="Deleting Index ..."
-                    mBtnName="Delete Index"
+                    mTitle={_("Delete VLV Index")}
+                    mMsg={_("Are you sure you want to delete this VLV index??")}
+                    mSpinningMsg={_("Deleting Index ...")}
+                    mBtnName={_("Delete Index")}
                 />
                 <DoubleConfirmModal
                     showModal={this.state.showReindexConfirm}
                     closeHandler={this.closeReindexConfirm}
-                    handleChange={this.handleModalChange}
+                    handleChange={this.onModalChange}
                     actionHandler={this.reindexVLV}
                     spinning={this.state.modalSpinning}
                     item={this.state.reindexVLVName}
                     checked={this.state.modalChecked}
-                    mTitle="Reindex VLV Index"
-                    mMsg="Are you sure you want to reindex this VLV index??"
-                    mSpinningMsg="Reindex ..."
-                    mBtnName="Reindex"
+                    mTitle={_("Reindex VLV Index")}
+                    mMsg={_("Are you sure you want to reindex this VLV index??")}
+                    mSpinningMsg={_("Reindex ...")}
+                    mBtnName={_("Reindex")}
                 />
                 <DoubleConfirmModal
                     showModal={this.state.showDeleteSortIndexConfirm}
                     closeHandler={this.closeDeleteSortIndexConfirm}
-                    handleChange={this.handleModalChange}
+                    handleChange={this.onModalChange}
                     actionHandler={this.deleteSortIndex}
                     spinning={this.state.modalSpinning}
                     item={this.state.deleteIndexName}
                     checked={this.state.modalChecked}
-                    mTitle="Delete VLV Sort Index"
-                    mMsg="Are you really sure you want to delete this sorting index?"
-                    mSpinningMsg="Deleting Index ..."
-                    mBtnName="Delete Index"
+                    mTitle={_("Delete VLV Sort Index")}
+                    mMsg={_("Are you really sure you want to delete this sorting index?")}
+                    mSpinningMsg={_("Deleting Index ...")}
+                    mBtnName={_("Delete Index")}
                 />
             </div>
         );
@@ -508,22 +510,22 @@ class AddVLVIndexModal extends React.Component {
         };
 
         // VLV Sort indexes
-        this.onVLVSortToggle = isVLVSortOpen => {
+        this.handleVLVSortToggle = isVLVSortOpen => {
             this.setState({
                 isVLVSortOpen
             });
         };
-        this.onVLVSortClear = () => {
+        this.handleVLVSortClear = () => {
             this.setState({
                 sortValue: [],
                 isVLVSortOpen: false
             });
         };
 
-        this.handleTypeaheadChange = this.handleTypeaheadChange.bind(this);
+        this.onTypeaheadChange = this.onTypeaheadChange.bind(this);
     }
 
-    handleTypeaheadChange(e, selection) {
+    onTypeaheadChange(e, selection) {
         if (this.state.sortValue.includes(selection)) {
             this.setState(
                 (prevState) => ({
@@ -548,58 +550,58 @@ class AddVLVIndexModal extends React.Component {
             attrs,
             saving,
         } = this.props;
-        let saveBtnName = "Create Sort Index";
+        let saveBtnName = _("Create Sort Index");
         const extraPrimaryProps = {};
         if (this.props.saving) {
-            saveBtnName = "Creating Index ...";
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            saveBtnName = _("Creating Index ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         }
 
         return (
             <Modal
                 variant={ModalVariant.medium}
                 aria-labelledby="ds-modal"
-                title="Create VLV Sort Index"
+                title={_("Create VLV Sort Index")}
                 isOpen={showModal}
-                onClose={this.props.closeHandler}
+                onClose={this.props.handleClose}
                 className={this.state.isVLVSortOpen ? "ds-modal-select-tall" : "ds-modal-select"}
                 actions={[
                     <Button
                         key="confirm"
                         variant="primary"
                         onClick={() => {
-                            this.props.saveHandler(this.state.sortValue);
+                            this.props.handleSave(this.state.sortValue);
                         }}
                         isLoading={saving}
-                        spinnerAriaValueText={saving ? "Saving" : undefined}
+                        spinnerAriaValueText={saving ? _("Saving") : undefined}
                         {...extraPrimaryProps}
-                        isDisabled={this.state.sortValue.length == 0 || saving}
+                        isDisabled={this.state.sortValue.length === 0 || saving}
                     >
                         {saveBtnName}
                     </Button>,
-                    <Button key="cancel" variant="link" onClick={this.props.closeHandler}>
-                        Cancel
+                    <Button key="cancel" variant="link" onClick={this.props.handleClose}>
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form isHorizontal autoComplete="off">
                     <Grid className="ds-margin-top">
                         <GridItem className="ds-label" span={12}>
-                            Build a list of attributes to form the "Sort" index
+                            {_("Build a list of attributes to form the \"Sort\" index")}
                         </GridItem>
                         <Select
                             variant={SelectVariant.typeaheadMulti}
-                            typeAheadAriaLabel="Type an attribute names to create a sort index"
+                            typeAheadAriaLabel={_("Type an attribute names to create a sort index")}
                             className="ds-margin-top-lg"
-                            onToggle={this.onVLVSortToggle}
-                            onClear={this.onVLVSortClear}
+                            onToggle={this.handleVLVSortToggle}
+                            onClear={this.handleVLVSortClear}
                             onSelect={this.handleTypeaheadChange}
                             maxHeight={1000}
                             selections={this.state.sortValue}
                             isOpen={this.state.isVLVSortOpen}
                             aria-labelledby="typeAhead-vlv-sort-index"
-                            placeholderText="Type an attribute name ..."
-                            noResultsFoundText="There are no matching entries"
+                            placeholderText={_("Type an attribute name ...")}
+                            noResultsFoundText={_("There are no matching entries")}
                         >
                             {attrs.map((attr, index) => (
                                 <SelectOption
@@ -615,7 +617,7 @@ class AddVLVIndexModal extends React.Component {
                                 onChange={(checked, e) => {
                                     handleChange(e);
                                 }}
-                                label="Reindex After Saving"
+                                label={_("Reindex After Saving")}
                             />
                         </GridItem>
                     </Grid>
@@ -636,18 +638,18 @@ class AddVLVModal extends React.Component {
             error,
             saving
         } = this.props;
-        let saveBtnName = "Save VLV Index";
+        let saveBtnName = _("Save VLV Index");
         const extraPrimaryProps = {};
         if (saving) {
-            saveBtnName = "Saving Index ...";
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            saveBtnName = _("Saving Index ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         }
 
         return (
             <Modal
                 variant={ModalVariant.medium}
                 aria-labelledby="ds-modal"
-                title="Create VLV Search Index"
+                title={_("Create VLV Search Index")}
                 isOpen={showModal}
                 onClose={closeHandler}
                 actions={[
@@ -656,21 +658,21 @@ class AddVLVModal extends React.Component {
                         variant="primary"
                         onClick={saveHandler}
                         isLoading={saving}
-                        spinnerAriaValueText={saving ? "Saving" : undefined}
+                        spinnerAriaValueText={saving ? _("Saving") : undefined}
                         {...extraPrimaryProps}
                         isDisabled={this.props.saveBtnDisabled || saving}
                     >
                         {saveBtnName}
                     </Button>,
                     <Button key="cancel" variant="link" onClick={closeHandler}>
-                        Cancel
+                        {_("Cancel")}
                     </Button>
                 ]}
             >
                 <Form isHorizontal>
                     <Grid className="ds-margin-top">
                         <GridItem className="ds-label" span={2}>
-                            VLV Index Name
+                            {_("VLV Index Name")}
                         </GridItem>
                         <GridItem span={10}>
                             <TextInput
@@ -688,7 +690,7 @@ class AddVLVModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={2}>
-                            Search Base
+                            {_("Search Base")}
                         </GridItem>
                         <GridItem span={10}>
                             <TextInput
@@ -706,7 +708,7 @@ class AddVLVModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={2}>
-                            Search Filter
+                            {_("Search Filter")}
                         </GridItem>
                         <GridItem span={10}>
                             <TextInput
@@ -724,7 +726,7 @@ class AddVLVModal extends React.Component {
                     </Grid>
                     <Grid>
                         <GridItem className="ds-label" span={2}>
-                            Search Scope
+                            {_("Search Scope")}
                         </GridItem>
                         <GridItem span={10}>
                             <FormSelect
@@ -745,11 +747,7 @@ class AddVLVModal extends React.Component {
                         <GridItem offset={1} className="ds-margin-top-lg ds-margin-bottom" span={10}>
                             <TextContent>
                                 <Text component={TextVariants.h4}>
-                                    After creating this VLV Search entry you can go to
-                                    the table and add VLV Sort Indexes to this VLV
-                                    Search.  After adding the Sort Indexes you will
-                                    need to <i>reindex</i> the VLV Index to make it
-                                    active.
+                                    {_("After creating this VLV Search entry you can go to the table and add VLV Sort Indexes to this VLV Search.  After adding the Sort Indexes you will need to <i>reindex</i> the VLV Index to make it active.")}
                                 </Text>
                             </TextContent>
                         </GridItem>
