@@ -1,3 +1,4 @@
+import cockpit from "cockpit";
 import React from 'react';
 import {
     Alert,
@@ -36,21 +37,23 @@ import {
 import { file_is_path } from "../../tools.jsx";
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 class EditableTable extends React.Component {
     constructor (props) {
         super(props);
 
         this.attributeValidationRules = [
             {
-                name: 'required',
+                name: _("required"),
                 validator: value => value.trim() !== '',
-                errorText: 'This field is required'
+                errorText: _("This field is required")
             }
         ];
 
         this.columns = [
-            { title: 'Attribute' },
-            { title: 'Value', cellTransforms: [breakWord] }
+            { title: _("Attribute") },
+            { title: _("Value"), cellTransforms: [breakWord] }
         ];
 
         this.state = {
@@ -60,7 +63,7 @@ class EditableTable extends React.Component {
             showPassword: false,
             pwdValue: "",
             pwdRowIndex: -1,
-            fileValue: null,
+            fileValue: "",
             fileName: '',
             encodedValueIsEmpty: true,
             strPathValueIsEmpty: true,
@@ -111,7 +114,7 @@ class EditableTable extends React.Component {
             }
         };
 
-        this.showOrHidePassword = () => {
+        this.handleShowOrHidePassword = () => {
             this.setState(({ showPassword }) => ({
                 showPassword: !showPassword
             }));
@@ -126,8 +129,8 @@ class EditableTable extends React.Component {
                 strPathValueIsEmpty,
             });
 
-            let encodedValue = '';
-            let myDecodedValue = `file://${filePath}`;
+            const encodedValue = '';
+            const myDecodedValue = `file://${filePath}`;
 
             const newRows = [...this.state.tableRows];
             newRows[this.state.currentRowIndex].cells[1].props.value = myDecodedValue;
@@ -159,28 +162,31 @@ class EditableTable extends React.Component {
             }
         };
 
-        this.handleFileChange = (fileValue, fileName, event) => {
+        this.handleClear = () => {
+            this.setState({
+                fileName: ""
+            });
+        };
+
+        this.handleFileChange = (e, file) => {
             let encodedValue;
             const encodedValueIsEmpty = true;
             const strPathValueIsEmpty = true;
             const isFileTooLarge = false;
 
             this.setState({
-                fileValue,
-                fileName,
+                fileName: file.name,
                 encodedValueIsEmpty,
                 strPathValueIsEmpty,
                 isFileTooLarge
             });
-            console.log(`fileValue = #${fileValue}#`);
-            console.log(fileValue);
-            console.log(`fileValue.size = ${fileValue.size}`);
+            console.debug('handleFileChange - file: ', file);
 
-            if (fileValue.size === undefined) { // The "Clear" button was pressed.
+            if (file.size === undefined) { // The "Clear" button was pressed.
                 return;
             }
 
-            if (fileValue.size === 0) { // An empty file was selected.
+            if (file.size === 0) { // An empty file was selected.
                 console.log('An empty file was selected. Nothing to do.');
                 return;
             }
@@ -191,8 +197,8 @@ class EditableTable extends React.Component {
             //
             // https://github.com/cockpit-project/cockpit/blob/dee6324d037f3b8961d1b38960b4226c7e473abf/src/websocket/websocketconnection.c#L154
             //
-            if (fileValue.size > WEB_SOCKET_MAX_PAYLOAD) {
-                console.log('File too large!');
+            if (file.size > WEB_SOCKET_MAX_PAYLOAD) {
+                console.log('handleFileChange - File too large!');
                 this.setState({ isFileTooLarge: true });
                 return;
             }
@@ -200,50 +206,59 @@ class EditableTable extends React.Component {
             // data:image/png;base64,
             // base64encode(fileName, val => { console.log(val); })
             // https://stackoverflow.com/questions/36280818/how-to-convert-file-to-base64-in-javascript
+
             const reader = new FileReader();
-            reader.readAsDataURL(fileValue);
+            reader.readAsDataURL(file);
             reader.onload = () => {
                 const pattern = ';base64,';
                 const pos = reader.result.indexOf(pattern);
                 const toDel = reader.result.substring(0, pos + pattern.length);
-                const isAnImage = fileValue.type.startsWith('image/');
+                const isAnImage = file.type.startsWith('image/');
 
                 // Check the file type.
                 encodedValue = this.state.attrIsJpegPhoto
-                ? isAnImage
-                    ? reader.result.replace(toDel, '')
-                    : null
+                    ? isAnImage
+                        ? reader.result.replace(toDel, '')
+                        : ""
                 // The attribute is a certificate.
-                : (fileValue.type === 'application/x-x509-ca-cert') ||
-                (fileValue.type === 'application/x-x509-user-cert')
-                    ? reader.result.replace(toDel, '')
-                    : null;
+                    : (file.type === 'application/x-x509-ca-cert') ||
+                (file.type === 'application/x-x509-user-cert') ||
+                (file.type === 'application/pkix-cert')
+                        ? reader.result.replace(toDel, '')
+                        : "";
 
-                if (encodedValue === null) {
-                    console.log('encodedValue is null. Nothing to do.');
+                if (encodedValue === "") {
+                    console.log('handleFileChange - encodedValue is null. Nothing to do.');
                     return;
                 }
 
                 // Decode the binary value.
-                let myDecodedValue = null;
+                let myDecodedValue = "";
                 if (isAnImage) {
                     if (this.state.attrIsJpegPhoto) {
-                        myDecodedValue = (<img
+                        myDecodedValue = (
+                            <img
                             src={`data:image/png;base64,${encodedValue}`}
                             alt=""
-                            style={{ width: '48px' }} // height will adjust automatically.
-                            />);
-                    } else {
-
+                            style={{ width: '48px' }}
+                            />
+                        );
                     }
                 } else {
                     // TODO ==> Decode the certificate
                     // IMPORTANT! ==> Enable the "Confirm" button once the cert decoding is completed.
                     // myDecodedValue = ...
+                    myDecodedValue = (
+                        <div>
+                            <Label icon={<InfoCircleIcon />} color="blue">
+                                {_("Value is too large to display")}
+                            </Label>
+                        </div>
+                    );
                 }
 
                 // console.log(reader.result.substring(0, 100));
-                console.log(`encodedValue.substring(0, 100) = ${encodedValue.substring(0, 100)}`);
+                console.log(`handleFileChange - encodedValue.substring(0, 100) = ${encodedValue.substring(0, 100)}`);
                 const newRows = [...this.state.tableRows];
                 newRows[this.state.currentRowIndex].cells[1].props.value = myDecodedValue;
                 // Store the encoded value to use it to create the LDIF statements!
@@ -264,7 +279,7 @@ class EditableTable extends React.Component {
                 this.props.saveCurrentRows(rowDataToSave, this.state.namingRowID);
             };
             reader.onerror = (error) => {
-                console.log(`Failed to encode the file : ${fileName}`, error);
+                console.log(`handleFileChange - Failed to encode the file : ${file.name}`, error);
             };
         };
 
@@ -291,7 +306,7 @@ class EditableTable extends React.Component {
         this.props.enableNextStep(foundEmptyValue === undefined);
     }
 
-    handleTextInputChange = (newValue, evt, rowIndex, cellIndex) => {
+    onTextInputChange = (newValue, evt, rowIndex, cellIndex) => {
         const newRows = [...this.state.tableRows];
         newRows[rowIndex].cells[cellIndex].props.editableValue = newValue;
         this.setState({
@@ -299,7 +314,7 @@ class EditableTable extends React.Component {
         });
     };
 
-    updateEditableRows = (evt, type, isEditable, rowIndex, validationErrors) => {
+    handleUpdateEditableRows = (evt, type, isEditable, rowIndex, validationErrors) => {
         // Do not allow to update the DN in the quick update mode.
         // Show a modal dialog to suggest to use the Renaming Wizard.
         if ((this.props.quickUpdate) && (type === 'edit')) {
@@ -330,7 +345,7 @@ class EditableTable extends React.Component {
                 this.setState({
                     isPasswordField: true,
                     pwdRowIndex: rowIndex
-                 });
+                });
                 return;
             } else if (BINARY_ATTRIBUTES.includes(myAttr)) {
                 this.setState({
@@ -364,22 +379,22 @@ class EditableTable extends React.Component {
 
         newRows[rowIndex] = applyCellEdits(newRows[rowIndex], type);
         this.setState({ tableRows: newRows },
-            () => {
-                // Check if there is any empty value.
-                const foundEmptyValue = newRows.find(el => el.cells[1].props.value === '');
-                if (foundEmptyValue === undefined) {
-                    const noEmptyValueCheck = type === 'save'; // Disable the next button on edit ( type='edit' ).
-                    const namingAttrSet = this.state.namingRowID !== -1;
-                    const enableNext = noEmptyValueCheck && namingAttrSet;
-                    this.props.enableNextStep(enableNext);
-                } else {
-                    this.props.enableNextStep(false);
-                }
-                if (type === 'save') {
-                    const rowDataToSave = this.buildRowDataToSave();
-                    this.props.saveCurrentRows(rowDataToSave, this.state.namingRowID);
-                }
-            });
+                      () => {
+                          // Check if there is any empty value.
+                          const foundEmptyValue = newRows.find(el => el.cells[1].props.value === '');
+                          if (foundEmptyValue === undefined) {
+                              const noEmptyValueCheck = type === 'save'; // Disable the next button on edit ( type='edit' ).
+                              const namingAttrSet = this.state.namingRowID !== -1;
+                              const enableNext = noEmptyValueCheck && namingAttrSet;
+                              this.props.enableNextStep(enableNext);
+                          } else {
+                              this.props.enableNextStep(false);
+                          }
+                          if (type === 'save') {
+                              const rowDataToSave = this.buildRowDataToSave();
+                              this.props.saveCurrentRows(rowDataToSave, this.state.namingRowID);
+                          }
+                      });
     };
 
     // Returns an array of row data to store in the parent component.
@@ -393,7 +408,7 @@ class EditableTable extends React.Component {
                 required: datum.required,
                 objectClass: datum.objectClass,
                 rowEditValidationRules: [...datum.rowEditValidationRules],
-            }
+            };
             // Save the encoded (base64) value if it's present.
             if (datum.cells[1].props.encodedvalue) {
                 obj.encodedvalue = datum.cells[1].props.encodedvalue;
@@ -433,17 +448,17 @@ class EditableTable extends React.Component {
                 cells: [
                     {
                         title: (value, rowIndex, cellIndex, props) => (
-                            <React.Fragment>
+                            <>
                                 <EditableTextCell
                                     value={value}
                                     rowIndex={rowIndex}
                                     cellIndex={cellIndex}
                                     props={props}
-                                    handleTextInputChange={this.handleTextInputChange}
+                                    handleTextInputChange={this.onTextInputChange}
                                     isDisabled
                                     inputAriaLabel={attrName}
                                 />
-                            </React.Fragment>
+                            </>
                         ),
                         props: {
                             value: attrName,
@@ -451,20 +466,18 @@ class EditableTable extends React.Component {
                         }
                     },
                     {
-
                         title: (value, rowIndex, cellIndex, props) => (
-                            <React.Fragment>
+                            <>
                                 <EditableTextCell
                                     // isDisabled={myData.isDisabled}
-                                    value={value !== "" ? "********" : ""}
+                                    value={value !== "" ? "********" : <Label color="red" icon={<InfoCircleIcon />}> {_("Empty value!")} </Label>}
                                     rowIndex={rowIndex}
                                     cellIndex={cellIndex}
                                     props={props}
-                                    handleTextInputChange={this.handleTextInputChange}
+                                    handleTextInputChange={this.onTextInputChange}
                                     inputAriaLabel={'_' + value} // To avoid empty property when value is empty.
                                 />
-                                { value === '' && <Label color="red" icon={<InfoCircleIcon />}> Empty value! </Label> }
-                            </React.Fragment>
+                            </>
                         ),
                         props: {
                             value: myData.val,
@@ -483,33 +496,30 @@ class EditableTable extends React.Component {
                 cells: [
                     {
                         title: (value, rowIndex, cellIndex, props) => (
-                            <React.Fragment>
+                            <>
                                 <EditableTextCell
                                     value={value}
                                     rowIndex={rowIndex}
                                     cellIndex={cellIndex}
                                     props={props}
-                                    handleTextInputChange={this.handleTextInputChange}
+                                    handleTextInputChange={this.onTextInputChange}
                                     isDisabled
                                     inputAriaLabel={attrName}
                                 />
                                 {
                                     (attrId === this.state.namingRowID || myData.namingAttr) &&
                                     <Popover
-                                        headerContent={<div>Naming Attribute</div>}
+                                        headerContent={<div>{_("Naming Attribute")}</div>}
                                         bodyContent={
                                             <div>
-                                                This attribute and value are part of
-                                                the entry's DN and can not be changed
-                                                except by doing a Rename (modrdn) operation
-                                                on the entry.
+                                                {_("This attribute and value are part of the entry's DN and can not be changed except by doing a Rename (modrdn) operation on the entry.")}
                                             </div>
                                         }
                                     >
-                                        <a href="#" className="ds-font-size-sm">Naming Attribute</a>
+                                        <a href="#" className="ds-font-size-sm">{_("Naming Attribute")}</a>
                                     </Popover>
                                 }
-                            </React.Fragment>
+                            </>
                         ),
                         props: {
                             value: attrName,
@@ -518,18 +528,17 @@ class EditableTable extends React.Component {
                     },
                     {
                         title: (value, rowIndex, cellIndex, props) => (
-                            <React.Fragment>
+                            <>
                                 <EditableTextCell
                                     // isDisabled={myData.isDisabled}
-                                    value={value}
+                                    value={value === "" ? <Label color="red" icon={<InfoCircleIcon />}> {_("Empty value!")} </Label> : value}
                                     rowIndex={rowIndex}
                                     cellIndex={cellIndex}
                                     props={props}
-                                    handleTextInputChange={this.handleTextInputChange}
+                                    handleTextInputChange={this.onTextInputChange}
                                     inputAriaLabel={'_' + value} // To avoid empty property when value is empty.
                                 />
-                                { value === '' && <Label color="red" icon={<InfoCircleIcon />}> Empty value! </Label> }
-                            </React.Fragment>
+                            </>
                         ),
                         props: {
                             value: myData.val,
@@ -568,7 +577,7 @@ class EditableTable extends React.Component {
             ? []
             : (this.props.namingAttr && myAttr !== this.props.namingAttr) || this.props.namingAttr === ""
                 ? [{
-                    title: 'Set as Naming Attribute',
+                    title: _("Set as Naming Attribute"),
                     onClick: () => {
                         const foundEmptyValue = this.state.tableRows.find(el => el.cells[1].props.value === '');
                         this.props.enableNextStep(foundEmptyValue === undefined);
@@ -577,24 +586,24 @@ class EditableTable extends React.Component {
                             namingRowID: myName,
                             rdnAttr: myAttr
                         },
-                        () => {
-                            this.props.setNamingRowID(myName);
-                        });
+                                      () => {
+                                          this.props.setNamingRowID(myName);
+                                      });
                     }
                 }]
-                : []
+                : [];
 
         const duplicationAction =
             this.props.isAttributeSingleValued(myAttr)
                 ? []
                 : [{
-                    title: 'Add Another Value',
+                    title: _("Add Another Value"),
                     onClick: (event, rowId, rowData) => {
                         const myData = {
                             id: generateUniqueId(),
                             attr: myAttr,
                             val: ''
-                        }
+                        };
                         const tableRows = [...this.state.tableRows];
                         const newItem = this.generateSingleRow(myData);
 
@@ -602,39 +611,39 @@ class EditableTable extends React.Component {
                         tableRows.splice(rowIndex + 1, 0, newItem);
 
                         this.setState({ tableRows },
-                            () => {
-                                const rowDataToSave = this.buildRowDataToSave();
-                                this.props.saveCurrentRows(rowDataToSave, this.state.namingRowID);
-                                // Disable the next step because a duplicated row has no initial value.
-                                this.props.enableNextStep(false);
-                                    });
-                                }
-                    }];
+                                      () => {
+                                          const rowDataToSave = this.buildRowDataToSave();
+                                          this.props.saveCurrentRows(rowDataToSave, this.state.namingRowID);
+                                          // Disable the next step because a duplicated row has no initial value.
+                                          this.props.enableNextStep(false);
+                                      });
+                    }
+                }];
 
         const removalAction = this.state.tableRows.length === 1 || rowData.namingAttr ||
             ((this.props.isAttributeRequired(myAttr) || rowData.required) && this.hasSingleOccurrence(myAttr))
             ? []
             : [
                 {
-                    title: 'Remove this Row',
+                    title: _("Remove this Row"),
                     onClick: (event, rowId) => {
                         const tableRows = this.state.tableRows.filter((aRow) => aRow.cells[0].props.name !== myName);
                         this.setState({ tableRows },
-                            () => {
-                                const rowDataToSave = this.buildRowDataToSave();
-                                const foundEmptyValue = tableRows.find(el => el.cells[1].props.value === '');
-                                this.props.enableNextStep(foundEmptyValue === undefined);
+                                      () => {
+                                          const rowDataToSave = this.buildRowDataToSave();
+                                          const foundEmptyValue = tableRows.find(el => el.cells[1].props.value === '');
+                                          this.props.enableNextStep(foundEmptyValue === undefined);
 
-                                let namingRowID = this.state.namingRowID;
-                                if (rowId === namingRowID) {
-                                    namingRowID = -1;
-                                    this.props.setNamingRowID(-1);
-                                    this.props.enableNextStep(false);
-                                }
+                                          let namingRowID = this.state.namingRowID;
+                                          if (rowId === namingRowID) {
+                                              namingRowID = -1;
+                                              this.props.setNamingRowID(-1);
+                                              this.props.enableNextStep(false);
+                                          }
 
-                                this.setState({ namingRowID });
-                                this.props.saveCurrentRows(rowDataToSave, namingRowID);
-                            });
+                                          this.setState({ namingRowID });
+                                          this.props.saveCurrentRows(rowDataToSave, namingRowID);
+                                      });
                     }
                 }
             ];
@@ -658,7 +667,7 @@ class EditableTable extends React.Component {
                 actions.push(removalAction[0]);
             } else {
                 actions.push({
-                    title: 'Required Attribute',
+                    title: _("Required Attribute"),
                     isDisabled: true
                 });
             }
@@ -673,14 +682,14 @@ class EditableTable extends React.Component {
                 ...removalAction
             ];
         }
-    }
+    };
 
     render () {
         const {
             tableRows,
             isPasswordField, showPassword,
             showFileUri, isDnModalOpen,
-            fileName, fileValue,
+            fileName,
             attrIsJpegPhoto,
             encodedValueIsEmpty,
             strPathValueIsEmpty,
@@ -709,50 +718,51 @@ class EditableTable extends React.Component {
             : `Type File Path ${attrIsJpegPhoto ? '(Photo)' : '(Certificate)'}`;
 
         return (
-            <React.Fragment>
+            <>
                 { isDnModalOpen &&
                     <Modal
                         id="modal-dn-id"
                         variant={ModalVariant.small}
                         titleIconVariant="info"
-                        title="DN Renaming"
+                        title={_("DN Renaming")}
                         isOpen={this.state.isDnModalOpen}
                         onClose={this.handleDnModalToggle}
                         actions={[
                             <Button key="close" variant="primary" onClick={this.handleDnModalToggle}>
-                                Close
+                                {_("Close")}
                             </Button>
                         ]}
                     >
-                        You cannot modify the RDN ( Relative Distinguished Name ) in the <strong>Quick Update</strong> mode.
+                        {_("You cannot modify the RDN ( Relative Distinguished Name ) in the <strong>Quick Update</strong> mode.")}
                         <br />
-                        If you want to modify the RDN, please use the <strong>Rename</strong> action option
-                    </Modal>
-                }
+                        {_("If you want to modify the RDN, please use the <strong>Quick Update</strong> action option")}
+                    </Modal>}
 
                 {isPasswordField &&
                     <Modal
                         id="modal-password-id"
                         variant={ModalVariant.medium}
-                        title="Set Password"
+                        title={_("Set Password")}
                         isOpen={isPasswordField}
                         onClose={this.handlePasswordToggle}
                         actions={[
-                            <Button key="confirm" variant="primary" name="confirm"
+                            <Button
+                                key="confirm" variant="primary" name="confirm"
                                 onClick={this.handlePwdSave}
                             >
-                                Confirm
+                                {_("Confirm")}
                             </Button>,
-                            <Button key="cancel" variant="link"
+                            <Button
+                                key="cancel" variant="link"
                                 onClick={this.handlePasswordToggle}
                             >
-                                Cancel
+                                {_("Cancel")}
                             </Button>
                         ]}
                     >
                         <InputGroup>
                             <TextInput
-                                name="passwordField"
+                                name={_("passwordField")}
                                 id="passwordField"
                                 type={showPassword ? 'text' : 'password'}
                                 onChange={this.handlePwdChange}
@@ -761,12 +771,11 @@ class EditableTable extends React.Component {
                             <Button
                                 variant="control"
                                 aria-label="password field icon"
-                                onClick={this.showOrHidePassword}
+                                onClick={this.handleShowOrHidePassword}
                                 icon={showPassword ? <EyeSlashIcon /> : <EyeIcon />}
                             />
                         </InputGroup>
-                    </Modal>
-                }
+                    </Modal>}
 
                 { showFileUri &&
                     <Modal
@@ -781,10 +790,10 @@ class EditableTable extends React.Component {
                                 isDisabled={encodedValueIsEmpty && strPathValueIsEmpty}
                                 onClick={this.handleToggleUri}
                             >
-                                Confirm
+                                {_("Confirm")}
                             </Button>,
                             <Button key="cancel" variant="link" onClick={this.handleToggleUri}>
-                                Cancel
+                                {_("Cancel")}
                             </Button>
                         ]}
                     >
@@ -793,8 +802,8 @@ class EditableTable extends React.Component {
                             className="ds-margin-top"
                             isChecked={uploadSelected}
                             onChange={this.handleRadioOnChange}
-                            label="Upload a file local to the browser."
-                            description="Select a file from the machine on which the browser was launched."
+                            label={_("Upload a file local to the browser.")}
+                            description={_("Select a file from the machine on which the browser was launched.")}
                             name="radio-binary-attribute"
                             id="radio-upload-binary-attribute"
                         />
@@ -803,8 +812,8 @@ class EditableTable extends React.Component {
                             value="TextInput"
                             isChecked={!uploadSelected}
                             onChange={this.handleRadioOnChange}
-                            label="Write the complete file path."
-                            description="Type the full path of the file on the server host the LDAP server."
+                            label={_("Write the complete file path.")}
+                            description={_("Type the full path of the file on the server host the LDAP server.")}
                             name="radio-binary-attribute"
                             id="radio-type-binary-attribute"
                         />
@@ -812,32 +821,26 @@ class EditableTable extends React.Component {
                         {/* binaryAttrMsg */}
 
                         {((fileName !== '') && encodedValueIsEmpty && strPathValueIsEmpty) &&
-                            <Alert variant="danger" isInline title="There was an issue with the uploaded file ( incorrect type? )." />
-                        }
+                            <Alert variant="danger" isInline title={_("There was an issue with the uploaded file ( incorrect type? ).")} />}
                         {isFileTooLarge &&
-                            <Alert variant="danger" isInline title="The file size larger than 128 MB. Use the file path option." />
-                        }
+                            <Alert variant="danger" isInline title={_("The file size larger than 128 MB. Use the file path option.")} />}
                         {!attrIsJpegPhoto &&
                             <Label className="ds-margin-top-lg" icon={<InfoCircleIcon />} color="blue">
-                                The certificate must be stored in the Distinguished Encoding Rules (DER) format.
-                            </Label>
-                        }
-
+                                {_("The certificate must be stored in the Distinguished Encoding Rules (DER) format.")}
+                            </Label>}
                         { uploadSelected &&
                             <FileUpload
                                 id="file-upload"
+                                type="dataURL"
                                 className="ds-margin-top-lg"
-                                value={fileValue}
                                 filename={fileName}
-                                onChange={this.handleFileChange}
-                                /* dropzoneProps={{
-                                    accept: attrIsJpegPhoto
-                                    ? '.jpg' // [.jpeg,.jpg]
-                                    : '.der'
-                                }} */
-                            />
-                        }
-
+                                value={fileName}
+                                onFileInputChange={this.handleFileChange}
+                                onClearClick={this.handleClear}
+                                validated={uploadSelected && fileName === "" ? 'error' : 'default'}
+                                hideDefaultPreview
+                                browseButtonText={_("Choose Binary File")}
+                            />}
                         { !uploadSelected &&
                             <TextInput
                                 value={binaryAttributeFilePath}
@@ -848,13 +851,11 @@ class EditableTable extends React.Component {
                                     : ValidatedOptions.error}
                                 type="text"
                                 aria-label="File input for a binary attribute."
-                            />
-                        }
-                    </Modal>
-                }
+                            />}
+                    </Modal>}
                 <Table
                     actionResolver={this.actionResolver}
-                    onRowEdit={this.updateEditableRows}
+                    onRowEdit={this.handleUpdateEditableRows}
                     dropdownDirection="up"
                     aria-label="Editable Rows Table"
                     variant={TableVariant.compact}
@@ -865,7 +866,7 @@ class EditableTable extends React.Component {
                     <TableHeader />
                     <TableBody />
                 </Table>
-            </React.Fragment>
+            </>
         );
     }
 }
@@ -877,14 +878,12 @@ EditableTable.propTypes = {
     isAttributeRequired: PropTypes.func,
     enableNextStep: PropTypes.func,
     saveCurrentRows: PropTypes.func,
-    allObjectclasses: PropTypes.array,
     disableNamingChange: PropTypes.bool,
 };
 
 EditableTable.defaultProps = {
     wizardEntryDn: "",
     editableTableData: [],
-    allObjectclasses: [],
     disableNamingChange: false
 };
 
