@@ -1,13 +1,15 @@
+import cockpit from "cockpit";
 import React from 'react';
 import {
     Alert,
     BadgeToggle,
-    Card, CardHeader, CardBody, CardFooter, CardTitle,
+    Card, CardBody, CardTitle,
     Dropdown, DropdownItem, DropdownPosition,
     Form,
     Grid, GridItem,
     Label,
     Pagination,
+    SearchInput,
     Select, SelectOption, SelectVariant,
     SimpleList, SimpleListItem,
     Spinner,
@@ -18,13 +20,8 @@ import {
     InfoCircleIcon,
 } from '@patternfly/react-icons';
 import {
-    EditableTextCell,
-    EditableSelectInputCell,
-    Table, TableHeader, TableBody, TableVariant, headerCol,
-    applyCellEdits,
-    cancelCellEdits,
-    getErrorTextByValidator,
-    validateCellEdits,
+    Table, TableHeader, TableBody, TableVariant,
+    headerCol,
 } from '@patternfly/react-table';
 import EditableTable from '../../lib/editableTable.jsx';
 import {
@@ -36,6 +33,8 @@ import {
     BINARY_ATTRIBUTES
 } from '../../lib/constants.jsx';
 
+const _ = cockpit.gettext;
+
 class AddUser extends React.Component {
     constructor (props) {
         super(props);
@@ -109,7 +108,7 @@ class AddUser extends React.Component {
             ],
             'Posix Account': [
                 'preferredDeliveryMethod', 'displayName', 'employeeNumber',
-                'preferredLanguage', 'userPassword','uidNumber', 'gidNumber',
+                'preferredLanguage', 'userPassword', 'uidNumber', 'gidNumber',
                 'homeDirectory', 'loginShell', 'gecos'
             ],
             'Service Account': [
@@ -119,9 +118,9 @@ class AddUser extends React.Component {
 
         this.attributeValidationRules = [
             {
-                name: 'required',
+                name: _("required"),
                 validator: value => value.trim() !== '',
-                errorText: 'This field is required'
+                errorText: _("This field is required")
             }
         ];
 
@@ -136,26 +135,28 @@ class AddUser extends React.Component {
             savedRows: [],
             commandOutput: '',
             resultVariant: 'default',
+            searchValue: "",
             stepIdReached: 1,
             itemCountAddUser: 0,
             pageAddUser: 1,
             perPageAddUser: 10,
             columnsUser: [
-                { title: 'Attribute Name', cellTransforms: [headerCol()] },
+                { title: _("Attribute Name"), cellTransforms: [headerCol()] },
             ],
             rowsUser: [],
+            rowsOrig: [],
             pagedRowsUser: [],
             selectedAttributes: [],
             isAttrDropDownOpen: false,
             // Values
             noEmptyValue: false,
             columnsValues: [
-                'Attribute',
-                'Value'
+                _("Attribute"),
+                _("Value")
             ],
             // Review step
             reviewValue: '',
-            reviewInvalidText: 'Invalid LDIF',
+            reviewInvalidText: _("Invalid LDIF"),
             reviewIsValid: true,
             reviewValidated: 'default',
             editableTableData: [],
@@ -166,7 +167,7 @@ class AddUser extends React.Component {
             isOpenType: false,
         };
 
-        this.onNext = ({ id }) => {
+        this.handleNext = ({ id }) => {
             this.setState({
                 stepIdReached: this.state.stepIdReached < id ? id : this.state.stepIdReached
             });
@@ -180,48 +181,49 @@ class AddUser extends React.Component {
                 // Create the LDAP entry.
                 const myLdifArray = this.state.ldifArray;
                 createLdapEntry(this.props.editorLdapServer,
-                    myLdifArray,
-                    (result) => {
-                        this.setState({
-                            commandOutput: result.errorCode === 0 ? 'Successfully added user!' : 'Failed to add user, error: ' + result.errorCode ,
-                            resultVariant: result.errorCode === 0 ? 'success' : 'danger',
-                            adding: false,
-                        }, () => {
-                            this.props.onReload();
-                        });
-                        // Update the wizard operation information.
-                        const myDn = myLdifArray[0].substring(4);
-                        const opInfo = {
-                            operationType: 'ADD',
-                            resultCode: result.errorCode,
-                            time: Date.now(),
-                            entryDn: myDn,
-                            relativeDn: this.state.namingAttrVal
-                        }
-                        this.props.setWizardOperationInfo(opInfo);
-                    }
+                                myLdifArray,
+                                (result) => {
+                                    this.setState({
+                                        commandOutput: result.errorCode === 0 ? _("Successfully added user!") : _("Failed to add user, error: ") + result.errorCode,
+                                        resultVariant: result.errorCode === 0 ? 'success' : 'danger',
+                                        adding: false,
+                                    }, () => {
+                                        this.props.onReload();
+                                    });
+                                    // Update the wizard operation information.
+                                    const myDn = myLdifArray[0].substring(4);
+                                    const opInfo = {
+                                        operationType: 'ADD',
+                                        resultCode: result.errorCode,
+                                        time: Date.now(),
+                                        entryDn: myDn,
+                                        relativeDn: this.state.namingAttrVal
+                                    };
+                                    this.props.setWizardOperationInfo(opInfo);
+                                }
                 );
             }
         };
 
-        this.onBack = ({ id }) => {
+        this.handleBack = ({ id }) => {
             if (id === 4) {
                 // true ==> Do not check the attribute selection when navigating back.
                 this.updateValuesTableRows(true);
             }
         };
 
-        this.onToggleType = isOpenType => {
+        this.handleToggleType = isOpenType => {
             this.setState({
                 isOpenType
             });
-        }
-        this.onSelectType = (event, selection) => {
-            let attributesArray = [];
+        };
+        this.handleSelectType = (event, selection) => {
+            const attributesArray = [];
             let selectedAttrs = [];
 
             this.allowedAttrs[selection].map(attr => {
                 attributesArray.push({ cells: [attr] });
+                return [];
             });
             this.requiredAttrs[selection].map(attr => {
                 attributesArray.push({
@@ -230,6 +232,7 @@ class AddUser extends React.Component {
                     isAttributeSelected: true,
                     disableCheckbox: true
                 });
+                return [];
             });
             selectedAttrs = [...this.requiredAttrs[selection]];
 
@@ -239,12 +242,41 @@ class AddUser extends React.Component {
             this.setState({
                 itemCountAddUser: attributesArray.length,
                 rowsUser: attributesArray,
+                rowsOrig: [...attributesArray],
                 pagedRowsUser: attributesArray.slice(0, this.state.perPageAddUser),
                 accountType: selection,
                 selectedAttributes: selectedAttrs,
                 isOpenType: false,
             });
-        }
+        };
+
+        this.handleAttrSearchChange = (value) => {
+            let attrRows = [];
+            let allAttrs = [];
+            const val = value.toLowerCase();
+
+            allAttrs = this.state.rowsOrig;
+
+            // Process search filter on the entire list
+            if (val !== "") {
+                for (const row of allAttrs) {
+                    const name = row.cells[0].toLowerCase();
+                    if (name.includes(val)) {
+                        attrRows.push(row);
+                    }
+                }
+            } else {
+                // Restore entire row list
+                attrRows = allAttrs;
+            }
+
+            this.setState({
+                rowsUser: attrRows,
+                pagedRowsUser: attrRows.slice(0, this.state.perPageAttr),
+                itemCountAddUser: attrRows.length,
+                searchValue: value
+            });
+        };
 
         // End constructor().
     }
@@ -254,6 +286,7 @@ class AddUser extends React.Component {
         // Set the default poisx user attributes
         this.allowedAttrs[this.state.accountType].map(attr => {
             attributesArray.push({ cells: [attr] });
+            return [];
         });
         this.requiredAttrs[this.state.accountType].map(attr => {
             attributesArray.push({
@@ -262,6 +295,7 @@ class AddUser extends React.Component {
                 isAttributeSelected: true,
                 disableCheckbox: true
             });
+            return [];
         });
 
         // Sort the attributes
@@ -270,19 +304,20 @@ class AddUser extends React.Component {
         this.setState({
             itemCountAddUser: attributesArray.length,
             rowsUser: attributesArray,
+            rowsOrig: [...attributesArray],
             pagedRowsUser: attributesArray.slice(0, this.state.perPageAddUser),
             selectedAttributes: [...this.requiredAttrs[this.state.accountType]],
         });
     }
 
-    onSetPageAddUser = (_event, pageNumber) => {
+    handleSetPageAddUser = (_event, pageNumber) => {
         this.setState({
             pageAddUser: pageNumber,
             pagedRowsUser: this.getAttributesToShow(pageNumber, this.state.perPageAddUser)
         });
     };
 
-    onPerPageSelectAddUser = (_event, perPage) => {
+    handlePerPageSelectAddUser = (_event, perPage) => {
         this.setState({
             pageAddUser: 1,
             perPageAddUser: perPage,
@@ -303,42 +338,41 @@ class AddUser extends React.Component {
 
     isAttributeRequired = attr => {
         return this.requiredAttrs[this.state.accountType].includes(attr);
-    }
-
-    onSelect = (event, isSelected, rowId) => {
-        let rows;
+    };
 
+    handleSelect = (event, isSelected, rowId) => {
         // Quick hack until the code is upgraded to a version that supports "disableCheckbox"
         if (this.state.pagedRowsUser[rowId].disableCheckbox === true) {
             return;
         } // End hack.
 
         // Process only the entries in the current page ( pagedRowsUser )
-        rows = [...this.state.pagedRowsUser];
+        const rows = [...this.state.pagedRowsUser];
         rows[rowId].selected = isSelected;
         // Find the entry in the full array and set 'isAttributeSelected' accordingly
         // The property 'isAttributeSelected' is used to build the LDAP entry to add.
         // The row ID cannot be used since it changes with the pagination.
-        const attrName = this.state.pagedRowsUser[rowId].cells[0];
+        const attrName = rows[rowId].cells[0];
         const allItems = [...this.state.rowsUser];
+        const allAttrs = this.state.rowsOrig;
         const index = allItems.findIndex(item => item.cells[0] === attrName);
         allItems[index].isAttributeSelected = isSelected;
-        const selectedAttributes = allItems
-            .filter(item => item.isAttributeSelected)
-            .map(selectedAttr => selectedAttr.cells[0]);
+        const selectedAttributes = allAttrs
+                .filter(item => item.isAttributeSelected)
+                .map(selectedAttr => selectedAttr.cells[0]);
 
         this.setState({
             rowsUser: allItems,
             pagedRowsUser: rows,
             selectedAttributes
         },
-        () => this.updateValuesTableRows());
+                      () => this.updateValuesTableRows());
     };
 
     updateValuesTableRows = (skipAttributeSelection) => {
         const newSelectedAttrs = [...this.state.selectedAttributes];
         let namingRowID = this.state.namingRowID;
-        let namingAttrVal = this.state.namingAttrVal
+        let namingAttrVal = this.state.namingAttrVal;
         let editableTableData = [];
         let namingAttr = this.state.namingAttr;
         let namingVal = this.state.namingVal;
@@ -351,11 +385,11 @@ class AddUser extends React.Component {
                     val: '',
                     required: false,
                     namingAttr: false,
-                }
+                };
                 return obj;
             });
             editableTableData.sort((a, b) => (a.attr > b.attr) ? 1 : -1);
-            namingRowID = editableTableData[0].id,
+            namingRowID = editableTableData[0].id;
             namingAttrVal = editableTableData[0].attr + "=" + editableTableData[0].val;
             namingAttr = editableTableData[0].attr;
             namingVal = editableTableData[0].val;
@@ -379,16 +413,16 @@ class AddUser extends React.Component {
                 }
                 // Remove the newly unselected attribute(s).
                 editableTableData = arrayOfAttrObjects
-                    .filter(datum => {
-                        const attrName = datum.attr;
-                        const found = newSelectedAttrs.find(attr => attr === attrName);
-                        return (found !== undefined);
-                    });
+                        .filter(datum => {
+                            const attrName = datum.attr;
+                            const found = newSelectedAttrs.find(attr => attr === attrName);
+                            return (found !== undefined);
+                        });
 
                 // Sort the rows
                 editableTableData.sort((a, b) => (a.attr > b.attr) ? 1 : -1);
                 if (this.state.namingRowID === -1) {
-                    namingRowID = editableTableData[0].id
+                    namingRowID = editableTableData[0].id;
                 }
             }
         }
@@ -415,7 +449,7 @@ class AddUser extends React.Component {
         let rows = this.state.savedRows;
 
         if (rows.length === 0) {
-            rows = this.state.editableTableData
+            rows = this.state.editableTableData;
         }
         for (const row of rows) {
             if (row.id === namingRowID) {
@@ -434,13 +468,13 @@ class AddUser extends React.Component {
         });
     };
 
-    onAttrDropDownToggle = isOpen => {
+    handleAttrDropDownToggle = isOpen => {
         this.setState({
             isAttrDropDownOpen: isOpen
         });
     };
 
-    onAttrDropDownSelect = event => {
+    handleAttrDropDownSelect = event => {
         this.setState((prevState, props) => {
             return { isAttrDropDownOpen: !prevState.isAttrDropDownOpen };
         });
@@ -456,34 +490,35 @@ class AddUser extends React.Component {
         return (
             <Dropdown
                 className="ds-dropdown-padding"
-                onSelect={this.onAttrDropDownSelect}
+                onSelect={this.handleAttrDropDownSelect}
                 position={DropdownPosition.left}
                 toggle={
-                    <BadgeToggle id="toggle-attr-select" onToggle={this.onAttrDropDownToggle}>
-                        {numSelected !== 0 ? <>{numSelected} selected </> : <>0 selected </>}
+                    <BadgeToggle id="toggle-attr-select" onToggle={this.handleAttrDropDownToggle}>
+                        {numSelected !== 0 ? <>{numSelected} {_("selected")} </> : <>0 {_("selected")} </>}
                     </BadgeToggle>
                 }
                 isOpen={isAttrDropDownOpen}
                 dropdownItems={items}
             />
         );
-    }
+    };
 
     saveCurrentRows = (savedRows, namingID) => {
-        this.setState({ savedRows },
-            () => {
-                // Update the naming information after the new rows have been saved.
-                if (namingID != -1) { // The namingIndex is set to -1 if the row is not the naming one.
-                    this.setNamingRowID(namingID);
-                }
-            });
-    }
+        this.setState({
+            savedRows
+        }, () => {
+            // Update the naming information after the new rows have been saved.
+            if (namingID !== -1) { // The namingIndex is set to -1 if the row is not the naming one.
+                this.setNamingRowID(namingID);
+            }
+        });
+    };
 
     generateLdifData = () => {
         const ldifArray = [];
         let isFilePath = false;
-        let objectClassData = this.userObjectclasses[this.state.accountType];
-        let cleanLdifArray = [];
+        const objectClassData = this.userObjectclasses[this.state.accountType];
+        const cleanLdifArray = [];
 
         ldifArray.push(`dn: ${this.state.namingAttrVal},${this.props.wizardEntryDn}`);
         ldifArray.push(...objectClassData);
@@ -507,12 +542,14 @@ class AddUser extends React.Component {
             if (attrName.toLowerCase().startsWith("userpassword")) {
                 cleanLdifArray.push("userpassword: ********");
             } else if (attrName.toLowerCase().startsWith("jpegphoto") && mySeparator === '::') {
-                const myTruncatedValue = (<div>
-                                              {"jpegphoto:: "}
-                                              <Label icon={<InfoCircleIcon />} color="blue" >
-                                                  Value is too large to display
-                                              </Label>
-                                          </div>);
+                const myTruncatedValue = (
+                    <div>
+                        {"jpegphoto:: "}
+                        <Label icon={<InfoCircleIcon />} color="blue">
+                            {_("Value is too large to display")}
+                        </Label>
+                    </div>
+                );
                 cleanLdifArray.push(myTruncatedValue);
             } else {
                 cleanLdifArray.push(...remainingData);
@@ -520,39 +557,37 @@ class AddUser extends React.Component {
         }
 
         this.setState({ ldifArray, cleanLdifArray });
-    }
+    };
 
     render () {
         const {
-            commandOutput,
-            itemCountAddUser, pageAddUser, perPageAddUser, columnsUser, pagedRowsUser,
-            ldifArray, cleanLdifArray, columnsValues, noEmptyValue, alertVariant,
-            namingAttrVal, namingAttr, namingVal, resultVariant, editableTableData,
-            stepIdReached
+            commandOutput, itemCountAddUser, pageAddUser, perPageAddUser,
+            columnsUser, pagedRowsUser, ldifArray, cleanLdifArray, noEmptyValue,
+            namingAttrVal, namingAttr, namingVal, resultVariant,
+            editableTableData, stepIdReached
         } = this.state;
 
         const rdnValue = namingVal;
         const myTitle = (namingAttrVal === '' || rdnValue === '')
-            ? 'Invalid Naming Attribute - Empty Value!'
-            : 'DN ( Distinguished Name )';
+            ? _("Invalid Naming Attribute - Empty Value!")
+            : _("DN ( Distinguished Name )");
 
         const userSelectStep = (
             <>
                 <div className="ds-container">
                     <TextContent>
                         <Text component={TextVariants.h3}>
-                            Select Entry Type
+                            {_("Select Entry Type")}
                         </Text>
                     </TextContent>
-
                 </div>
                 <div className="ds-indent">
                     <Select
                         variant={SelectVariant.single}
                         className="ds-margin-top-lg"
                         aria-label="Select user type"
-                        onToggle={this.onToggleType}
-                        onSelect={this.onSelectType}
+                        onToggle={this.handleToggleType}
+                        onSelect={this.handleSelectType}
                         selections={this.state.accountType}
                         isOpen={this.state.isOpenType}
                     >
@@ -562,21 +597,14 @@ class AddUser extends React.Component {
                     </Select>
                     <TextContent className="ds-margin-top-xlg">
                         <Text component={TextVariants.h6} className="ds-margin-top-lg ds-font-size-md">
-                            <b>Basic Account</b> - This type of user entry uses a
-                            common set of objectclasses (nsPerson, nsAccount, and nsOrgPerson).
+                            <b>{_("Basic Account")}</b>{_(" - This type of user entry uses a common set of objectclasses (nsPerson, nsAccount, and nsOrgPerson).")}
                         </Text>
                         <Text component={TextVariants.h6} className="ds-margin-top-lg ds-font-size-md">
-                            <b>Posix Account</b> - This type of user entry uses a
-                            similar set of objectclasses as the <i>Basic Account</i> (nsPerson,
-                            nsAccount, nsOrgPerson, and posixAccount), but it includes
-                            POSIX attributes like: <i>uidNumber, gidNumber, homeDirectory,
-                            loginShell, and gecos</i>.
+                            <b>{_("Posix Account")}</b>{_(" - This type of user entry uses a similar set of objectclasses as the ")}<i>{_("Basic Account")}</i> {_("(nsPerson, nsAccount, nsOrgPerson, and posixAccount), but it includes POSIX attributes like:")}
+                            <i>{_("uidNumber, gidNumber, homeDirectory, loginShell, and gecos")}</i>.
                         </Text>
                         <Text component={TextVariants.h6} className="ds-margin-top-lg ds-font-size-md">
-                            <b>Service Account</b> - This type of entry uses a
-                            bare minimum of objectclasses (nsAccount, and applicationProcess) and
-                            attributes to create a simple object used to represent a service
-                            (not a user identity).
+                            <b>{_("Service Account")}</b>{_(" - This type of entry uses a bare minimum of objectclasses (nsAccount, and applicationProcess) and attributes to create a simple object used to represent a service (not a user identity).")}
                         </Text>
                     </TextContent>
                 </div>
@@ -588,24 +616,37 @@ class AddUser extends React.Component {
                 <div className="ds-container">
                     <TextContent>
                         <Text component={TextVariants.h3}>
-                            Select Entry Attributes
+                            {_("Select Entry Attributes")}
                         </Text>
                     </TextContent>
                     {this.buildAttrDropdown()}
                 </div>
-                <Pagination
-                    itemCount={itemCountAddUser}
-                    page={pageAddUser}
-                    perPage={perPageAddUser}
-                    onSetPage={this.onSetPageAddUser}
-                    widgetId="pagination-options-menu-add-user"
-                    onPerPageSelect={this.onPerPageSelectAddUser}
-                    isCompact
-                />
+                <Grid className="ds-margin-top-lg">
+                    <GridItem span={5}>
+                        <SearchInput
+                            className="ds-font-size-md"
+                            placeholder={_("Search Attributes")}
+                            value={this.state.searchValue}
+                            onChange={(evt, val) => this.handleAttrSearchChange(val)}
+                            onClear={() => this.handleAttrSearchChange('')}
+                        />
+                    </GridItem>
+                    <GridItem span={7}>
+                        <Pagination
+                            itemCount={itemCountAddUser}
+                            page={pageAddUser}
+                            perPage={perPageAddUser}
+                            onSetPage={this.handleSetPageAddUser}
+                            widgetId="pagination-options-menu-add-user"
+                            onPerPageSelect={this.handlePerPageSelectAddUser}
+                            isCompact
+                        />
+                    </GridItem>
+                </Grid>
                 <Table
                     cells={columnsUser}
                     rows={pagedRowsUser}
-                    onSelect={this.onSelect}
+                    onSelect={this.handleSelect}
                     variant={TableVariant.compact}
                     aria-label="Pagination User Attributes"
                     canSelectAll={false}
@@ -617,24 +658,24 @@ class AddUser extends React.Component {
         );
 
         const userValuesStep = (
-            <React.Fragment>
+            <>
                 <Form autoComplete="off">
                     <Grid>
                         <GridItem className="ds-margin-top" span={12}>
                             <Alert
                                 variant={namingAttr === '' || namingVal === ''
-                                    ? 'warning'
-                                    : 'success'}
+                                    ? "warning"
+                                    : "success"}
                                 isInline
                                 title={myTitle}
                             >
-                                <b>Entry DN:&nbsp;&nbsp;&nbsp;</b>{(namingAttr ? namingAttr : "??????")}={namingVal ? namingVal : "??????"},{this.props.wizardEntryDn}
+                                <b>{_("Entry DN:")}&nbsp;&nbsp;&nbsp;</b>{(namingAttr || "??????")}={namingVal || "??????"},{this.props.wizardEntryDn}
                             </Alert>
                         </GridItem>
                         <GridItem span={12} className="ds-margin-top-xlg">
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    Set Attribute Values
+                                    {_("Set Attribute Values")}
                                 </Text>
                             </TextContent>
                         </GridItem>
@@ -653,7 +694,7 @@ class AddUser extends React.Component {
                         namingAttr={this.state.namingAttr}
                     />
                 </GridItem>
-            </React.Fragment>
+            </>
         );
 
         const ldifListItems = cleanLdifArray.map((line, index) =>
@@ -667,15 +708,14 @@ class AddUser extends React.Component {
                 <Alert
                     variant="info"
                     isInline
-                    title="LDIF Content for User Creation"
+                    title={_("LDIF Content for User Creation")}
                 />
                 <Card isSelectable>
                     <CardBody>
                         { (ldifListItems.length > 0) &&
                             <SimpleList aria-label="LDIF data User">
                                 {ldifListItems}
-                            </SimpleList>
-                        }
+                            </SimpleList>}
                     </CardBody>
                 </Card>
             </div>
@@ -685,34 +725,32 @@ class AddUser extends React.Component {
         const ldifLines = ldifArray.map(line => {
             nb++;
             return { data: line, id: nb };
-        })
+        });
         const userReviewStep = (
             <div>
                 <Alert
                     variant={resultVariant}
                     isInline
-                    title="Result for User Creation"
+                    title={_("Result for User Creation")}
                 >
                     {commandOutput}
                     {this.state.adding &&
                         <div>
                             <Spinner className="ds-left-margin" size="md" />
-                            &nbsp;&nbsp;Adding user ...
-                        </div>
-                    }
+                            &nbsp;&nbsp;{_("Adding user ...")}
+                        </div>}
                 </Alert>
                 {resultVariant === 'danger' &&
                     <Card isSelectable>
                         <CardTitle>
-                            LDIF Data
+                            {_("LDIF Data")}
                         </CardTitle>
                         <CardBody>
                             {ldifLines.map((line) => (
                                 <h6 key={line.id}>{line.data}</h6>
                             ))}
                         </CardBody>
-                    </Card>
-                }
+                    </Card>}
             </div>
         );
 
@@ -726,52 +764,54 @@ class AddUser extends React.Component {
             },
             {
                 id: 2,
-                name: 'Choose User Type',
+                name: _("Choose User Type"),
                 component: userSelectStep,
                 canJumpTo: stepIdReached >= 2 && stepIdReached < 6
             },
             {
                 id: 3,
-                name: 'Select Attributes',
+                name: _("Select Attributes"),
                 component: userAttributesStep,
                 canJumpTo: stepIdReached >= 3 && stepIdReached < 6
             },
             {
                 id: 4,
-                name: 'Set Values',
+                name: _("Set Values"),
                 component: userValuesStep,
                 canJumpTo: stepIdReached >= 4 && stepIdReached < 6,
                 enableNext: noEmptyValue
             },
             {
                 id: 5,
-                name: 'Create User',
+                name: _("Create User"),
                 component: userCreationStep,
-                nextButtonText: 'Create User',
+                nextButtonText: _("Create User"),
                 canJumpTo: stepIdReached >= 5 && stepIdReached < 6
             },
             {
                 id: 6,
-                name: 'Review Result',
+                name: _("Review Result"),
                 component: userReviewStep,
-                nextButtonText: 'Finish',
+                nextButtonText: _("Finish"),
                 canJumpTo: stepIdReached >= 6,
                 hideBackButton: true,
                 enableNext: !this.state.adding
             }
         ];
 
-        const title = <>
-            Parent DN: &nbsp;&nbsp;<strong>{this.props.wizardEntryDn}</strong>
-        </>;
+        const title = (
+            <>
+                {_("Parent DN: ")}&nbsp;&nbsp;<strong>{this.props.wizardEntryDn}</strong>
+            </>
+        );
 
         return (
             <Wizard
                 isOpen={this.props.isWizardOpen}
-                onClose={this.props.toggleOpenWizard}
-                onNext={this.onNext}
-                onBack={this.onBack}
-                title="Add A User"
+                onClose={this.props.handleToggleWizard}
+                onNext={this.handleNext}
+                onBack={this.handleBack}
+                title={_("Add A User")}
                 description={title}
                 steps={addUserSteps}
             />
