@@ -23,6 +23,8 @@ import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import PropTypes from "prop-types";
 import { log_cmd, valid_dn, listsEqual } from "../tools.jsx";
 
+const _ = cockpit.gettext;
+
 class AttributeUniqueness extends React.Component {
     componentDidMount() {
         if (this.props.wasActiveList.includes(5)) {
@@ -69,13 +71,13 @@ class AttributeUniqueness extends React.Component {
         };
 
         this.handleSwitchChange = this.handleSwitchChange.bind(this);
-        this.handleChange = this.handleChange.bind(this);
+        this.onChange = this.onChange.bind(this);
         this.handleFieldChange = this.handleFieldChange.bind(this);
         this.handleTypeaheadChange = this.handleTypeaheadChange.bind(this);
         this.loadConfigs = this.loadConfigs.bind(this);
         this.showEditConfigModal = this.showEditConfigModal.bind(this);
-        this.showAddConfigModal = this.showAddConfigModal.bind(this);
-        this.closeModal = this.closeModal.bind(this);
+        this.handleShowAddConfigModal = this.handleShowAddConfigModal.bind(this);
+        this.handleCloseModal = this.handleCloseModal.bind(this);
         this.openModal = this.openModal.bind(this);
         this.cmdOperation = this.cmdOperation.bind(this);
         this.closeConfirmDelete = this.closeConfirmDelete.bind(this);
@@ -86,7 +88,7 @@ class AttributeUniqueness extends React.Component {
         this.validateConfig = this.validateConfig.bind(this);
 
         // Attribute Name
-        this.onAttributeNameSelect = (event, selection) => {
+        this.handleAttributeNameSelect = (event, selection) => {
             if (this.state.attrNames.includes(selection)) {
                 this.setState(
                     (prevState) => ({
@@ -103,12 +105,12 @@ class AttributeUniqueness extends React.Component {
                 );
             }
         };
-        this.onAttributeNameToggle = isAttributeNameOpen => {
+        this.handleAttributeNameToggle = isAttributeNameOpen => {
             this.setState({
                 isAttributeNameOpen
             }, () => { this.validateConfig() });
         };
-        this.onAttributeNameClear = () => {
+        this.handleAttributeNameClear = () => {
             this.setState({
                 attrNames: [],
                 isAttributeNameOpen: false
@@ -116,7 +118,7 @@ class AttributeUniqueness extends React.Component {
         };
 
         // Subtrees
-        this.onSubtreesSelect = (event, selection) => {
+        this.handleSubtreesSelect = (event, selection) => {
             if (this.state.subtrees.includes(selection)) {
                 this.setState(
                     (prevState) => ({
@@ -133,18 +135,18 @@ class AttributeUniqueness extends React.Component {
                 );
             }
         };
-        this.onSubtreesToggle = isSubtreesOpen => {
+        this.handleSubtreesToggle = isSubtreesOpen => {
             this.setState({
                 isSubtreesOpen
             }, () => { this.validateConfig() });
         };
-        this.onSubtreesClear = () => {
+        this.handleSubtreesClear = () => {
             this.setState({
                 subtrees: [],
                 isSubtreesOpen: false
             }, () => { this.validateConfig() });
         };
-        this.onSubtreesCreateOption = newValue => {
+        this.handleSubtreesCreateOption = newValue => {
             if (!this.state.subtreesOptions.includes(newValue)) {
                 this.setState({
                     subtreesOptions: [...this.state.subtreesOptions, newValue],
@@ -160,7 +162,7 @@ class AttributeUniqueness extends React.Component {
 
         // Must have a subtree and attribute set
         for (const attrList of ['attrNames', 'subtrees']) {
-            if (this.state[attrList].length == 0) {
+            if (this.state[attrList].length === 0) {
                 errObj[attrList] = true;
                 all_good = false;
             }
@@ -175,7 +177,7 @@ class AttributeUniqueness extends React.Component {
             }
         }
 
-        if (this.state.configName == "") {
+        if (this.state.configName === "") {
             errObj.configName = true;
             all_good = false;
         }
@@ -197,7 +199,7 @@ class AttributeUniqueness extends React.Component {
                 'configEnabled'
             ];
             for (const check_attr of configAttrs) {
-                if (this.state[check_attr] != this.state['_' + check_attr]) {
+                if (this.state[check_attr] !== this.state['_' + check_attr]) {
                     all_good = true;
                     break;
                 }
@@ -215,7 +217,7 @@ class AttributeUniqueness extends React.Component {
         }, () => { this.validateConfig() });
     }
 
-    handleChange(e) {
+    onChange(e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
             [e.target.id]: value
@@ -234,7 +236,7 @@ class AttributeUniqueness extends React.Component {
         // instead of string.  Grab the "label" in this case
         const new_values = [];
         for (let val of values) {
-            if (val != "") {
+            if (val !== "") {
                 if (typeof val === 'object') {
                     val = val.label;
                 }
@@ -268,11 +270,11 @@ class AttributeUniqueness extends React.Component {
                     const tableKey = this.state.tableKey + 1;
                     this.setState({
                         configRows: myObject.items.map(item => item.attrs),
-                        tableKey: tableKey
+                        tableKey
                     });
                 })
                 .fail(err => {
-                    if (err != 0) {
+                    if (err !== 0) {
                         const errMsg = JSON.parse(err);
                         console.log("loadConfigs failed", errMsg.desc);
                     }
@@ -283,7 +285,7 @@ class AttributeUniqueness extends React.Component {
         this.openModal(name);
     }
 
-    showAddConfigModal(rowData) {
+    handleShowAddConfigModal(rowData) {
         this.openModal();
     }
 
@@ -327,11 +329,11 @@ class AttributeUniqueness extends React.Component {
                             configName: configEntry.cn === undefined ? "" : configEntry.cn[0],
                             configEnabled: !(
                                 configEntry["nsslapd-pluginenabled"] === undefined ||
-                            configEntry["nsslapd-pluginenabled"][0] == "off"
+                            configEntry["nsslapd-pluginenabled"][0] === "off"
                             ),
                             acrossAllSubtrees: !(
                                 configEntry["uniqueness-across-all-subtrees"] === undefined ||
-                            configEntry["uniqueness-across-all-subtrees"][0] == "off"
+                            configEntry["uniqueness-across-all-subtrees"][0] === "off"
                             ),
                             topEntryOc:
                             configEntry["uniqueness-top-entry-oc"] === undefined
@@ -344,11 +346,11 @@ class AttributeUniqueness extends React.Component {
 
                             _configEnabled: !(
                                 configEntry["nsslapd-pluginenabled"] === undefined ||
-                            configEntry["nsslapd-pluginenabled"][0] == "off"
+                            configEntry["nsslapd-pluginenabled"][0] === "off"
                             ),
                             _acrossAllSubtrees: !(
                                 configEntry["uniqueness-across-all-subtrees"] === undefined ||
-                            configEntry["uniqueness-across-all-subtrees"][0] == "off"
+                            configEntry["uniqueness-across-all-subtrees"][0] === "off"
                             ),
                             _topEntryOc:
                             configEntry["uniqueness-top-entry-oc"] === undefined
@@ -393,7 +395,7 @@ class AttributeUniqueness extends React.Component {
         }
     }
 
-    closeModal() {
+    handleCloseModal() {
         this.setState({ configEntryModalShow: false });
     }
 
@@ -422,11 +424,11 @@ class AttributeUniqueness extends React.Component {
             acrossAllSubtrees ? "on" : "off"
         ];
 
-        if (subtrees.length == 0 && subtreeEnriesOc.length == 0) {
+        if (subtrees.length === 0 && subtreeEnriesOc.length === 0) {
             // There mustr a subtree or entry OC sets
             this.props.addNotification(
                 "error",
-                `There must be at least one Subtree or Subtree Entries OC set`
+                _("There must be at least one Subtree or Subtree Entries OC set")
             );
             return;
         }
@@ -436,26 +438,26 @@ class AttributeUniqueness extends React.Component {
         });
 
         // Delete attributes if the user set an empty value to the field
-        if (!(action == "add" && attrNames.length == 0)) {
+        if (!(action === "add" && attrNames.length === 0)) {
             cmd = [...cmd, "--attr-name"];
-            if (attrNames.length != 0) {
+            if (attrNames.length !== 0) {
                 for (const value of attrNames) {
                     cmd = [...cmd, value];
                 }
-            } else if (action == "add") {
+            } else if (action === "add") {
                 cmd = [...cmd, ""];
             } else {
                 cmd = [...cmd, "delete"];
             }
         }
 
-        if (!(action == "add" && subtrees.length == 0)) {
+        if (!(action === "add" && subtrees.length === 0)) {
             cmd = [...cmd, "--subtree"];
-            if (subtrees.length != 0) {
+            if (subtrees.length !== 0) {
                 for (const value of subtrees) {
                     cmd = [...cmd, value];
                 }
-            } else if (action == "add") {
+            } else if (action === "add") {
                 cmd = [...cmd, ""];
             } else {
                 cmd = [...cmd, "delete"];
@@ -463,18 +465,18 @@ class AttributeUniqueness extends React.Component {
         }
 
         cmd = [...cmd, "--top-entry-oc"];
-        if (topEntryOc.length != 0) {
+        if (topEntryOc.length !== 0) {
             cmd = [...cmd, topEntryOc];
-        } else if (action == "add") {
+        } else if (action === "add") {
             cmd = [...cmd, ""];
         } else {
             cmd = [...cmd, "delete"];
         }
 
         cmd = [...cmd, "--subtree-entries-oc"];
-        if (subtreeEnriesOc.length != 0) {
+        if (subtreeEnriesOc.length !== 0) {
             cmd = [...cmd, subtreeEnriesOc];
-        } else if (action == "add") {
+        } else if (action === "add") {
             cmd = [...cmd, ""];
         } else {
             cmd = [...cmd, "delete"];
@@ -494,10 +496,10 @@ class AttributeUniqueness extends React.Component {
                     console.info("attrUniqOperation", "Result", content);
                     this.props.addNotification(
                         "success",
-                        `The ${action} operation was successfully done on "${configName}" entry`
+                        cockpit.format(_("The $0 operation was successfully done on \"$1\" entry"), action, configName)
                     );
                     this.loadConfigs();
-                    this.closeModal();
+                    this.handleCloseModal();
                     this.setState({
                         saving: false
                     });
@@ -506,10 +508,10 @@ class AttributeUniqueness extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error during the config entry ${action} operation - ${errMsg.desc}`
+                        cockpit.format(_("Error during the config entry $0 operation - $1"), action, errMsg.desc)
                     );
                     this.loadConfigs();
-                    this.closeModal();
+                    this.handleCloseModal();
                     this.setState({
                         saving: false
                     });
@@ -559,21 +561,21 @@ class AttributeUniqueness extends React.Component {
                     console.info("deleteConfig", "Result", content);
                     this.props.addNotification(
                         "success",
-                        `Config entry ${this.state.deleteName} was successfully deleted`
+                        cockpit.format(_("Config entry $0 was successfully deleted"), this.state.deleteName)
                     );
                     this.loadConfigs();
-                    this.closeModal();
+                    this.handleCloseModal();
                     this.closeConfirmDelete();
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error during the config entry removal operation - ${errMsg.desc}`
+                        cockpit.format(_("Error during the config entry removal operation - $0"), errMsg.desc)
                     );
                     this.loadConfigs();
                     this.closeConfirmDelete();
-                    this.closeModal();
+                    this.handleCloseModal();
                 });
     }
 
@@ -598,16 +600,16 @@ class AttributeUniqueness extends React.Component {
             newEntry,
         } = this.state;
 
-        const title = (newEntry ? "Add" : "Edit") + " Attribute Uniqueness Plugin Config Entry";
-        let saveBtnName = (newEntry ? "Add" : "Save") + " Config";
+        const title = cockpit.format(_("$0 Attribute Uniqueness Plugin Config Entry"), (newEntry ? _("Add") : _("Edit")));
+        let saveBtnName = (newEntry ? _("Add") : _("Save")) + _(" Config");
         const extraPrimaryProps = {};
         if (this.state.saving) {
             if (newEntry) {
-                saveBtnName = "Adding Config ...";
+                saveBtnName = _("Adding Config ...");
             } else {
-                saveBtnName = "Saving Config ...";
+                saveBtnName = _("Saving Config ...");
             }
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         }
         return (
             <div className={this.state.saving || this.state.modalSpinning ? "ds-disabled" : ""}>
@@ -616,7 +618,7 @@ class AttributeUniqueness extends React.Component {
                     title={title}
                     aria-labelledby="ds-modal"
                     isOpen={configEntryModalShow}
-                    onClose={this.closeModal}
+                    onClose={this.handleCloseModal}
                     actions={[
                         <Button
                             className="ds-margin-top"
@@ -625,23 +627,23 @@ class AttributeUniqueness extends React.Component {
                             onClick={newEntry ? this.addConfig : this.editConfig}
                             isDisabled={this.state.saveBtnDisabled || this.state.saving}
                             isLoading={this.state.saving}
-                            spinnerAriaValueText={this.state.saving ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.saving ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveBtnName}
                         </Button>,
-                        <Button key="cancel" variant="link" onClick={this.closeModal}>
-                            Cancel
+                        <Button key="cancel" variant="link" onClick={this.handleCloseModal}>
+                            {_("Cancel")}
                         </Button>
                     ]}
                 >
                     <Form isHorizontal autoComplete="off">
                         <Grid
                             className="ds-margin-top"
-                            title='Sets the name of the plug-in configuration record. (cn) You can use any string, but "attribute_name Attribute Uniqueness" is recommended.'
+                            title={_("Sets the name of the plug-in configuration record. (cn) You can use any string, but \"attribute_name Attribute Uniqueness\" is recommended.")}
                         >
                             <GridItem span={3} className="ds-label">
-                                Config Name
+                                {_("Config Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -654,26 +656,26 @@ class AttributeUniqueness extends React.Component {
                                     onChange={(str, e) => {
                                         this.handleFieldChange(e);
                                     }}
-                                    validated={this.state.error.configName || this.state.configName == "" ? ValidatedOptions.error : ValidatedOptions.default}
+                                    validated={this.state.error.configName || this.state.configName === "" ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets the name of the attribute whose values must be unique. This attribute is multi-valued. (uniqueness-attribute-name)">
+                        <Grid title={_("Sets the name of the attribute whose values must be unique. This attribute is multi-valued. (uniqueness-attribute-name)")}>
                             <GridItem span={3} className="ds-label">
-                                Attribute Names
+                                {_("Attribute Names")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
                                     variant={SelectVariant.typeaheadMulti}
                                     typeAheadAriaLabel="Type an attribute"
-                                    onToggle={this.onAttributeNameToggle}
-                                    onSelect={this.onAttributeNameSelect}
-                                    onClear={this.onAttributeNameClear}
+                                    onToggle={this.handleAttributeNameToggle}
+                                    onSelect={this.handleAttributeNameSelect}
+                                    onClear={this.handleAttributeNameClear}
                                     selections={attrNames}
                                     isOpen={this.state.isAttributeNameOpen}
                                     aria-labelledby="typeAhead-attr-name"
-                                    placeholderText="Type an attribute name..."
-                                    noResultsFoundText="There are no matching attributes"
+                                    placeholderText={_("Type an attribute name...")}
+                                    noResultsFoundText={_("There are no matching attributes")}
                                     validated={this.state.error.attrNames ? "error" : "default"}
                                 >
                                     {this.props.attributes.map((attr, index) => (
@@ -685,24 +687,24 @@ class AttributeUniqueness extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets the DN under which the plug-in checks for uniqueness of the attributes value. This attribute is multi-valued (uniqueness-subtrees)">
+                        <Grid title={_("Sets the DN under which the plug-in checks for uniqueness of the attributes value. This attribute is multi-valued (uniqueness-subtrees)")}>
                             <GridItem span={3} className="ds-label">
-                                Subtrees
+                                {_("Subtrees")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
                                     variant={SelectVariant.typeaheadMulti}
                                     typeAheadAriaLabel="Type a subtree DN"
-                                    onToggle={this.onSubtreesToggle}
-                                    onSelect={this.onSubtreesSelect}
-                                    onClear={this.onSubtreesClear}
+                                    onToggle={this.handleSubtreesToggle}
+                                    onSelect={this.handleSubtreesSelect}
+                                    onClear={this.handleSubtreesClear}
                                     selections={subtrees}
                                     isOpen={this.state.isSubtreesOpen}
                                     aria-labelledby="typeAhead-subtrees"
-                                    placeholderText="Type a subtree DN..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type a subtree DN...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                     isCreatable
-                                    onCreateOption={this.onSubtreesCreateOption}
+                                    onCreateOption={this.handleSubtreesCreateOption}
                                     validated={this.state.error.subtrees ? "error" : "default"}
                                 >
                                     {[""].map((dn, index) => (
@@ -714,9 +716,9 @@ class AttributeUniqueness extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="Verifies that the value of the attribute set in uniqueness-attribute-name is unique in this subtree (uniqueness-top-entry-oc)">
+                        <Grid title={_("Verifies that the value of the attribute set in uniqueness-attribute-name is unique in this subtree (uniqueness-top-entry-oc)")}>
                             <GridItem span={3} className="ds-label">
-                                Top Entry OC
+                                {_("Top Entry OC")}
                             </GridItem>
                             <GridItem span={6}>
                                 <FormSelect
@@ -738,15 +740,15 @@ class AttributeUniqueness extends React.Component {
                                     id="acrossAllSubtrees"
                                     className="ds-left-margin"
                                     isChecked={acrossAllSubtrees}
-                                    title="If enabled (on), the plug-in checks that the attribute is unique across all subtrees set. If you set the attribute to off, uniqueness is only enforced within the subtree of the updated entry (uniqueness-across-all-subtrees)"
+                                    title={_("If enabled (on), the plug-in checks that the attribute is unique across all subtrees set. If you set the attribute to off, uniqueness is only enforced within the subtree of the updated entry (uniqueness-across-all-subtrees)")}
                                     onChange={(checked, e) => { this.handleFieldChange(e) }}
-                                    label="Across All Subtrees"
+                                    label={_("Across All Subtrees")}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Verifies if an attribute is unique, if the entry contains the objectclass set in this parameter (uniqueness-subtree-entries-oc)">
+                        <Grid title={_("Verifies if an attribute is unique, if the entry contains the objectclass set in this parameter (uniqueness-subtree-entries-oc)")}>
                             <GridItem span={3} className="ds-label">
-                                Subtree Entry's OC
+                                {_("Subtree Entry's OC")}
                             </GridItem>
                             <GridItem span={6}>
                                 <FormSelect
@@ -764,15 +766,15 @@ class AttributeUniqueness extends React.Component {
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid className="ds-margin-bottom" title="Identifies whether or not the config is enabled.">
+                        <Grid className="ds-margin-bottom" title={_("Identifies whether or not the config is enabled.")}>
                             <GridItem span={3} className="ds-label">
-                                Enable config
+                                {_("Enable config")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Switch
                                     id="configEnabled"
-                                    label="Configuration is enabled"
-                                    labelOff="Configuration is disabled"
+                                    label={_("Configuration is enabled")}
+                                    labelOff={_("Configuration is disabled")}
                                     isChecked={configEnabled}
                                     onChange={this.handleSwitchChange}
                                 />
@@ -805,9 +807,9 @@ class AttributeUniqueness extends React.Component {
                             <Button
                                 key="add-config"
                                 variant="primary"
-                                onClick={this.showAddConfigModal}
+                                onClick={this.handleShowAddConfigModal}
                             >
-                                Add Config
+                                {_("Add Config")}
                             </Button>
                         </GridItem>
                     </Grid>
@@ -815,15 +817,15 @@ class AttributeUniqueness extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmDelete}
                     closeHandler={this.closeConfirmDelete}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.deleteConfig}
                     spinning={this.state.modalSpinning}
                     item={this.state.deleteName}
                     checked={this.state.modalChecked}
-                    mTitle="Delete Attribute Uniqueness Configuration"
-                    mMsg="Are you sure you want to delete this configuration?"
-                    mSpinningMsg="Deleting attribute uniqueness configuration..."
-                    mBtnName="Delete Configuration"
+                    mTitle={_("Delete Attribute Uniqueness Configuration")}
+                    mMsg={_("Are you sure you want to delete this configuration?")}
+                    mSpinningMsg={_("Deleting attribute uniqueness configuration...")}
+                    mBtnName={_("Delete Configuration")}
                 />
             </div>
         );
