@@ -27,6 +27,8 @@ import PropTypes from "prop-types";
 import { log_cmd, listsEqual, valid_dn } from "../tools.jsx";
 import { DoubleConfirmModal } from "../notifications.jsx";
 
+const _ = cockpit.gettext;
+
 class AutoMembership extends React.Component {
     componentDidMount() {
         if (this.props.wasActiveList.includes(5)) {
@@ -90,13 +92,13 @@ class AutoMembership extends React.Component {
             showConfirmDelete: false,
         };
 
-        // This vastly improves rendering performance during handleChange()
-        let attrs = [...this.props.attributes, 'dn'].sort();
+        // This vastly improves rendering performance during onChange()
+        const attrs = [...this.props.attributes, 'dn'].sort();
         this.attrRows = attrs.map((attr) => (
             <FormSelectOption key={attr} value={attr} label={attr} />
         ));
 
-        this.onRegexExcludeSelect = (event, selection) => {
+        this.handleRegexExcludeSelect = (event, selection) => {
             const { regexExclusive } = this.state;
             if (regexExclusive.includes(selection)) {
                 this.setState(
@@ -114,7 +116,7 @@ class AutoMembership extends React.Component {
                 );
             }
         };
-        this.onCreateRegexExcludeOption = newValue => {
+        this.handleCreateRegexExcludeOption = newValue => {
             if (!this.state.excludeOptions.includes(newValue)) {
                 this.setState({
                     excludeOptions: [...this.state.excludeOptions, newValue],
@@ -122,19 +124,19 @@ class AutoMembership extends React.Component {
                 });
             }
         };
-        this.onRegexExcludeToggle = isRegexExcludeOpen => {
+        this.handleRegexExcludeToggle = isRegexExcludeOpen => {
             this.setState({
                 isRegexExcludeOpen
             });
         };
-        this.clearRegexExcludeSelection = () => {
+        this.handleClearRegexExcludeSelection = () => {
             this.setState({
                 regexExclusive: [],
                 isRegexExcludeOpen: false
             }, () => { this.validateRegex() });
         };
 
-        this.onRegexIncludeSelect = (event, selection) => {
+        this.handleRegexIncludeSelect = (event, selection) => {
             const { regexInclusive } = this.state;
             if (regexInclusive.includes(selection)) {
                 this.setState(
@@ -152,7 +154,7 @@ class AutoMembership extends React.Component {
                 );
             }
         };
-        this.onCreateRegexIncludeOption = newValue => {
+        this.handleCreateRegexIncludeOption = newValue => {
             if (!this.state.includeOptions.includes(newValue)) {
                 this.setState({
                     includeOptions: [...this.state.includeOptions, newValue],
@@ -160,12 +162,12 @@ class AutoMembership extends React.Component {
                 });
             }
         };
-        this.onRegexIncludeToggle = isRegexIncludeOpen => {
+        this.handleRegexIncludeToggle = isRegexIncludeOpen => {
             this.setState({
                 isRegexIncludeOpen
             });
         };
-        this.clearRegexIncludeSelection = () => {
+        this.handleClearRegexIncludeSelection = () => {
             this.setState({
                 regexInclusive: [],
                 isRegexIncludeOpen: false
@@ -174,23 +176,23 @@ class AutoMembership extends React.Component {
 
         this.validateModal = this.validateModal.bind(this);
         this.validateRegex = this.validateRegex.bind(this);
-        this.handleChange = this.handleChange.bind(this);
+        this.onChange = this.onChange.bind(this);
         this.handleRegexChange = this.handleRegexChange.bind(this);
         this.handleFieldChange = this.handleFieldChange.bind(this);
         this.loadDefinitions = this.loadDefinitions.bind(this);
         this.loadRegexes = this.loadRegexes.bind(this);
         this.openModal = this.openModal.bind(this);
-        this.closeModal = this.closeModal.bind(this);
+        this.handleCloseModal = this.handleCloseModal.bind(this);
         this.showEditDefinitionModal = this.showEditDefinitionModal.bind(this);
-        this.showAddDefinitionModal = this.showAddDefinitionModal.bind(this);
+        this.handleShowAddDefinitionModal = this.handleShowAddDefinitionModal.bind(this);
         this.cmdOperation = this.cmdOperation.bind(this);
         this.deleteDefinition = this.deleteDefinition.bind(this);
         this.addDefinition = this.addDefinition.bind(this);
         this.editDefinition = this.editDefinition.bind(this);
         this.openRegexModal = this.openRegexModal.bind(this);
-        this.closeRegexModal = this.closeRegexModal.bind(this);
+        this.handleCloseRegexModal = this.handleCloseRegexModal.bind(this);
         this.showEditRegexModal = this.showEditRegexModal.bind(this);
-        this.showAddRegexModal = this.showAddRegexModal.bind(this);
+        this.handleShowAddRegexModal = this.handleShowAddRegexModal.bind(this);
         this.cmdRegexOperation = this.cmdRegexOperation.bind(this);
         this.deleteRegex = this.deleteRegex.bind(this);
         this.addRegex = this.addRegex.bind(this);
@@ -211,14 +213,14 @@ class AutoMembership extends React.Component {
         ];
 
         for (const attr of reqAttrs) {
-            if (this.state[attr] == "") {
+            if (this.state[attr] === "") {
                 error[attr] = true;
                 all_good = false;
             }
         }
 
         for (const attr of dnAttrs) {
-            if (this.state[attr] != "" && !valid_dn(this.state[attr])) {
+            if (this.state[attr] !== "" && !valid_dn(this.state[attr])) {
                 error[attr] = true;
                 all_good = false;
             }
@@ -232,22 +234,22 @@ class AutoMembership extends React.Component {
                 'groupingAttrMember', 'groupingAttrEntry', 'scope'
             ];
             for (const check_attr of attrs) {
-                if (this.state[check_attr] != this.state['_' + check_attr]) {
+                if (this.state[check_attr] !== this.state['_' + check_attr]) {
                     all_good = true;
                     break;
                 }
             }
             // If regexes changed, we need to check that here too
-            if (this.state.regexRows.length != this.state._regexRows.length) {
+            if (this.state.regexRows.length !== this.state._regexRows.length) {
                 all_good = true;
             }
             if (!all_good) {
                 for (const row of this.state.regexRows) {
                     let found = false;
                     for (const orig_row of this.state._regexRows) {
-                        if (orig_row.cn[0] == row.cn[0]) {
+                        if (orig_row.cn[0] === row.cn[0]) {
                             found = true;
-                            if (orig_row.automembertargetgroup[0] != row.automembertargetgroup[0]) {
+                            if (orig_row.automembertargetgroup[0] !== row.automembertargetgroup[0]) {
                                 all_good = true;
                                 break;
                             }
@@ -269,7 +271,7 @@ class AutoMembership extends React.Component {
                     for (const orig_row of this.state._regexRows) {
                         let found = false;
                         for (const row of this.state.regexRows) {
-                            if (orig_row.cn[0] == row.cn[0]) {
+                            if (orig_row.cn[0] === row.cn[0]) {
                                 found = true;
                             }
                         }
@@ -284,7 +286,7 @@ class AutoMembership extends React.Component {
 
         this.setState({
             saveBtnDisabled: !all_good,
-            error: error
+            error
         });
     }
 
@@ -299,14 +301,14 @@ class AutoMembership extends React.Component {
         ];
 
         for (const attr of reqAttrs) {
-            if (this.state[attr] == "") {
+            if (this.state[attr] === "") {
                 error[attr] = true;
                 all_good = false;
             }
         }
 
         for (const attr of dnAttrs) {
-            if (this.state[attr] != "" && !valid_dn(this.state[attr])) {
+            if (this.state[attr] !== "" && !valid_dn(this.state[attr])) {
                 error[attr] = true;
                 all_good = false;
             }
@@ -322,7 +324,7 @@ class AutoMembership extends React.Component {
                 'regexExclusive', 'regexInclusive'
             ];
             for (const check_attr of attrs) {
-                if (this.state[check_attr] != this.state['_' + check_attr]) {
+                if (this.state[check_attr] !== this.state['_' + check_attr]) {
                     all_good = true;
                     break;
                 }
@@ -338,11 +340,11 @@ class AutoMembership extends React.Component {
 
         this.setState({
             saveRegexBtnDisabled: !all_good,
-            error: error
+            error
         }, () => { this.validateModal() });
     }
 
-    handleChange(e) {
+    onChange(e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
             [e.target.id]: value
@@ -385,7 +387,7 @@ class AutoMembership extends React.Component {
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    if (err != 0) {
+                    if (err !== 0) {
                         console.log("loadDefinitions failed", errMsg.desc);
                     }
                 });
@@ -427,12 +429,12 @@ class AutoMembership extends React.Component {
                     this.setState({
                         regexRows: rows,
                         _regexRows: JSON.parse(JSON.stringify(rows)),
-                        regexTableKey: regexTableKey
+                        regexTableKey
                     });
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    if (err != 0) {
+                    if (err !== 0) {
                         console.log("loadRegexes failed", errMsg.desc);
                     }
                 });
@@ -442,7 +444,7 @@ class AutoMembership extends React.Component {
         this.openModal(rowData);
     }
 
-    showAddDefinitionModal(rowData) {
+    handleShowAddDefinitionModal(rowData) {
         this.openModal();
     }
 
@@ -562,18 +564,18 @@ class AutoMembership extends React.Component {
         this.openRegexModal(name);
     }
 
-    showAddRegexModal() {
+    handleShowAddRegexModal() {
         this.openRegexModal();
     }
 
-    closeModal() {
+    handleCloseModal() {
         this.setState({
             definitionEntryModalShow: false,
             saving: false
         });
     }
 
-    closeRegexModal() {
+    handleCloseRegexModal() {
         this.setState({ regexEntryModalShow: false });
     }
 
@@ -591,12 +593,12 @@ class AutoMembership extends React.Component {
             definitionName === "" ||
             scope === "" ||
             filter === "" ||
-            groupingAttrMember == "" ||
+            groupingAttrMember === "" ||
             groupingAttrEntry === ""
         ) {
             this.props.addNotification(
                 "warning",
-                "Name, Scope, Filter and Grouping Attribute are required."
+                _("Name, Scope, Filter and Grouping Attribute are required.")
             );
         } else {
             let cmd = [
@@ -609,17 +611,17 @@ class AutoMembership extends React.Component {
                 definitionName,
                 action,
                 "--default-group",
-                defaultGroup || action == "add" ? defaultGroup : "delete",
+                defaultGroup || action === "add" ? defaultGroup : "delete",
                 "--filter",
-                filter || action == "add" ? filter : "delete",
+                filter || action === "add" ? filter : "delete",
                 "--scope",
-                scope || action == "add" ? scope : "delete"
+                scope || action === "add" ? scope : "delete"
             ];
 
             cmd = [...cmd, "--grouping-attr"];
-            if (groupingAttrMember != "" && groupingAttrEntry != "") {
+            if (groupingAttrMember !== "" && groupingAttrEntry !== "") {
                 cmd = [...cmd, `${groupingAttrMember}:${groupingAttrEntry}`];
-            } else if (action == "add") {
+            } else if (action === "add") {
                 cmd = [...cmd, ""];
             } else {
                 cmd = [...cmd, "delete"];
@@ -644,11 +646,11 @@ class AutoMembership extends React.Component {
                         console.info("AutoMembershipOperation", "Result", content);
                         this.props.addNotification(
                             "success",
-                            `The ${action} operation was successfully done on "${definitionName}" entry`
+                            cockpit.format(_("The $0 operation was successfully done on \"$1\" entry"), action, definitionName)
                         );
                         this.loadDefinitions();
                         this.purgeRegexUpdate();
-                        this.closeModal();
+                        this.handleCloseModal();
                         this.props.toggleLoadingHandler();
                     })
                     .fail(err => {
@@ -656,13 +658,13 @@ class AutoMembership extends React.Component {
                         if (errMsg.desc.indexOf("nothing to set") === 0) {
                             this.props.addNotification(
                                 "error",
-                                `Error during the definition entry ${action} operation - ${errMsg.desc}`
+                                cockpit.format(_("Error during the definition entry $0 operation - $1"), action, errMsg.desc)
                             );
                         } else {
                             this.purgeRegexUpdate();
                         }
                         this.loadDefinitions();
-                        this.closeModal();
+                        this.handleCloseModal();
                         this.props.toggleLoadingHandler();
                     });
         }
@@ -706,9 +708,7 @@ class AutoMembership extends React.Component {
                         const errMsg = JSON.parse(err);
                         this.props.addNotification(
                             "error",
-                            `Error during the regex "${regexToDelete}" entry delete operation - ${
-                                errMsg.desc
-                            }`
+                            cockpit.format(_("Error during the regex \"$0\" entry delete operation - $1"), regexToDelete, errMsg.desc)
                         );
                     });
         }
@@ -743,36 +743,36 @@ class AutoMembership extends React.Component {
             const regexExclusive = row.automemberexclusiveregex === undefined ? [] : row.automemberexclusiveregex;
             const regexInclusive = row.automemberinclusiveregex === undefined ? [] : row.automemberinclusiveregex;
 
-            if (!(action == "add" && regexTargetGroup == 0)) {
+            if (!(action === "add" && regexTargetGroup === 0)) {
                 cmd = [...cmd, "--target-group"];
                 if (regexTargetGroup) {
                     cmd = [...cmd, regexTargetGroup];
-                } else if (action == "add") {
+                } else if (action === "add") {
                     cmd = [...cmd, ""];
                 } else {
                     cmd = [...cmd, "delete"];
                 }
             }
 
-            if (!(action == "add" && regexExclusive.length == 0)) {
+            if (!(action === "add" && regexExclusive.length === 0)) {
                 cmd = [...cmd, "--exclusive"];
-                if (regexExclusive.length != 0) {
+                if (regexExclusive.length !== 0) {
                     for (const regex of regexExclusive) {
                         cmd = [...cmd, regex];
                     }
-                } else if (action == "add") {
+                } else if (action === "add") {
                     cmd = [...cmd, ""];
                 } else {
                     cmd = [...cmd, "delete"];
                 }
             }
-            if (!(action == "add" && regexInclusive.length == 0)) {
+            if (!(action === "add" && regexInclusive.length === 0)) {
                 cmd = [...cmd, "--inclusive"];
-                if (regexInclusive.length != 0) {
+                if (regexInclusive.length !== 0) {
                     for (const regex of regexInclusive) {
                         cmd = [...cmd, regex];
                     }
-                } else if (action == "add") {
+                } else if (action === "add") {
                     cmd = [...cmd, ""];
                 } else {
                     cmd = [...cmd, "delete"];
@@ -800,9 +800,7 @@ class AutoMembership extends React.Component {
                         const errMsg = JSON.parse(err);
                         this.props.addNotification(
                             "error",
-                            `Error during the regex "${regexName}" entry ${action} operation - ${
-                                errMsg.desc
-                            }`
+                            cockpit.format(_("Error during the regex \"$0\" entry $1 operation - $2"), regexName, action, errMsg.desc)
                         );
                     });
         }
@@ -850,7 +848,7 @@ class AutoMembership extends React.Component {
                     console.info("deleteDefinition", "Result", content);
                     this.props.addNotification(
                         "success",
-                        `Definition entry ${this.state.deleteName} was successfully deleted`
+                        cockpit.format(_("Definition entry $0 was successfully deleted"), this.state.deleteName)
                     );
                     this.loadDefinitions();
                     this.closeConfirmDelete();
@@ -859,7 +857,7 @@ class AutoMembership extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error during the definition entry removal operation - ${errMsg.desc}`
+                        cockpit.format(_("Error during the definition entry removal operation - $0"), errMsg.desc)
                     );
                     this.loadDefinitions();
                     this.closeConfirmDelete();
@@ -950,10 +948,10 @@ class AutoMembership extends React.Component {
         }
 
         if (regexName === "" || regexTargetGroup === "") {
-            this.props.addNotification("warning", "Name and Target Group are required.");
+            this.props.addNotification("warning", _("Name and Target Group are required."));
         } else {
             const regexTableKey = this.state.regexTableKey + 1;
-            if (action == "add") {
+            if (action === "add") {
                 if (!regexExists) {
                     this.setState(prevState => ({
                         regexRows: [
@@ -972,12 +970,12 @@ class AutoMembership extends React.Component {
                                 needsadd: true
                             }
                         ],
-                        regexTableKey: regexTableKey
+                        regexTableKey
                     }), () => { this.validateModal() });
                 } else {
-                    this.props.addNotification("error", `Regex "${regexName}" already exists`);
+                    this.props.addNotification("error", cockpit.format(_("Regex \"$0\" already exists"), regexName));
                 }
-            } else if (action == "set") {
+            } else if (action === "set") {
                 if (regexExists) {
                     this.setState({
                         regexRows: regexRows.filter(row => row.cn[0] !== regexName)
@@ -999,16 +997,16 @@ class AutoMembership extends React.Component {
                                 needsupdate: true
                             }
                         ],
-                        regexTableKey: regexTableKey
+                        regexTableKey
                     }), () => { this.validateModal() });
                 } else {
                     this.props.addNotification(
                         "error",
-                        `Regex "${regexName}" does not exist - "${action}" is impossible`
+                        cockpit.format(_("Regex \"$0\" does not exist - \"$1\" is impossible"), regexName, action)
                     );
                 }
             }
-            this.closeRegexModal();
+            this.handleCloseRegexModal();
         }
     }
 
@@ -1018,7 +1016,7 @@ class AutoMembership extends React.Component {
         if (regexRows.some(row => row.cn[0] === regexName)) {
             this.setState({
                 regexRows: regexRows.filter(row => row.cn[0] !== regexName),
-                regexTableKey: regexTableKey
+                regexTableKey
             });
             this.setState(prevState => ({
                 regexesToDelete: [...prevState.regexesToDelete, regexName]
@@ -1026,7 +1024,7 @@ class AutoMembership extends React.Component {
         } else {
             this.props.addNotification(
                 "error",
-                `Regex "${regexName}" does not exist - impossible to delete`
+                cockpit.format(_("Regex \"$0\" does not exist - impossible to delete"), regexName)
             );
         }
     }
@@ -1062,12 +1060,12 @@ class AutoMembership extends React.Component {
             firstLoad,
         } = this.state;
 
-        const title = (newDefinitionEntry ? "Add" : "Edit") + " Auto Membership Plugin Definition Entry";
+        const title = cockpit.format(_("$0  Auto Membership Plugin Definition Entry"), (newDefinitionEntry ? _("Add") : _("Edit")));
         const extraPrimaryProps = {};
-        let saveBtnText = newDefinitionEntry ? "Add Definition" : "Save Definition";
+        let saveBtnText = newDefinitionEntry ? _("Add Definition") : _("Save Definition");
         if (saving) {
             // Main plugin config
-            saveBtnText = newDefinitionEntry ? "Adding ..." : "Saving ...";
+            saveBtnText = newDefinitionEntry ? _("Adding ...") : _("Saving ...");
         }
 
         return (
@@ -1077,7 +1075,7 @@ class AutoMembership extends React.Component {
                     title={title}
                     isOpen={definitionEntryModalShow}
                     aria-labelledby="ds-modal"
-                    onClose={this.closeModal}
+                    onClose={this.handleCloseModal}
                     actions={[
                         <Button
                             key="confirm"
@@ -1085,20 +1083,20 @@ class AutoMembership extends React.Component {
                             onClick={newDefinitionEntry ? this.addDefinition : this.editDefinition}
                             isDisabled={saveBtnDisabled || saving}
                             isLoading={saving}
-                            spinnerAriaValueText={saving ? "Saving" : undefined}
+                            spinnerAriaValueText={saving ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveBtnText}
                         </Button>,
-                        <Button key="cancel" variant="link" onClick={this.closeModal}>
-                            Cancel
+                        <Button key="cancel" variant="link" onClick={this.handleCloseModal}>
+                            {_("Cancel")}
                         </Button>
                     ]}
                 >
                     <Form isHorizontal autoComplete="off">
                         <Grid className="ds-margin-top">
                             <GridItem className="ds-label" span={3}>
-                                Definition Name
+                                {_("Definition Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1111,13 +1109,13 @@ class AutoMembership extends React.Component {
                                         this.handleFieldChange(e);
                                     }}
                                     isDisabled={!newDefinitionEntry}
-                                    validated={this.state.error.definitionName || definitionName == "" ? ValidatedOptions.error : ValidatedOptions.default}
+                                    validated={this.state.error.definitionName || definitionName === "" ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets the subtree DN to search for entries (autoMemberScope).">
+                        <Grid title={_("Sets the subtree DN to search for entries (autoMemberScope).")}>
                             <GridItem className="ds-label" span={3}>
-                                Subtree Scope
+                                {_("Subtree Scope")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1129,13 +1127,13 @@ class AutoMembership extends React.Component {
                                     onChange={(str, e) => {
                                         this.handleFieldChange(e);
                                     }}
-                                    validated={this.state.error.scope || scope == "" ? ValidatedOptions.error : ValidatedOptions.default}
+                                    validated={this.state.error.scope || scope === "" ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets a standard LDAP search filter to use to search for matching entries (autoMemberFilter)">
+                        <Grid title={_("Sets a standard LDAP search filter to use to search for matching entries (autoMemberFilter)")}>
                             <GridItem className="ds-label" span={3}>
-                                Entry Filter
+                                {_("Entry Filter")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1147,13 +1145,13 @@ class AutoMembership extends React.Component {
                                     onChange={(str, e) => {
                                         this.handleFieldChange(e);
                                     }}
-                                    validated={this.state.error.filter || filter == "" ? ValidatedOptions.error : ValidatedOptions.default}
+                                    validated={this.state.error.filter || filter === "" ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Specifies the name of the member attribute in the group entry and the attribute in the object entry that supplies the member attribute value, in the format group_member_attr:entry_attr (autoMemberGroupingAttr)">
+                        <Grid title={_("Specifies the name of the member attribute in the group entry and the attribute in the object entry that supplies the member attribute value, in the format group_member_attr:entry_attr (autoMemberGroupingAttr)")}>
                             <GridItem className="ds-label" span={3}>
-                                Grouping Attribute
+                                {_("Grouping Attribute")}
                             </GridItem>
                             <GridItem span={4}>
                                 <FormSelect
@@ -1163,7 +1161,7 @@ class AutoMembership extends React.Component {
                                         this.handleFieldChange(event);
                                     }}
                                     aria-label="FormSelect Input"
-                                    validated={groupingAttrMember == "" ? "error" : "default"}
+                                    validated={groupingAttrMember === "" ? "error" : "default"}
                                 >
                                     <FormSelectOption key="no-setting" value="" label="-" />
                                     {this.attrRows}
@@ -1180,16 +1178,16 @@ class AutoMembership extends React.Component {
                                         this.handleFieldChange(event);
                                     }}
                                     aria-label="FormSelect Input"
-                                    validated={groupingAttrEntry == "" ? "error" : "default"}
+                                    validated={groupingAttrEntry === "" ? "error" : "default"}
                                 >
                                     <FormSelectOption key="no-setting" value="" label="-" />
                                     {this.attrRows}
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets an optional default or fallback group to add the entry to as a member (autoMemberDefaultGroup)">
+                        <Grid title={_("Sets an optional default or fallback group to add the entry to as a member (autoMemberDefaultGroup)")}>
                             <GridItem className="ds-label" span={3}>
-                                Default Group
+                                {_("Default Group")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1209,7 +1207,7 @@ class AutoMembership extends React.Component {
                     <hr />
                     <TextContent>
                         <Text className="ds-center" component={TextVariants.h3}>
-                            Membership Regular Expressions
+                            {_("Membership Regular Expressions")}
                         </Text>
                     </TextContent>
                     <Grid>
@@ -1226,9 +1224,9 @@ class AutoMembership extends React.Component {
                         <GridItem span={12}>
                             <Button
                                 variant="secondary"
-                                onClick={this.showAddRegexModal}
+                                onClick={this.handleShowAddRegexModal}
                             >
-                                Add Regex
+                                {_("Add Regex")}
                             </Button>
                         </GridItem>
                     </Grid>
@@ -1237,10 +1235,10 @@ class AutoMembership extends React.Component {
 
                 <Modal
                     variant={ModalVariant.medium}
-                    title="Manage Auto Membership Plugin Regex Entry"
+                    title={_("Manage Auto Membership Plugin Regex Entry")}
                     isOpen={regexEntryModalShow}
                     aria-labelledby="ds-modal"
-                    onClose={this.closeRegexModal}
+                    onClose={this.handleCloseRegexModal}
                     actions={[
                         <Button
                             key="confirm"
@@ -1248,17 +1246,17 @@ class AutoMembership extends React.Component {
                             isDisabled={saveRegexBtnDisabled}
                             onClick={newRegexEntry ? this.addRegex : this.editRegex}
                         >
-                            Save
+                            {_("Save")}
                         </Button>,
-                        <Button key="cancel" variant="link" onClick={this.closeRegexModal}>
-                            Cancel
+                        <Button key="cancel" variant="link" onClick={this.handleCloseRegexModal}>
+                            {_("Cancel")}
                         </Button>
                     ]}
                 >
                     <Form isHorizontal autoComplete="off">
                         <Grid>
                             <GridItem className="ds-label" span={3}>
-                                Regex Name
+                                {_("Regex Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1275,23 +1273,23 @@ class AutoMembership extends React.Component {
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)">
+                        <Grid title={_("Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)")}>
                             <GridItem className="ds-label" span={3}>
-                                Exclusive Regex
+                                {_("Exclusive Regex")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
                                     variant={SelectVariant.typeaheadMulti}
                                     typeAheadAriaLabel="Type a regex"
-                                    onToggle={this.onRegexExcludeToggle}
-                                    onSelect={this.onRegexExcludeSelect}
-                                    onClear={this.clearRegexExcludeSelection}
+                                    onToggle={this.handleRegexExcludeToggle}
+                                    onSelect={this.handleRegexExcludeSelect}
+                                    onClear={this.handleClearRegexExcludeSelection}
                                     selections={regexExclusive}
                                     isOpen={this.state.isRegexExcludeOpen}
                                     aria-labelledby="typeAhead-excl-regex"
-                                    placeholderText="Type a regex..."
+                                    placeholderText={_("Type a regex...")}
                                     isCreatable
-                                    onCreateOption={this.onCreateRegexExcludeOption}
+                                    onCreateOption={this.handleCreateRegexExcludeOption}
                                 >
                                     {[].map((attr, index) => (
                                         <SelectOption
@@ -1302,23 +1300,23 @@ class AutoMembership extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)">
+                        <Grid title={_("Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)")}>
                             <GridItem className="ds-label" span={3}>
-                                Inclusive Regex
+                                {_("Inclusive Regex")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
                                     variant={SelectVariant.typeaheadMulti}
                                     typeAheadAriaLabel="Type a regex"
-                                    onToggle={this.onRegexIncludeToggle}
-                                    onSelect={this.onRegexIncludeSelect}
-                                    onClear={this.clearRegexIncludeSelection}
+                                    onToggle={this.handleRegexIncludeToggle}
+                                    onSelect={this.handleRegexIncludeSelect}
+                                    onClear={this.handleClearRegexIncludeSelection}
                                     selections={regexInclusive}
                                     isOpen={this.state.isRegexIncludeOpen}
                                     aria-labelledby="typeAhead-incl-regex"
-                                    placeholderText="Type a regex..."
+                                    placeholderText={_("Type a regex...")}
                                     isCreatable
-                                    onCreateOption={this.onCreateRegexIncludeOption}
+                                    onCreateOption={this.handleCreateRegexIncludeOption}
                                 >
                                     {[].map((attr, index) => (
                                         <SelectOption
@@ -1329,9 +1327,9 @@ class AutoMembership extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="Sets which group to add the entry to as a member, if it meets the regular expression conditions (autoMemberTargetGroup)">
+                        <Grid title={_("Sets which group to add the entry to as a member, if it meets the regular expression conditions (autoMemberTargetGroup)")}>
                             <GridItem className="ds-label" span={3}>
-                                Target Group
+                                {_("Target Group")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -1371,9 +1369,9 @@ class AutoMembership extends React.Component {
                             />
                             <Button
                                 variant="primary"
-                                onClick={this.showAddDefinitionModal}
+                                onClick={this.handleShowAddDefinitionModal}
                             >
-                                Add Definition
+                                {_("Add Definition")}
                             </Button>
                         </GridItem>
                     </Grid>
@@ -1381,15 +1379,15 @@ class AutoMembership extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmDelete}
                     closeHandler={this.closeConfirmDelete}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.deleteDefinition}
                     spinning={this.state.modalSpinning}
                     item={this.state.deleteName}
                     checked={this.state.modalChecked}
-                    mTitle="Delete Autemebership Configuration"
-                    mMsg="Are you sure you want to delete this configuration?"
-                    mSpinningMsg="Deleting Configuration..."
-                    mBtnName="Delete Configuration"
+                    mTitle={_("Delete Autemebership Configuration")}
+                    mMsg={_("Are you sure you want to delete this configuration?")}
+                    mSpinningMsg={_("Deleting Configuration...")}
+                    mBtnName={_("Delete Configuration")}
                 />
             </div>
         );
