@@ -17,7 +17,9 @@ import {
     TextVariants,
     Tooltip,
 } from '@patternfly/react-core';
-import OutlinedQuestionCircleIcon from '@patternfly/react-icons/dist/js/icons/outlined-question-circle-icon';
+import { OutlinedQuestionCircleIcon } from '@patternfly/react-icons/dist/js/icons/outlined-question-circle-icon';
+
+const _ = cockpit.gettext;
 
 export class Changelog extends React.Component {
     constructor (props) {
@@ -28,16 +30,16 @@ export class Changelog extends React.Component {
             showConfirmDelete: false,
             saveBtnDisabled: true,
             // Changelog settings
-            clMaxEntries: Number(this.props.clMaxEntries) == 0 ? -1 : Number(this.props.clMaxEntries),
-            clMaxAge: Number(this.props.clMaxAge.slice(0, -1)) == 0 ? -1 : Number(this.props.clMaxAge.slice(0, -1)),
-            clMaxAgeUnit: this.props.clMaxAge != "" ? this.props.clMaxAge.slice(-1).toLowerCase() : "s",
-            clTrimInt: Number(this.props.clTrimInt) == 0 ? -1 : Number(this.props.clTrimInt),
+            clMaxEntries: Number(this.props.clMaxEntries) === 0 ? -1 : Number(this.props.clMaxEntries),
+            clMaxAge: Number(this.props.clMaxAge.slice(0, -1)) === 0 ? -1 : Number(this.props.clMaxAge.slice(0, -1)),
+            clMaxAgeUnit: this.props.clMaxAge !== "" ? this.props.clMaxAge.slice(-1).toLowerCase() : "s",
+            clTrimInt: Number(this.props.clTrimInt) === 0 ? -1 : Number(this.props.clTrimInt),
             clEncrypt: this.props.clEncrypt,
             // Preserve original settings
-            _clMaxEntries: Number(this.props.clMaxEntries) == 0 ? -1 : Number(this.props.clMaxEntries),
-            _clMaxAge: Number(this.props.clMaxAge.slice(0, -1)) == 0 ? -1 : Number(this.props.clMaxAge.slice(0, -1)),
-            _clMaxAgeUnit: this.props.clMaxAge != "" ? this.props.clMaxAge.slice(-1).toLowerCase() : "s",
-            _clTrimInt: Number(this.props.clTrimInt) == 0 ? -1 : Number(this.props.clTrimInt),
+            _clMaxEntries: Number(this.props.clMaxEntries) === 0 ? -1 : Number(this.props.clMaxEntries),
+            _clMaxAge: Number(this.props.clMaxAge.slice(0, -1)) === 0 ? -1 : Number(this.props.clMaxAge.slice(0, -1)),
+            _clMaxAgeUnit: this.props.clMaxAge !== "" ? this.props.clMaxAge.slice(-1).toLowerCase() : "s",
+            _clTrimInt: Number(this.props.clTrimInt) === 0 ? -1 : Number(this.props.clTrimInt),
             _clEncrypt: this.props.clEncrypt,
         };
 
@@ -64,30 +66,30 @@ export class Changelog extends React.Component {
         };
 
         this.handleChange = this.handleChange.bind(this);
-        this.saveSettings = this.saveSettings.bind(this);
+        this.handleSaveSettings = this.handleSaveSettings.bind(this);
     }
 
-    saveSettings () {
-        let cmd = [
+    handleSaveSettings () {
+        const cmd = [
             'dsconf', '-j', 'ldapi://%2fvar%2frun%2fslapd-' + this.props.serverId + '.socket',
             'replication', 'set-changelog', '--suffix', this.props.suffix
         ];
         let requires_restart = false;
         let msg = "Successfully updated changelog configuration.";
 
-        if (this.state.clMaxEntries != this.state._clMaxEntries) {
+        if (this.state.clMaxEntries !== this.state._clMaxEntries) {
             cmd.push("--max-entries=" + this.state.clMaxEntries);
         }
-        if (this.state.clMaxAge != this.state._clMaxAge || this.state.clMaxAgeUnit != this.state._clMaxAgeUnit) {
+        if (this.state.clMaxAge !== this.state._clMaxAge || this.state.clMaxAgeUnit !== this.state._clMaxAgeUnit) {
             cmd.push("--max-age=" + this.state.clMaxAge + this.state.clMaxAgeUnit);
         }
-        if (this.state.clTrimInt != this.state._clTrimInt) {
+        if (this.state.clTrimInt !== this.state._clTrimInt) {
             cmd.push("--trim-interval=" + this.state.clTrimInt);
         }
-        if (this.state.clEncrypt != this.state._clEncrypt) {
+        if (this.state.clEncrypt !== this.state._clEncrypt) {
             if (this.state.clEncrypt) {
                 cmd.push("--encrypt");
-                msg += "  This requires a server restart to take effect";
+                msg += _("  This requires a server restart to take effect");
                 requires_restart = true;
             } else {
                 cmd.push("--disable-encrypt");
@@ -98,7 +100,7 @@ export class Changelog extends React.Component {
                 // Start the spinner
                 saving: true
             });
-            log_cmd("saveSettings", "Applying replication changelog changes", cmd);
+            log_cmd("handleSaveSettings", "Applying replication changelog changes", cmd);
             cockpit
                     .spawn(cmd, { superuser: true, err: "message" })
                     .done(content => {
@@ -124,7 +126,7 @@ export class Changelog extends React.Component {
                         }
                         this.props.addNotification(
                             "error",
-                            `Error updating changelog configuration - ${msg}`
+                            cockpit.format(_("Error updating changelog configuration - $0"), msg)
                         );
                     });
         }
@@ -133,16 +135,16 @@ export class Changelog extends React.Component {
     validateSaveBtn() {
         let saveBtnDisabled = true;
 
-        if (this.state.clMaxEntries != this.state._clMaxEntries ||
-            this.state.clMaxAge != this.state._clMaxAge ||
-            this.state.clMaxAgeUnit != this.state._clMaxAgeUnit ||
-            this.state.clTrimInt != this.state._clTrimInt ||
-            this.state.clEncrypt != this.state._clEncrypt) {
+        if (this.state.clMaxEntries !== this.state._clMaxEntries ||
+            this.state.clMaxAge !== this.state._clMaxAge ||
+            this.state.clMaxAgeUnit !== this.state._clMaxAgeUnit ||
+            this.state.clTrimInt !== this.state._clTrimInt ||
+            this.state.clEncrypt !== this.state._clEncrypt) {
             saveBtnDisabled = false;
         }
 
         this.setState({
-            saveBtnDisabled: saveBtnDisabled,
+            saveBtnDisabled,
         });
     }
 
@@ -174,28 +176,28 @@ export class Changelog extends React.Component {
                     let clEncrypt = false;
                     for (const attr in config.attrs) {
                         const val = config.attrs[attr][0];
-                        if (attr == "nsslapd-changelogmaxentries") {
+                        if (attr === "nsslapd-changelogmaxentries") {
                             clMaxEntries = val;
-                        } else if (attr == "nsslapd-changelogmaxage") {
+                        } else if (attr === "nsslapd-changelogmaxage") {
                             clMaxAge = val.slice(0, -1);
                             clMaxAgeUnit = val.slice(-1).toLowerCase();
-                        } else if (attr == "nsslapd-changelogtrim-interval") {
+                        } else if (attr === "nsslapd-changelogtrim-interval") {
                             clTrimInt = val;
-                        } else if (attr == "nsslapd-encryptionalgorithm") {
+                        } else if (attr === "nsslapd-encryptionalgorithm") {
                             clEncrypt = true;
                         }
                     }
                     this.setState({
-                        clMaxEntries: Number(clMaxEntries) == 0 ? -1 : Number(clMaxEntries),
-                        clMaxAge: Number(clMaxAge) == 0 ? -1 : Number(clMaxAge),
-                        clMaxAgeUnit: clMaxAgeUnit,
-                        clTrimInt: Number(clTrimInt) == 0 ? -1 : Number(clTrimInt),
-                        clEncrypt: clEncrypt,
+                        clMaxEntries: Number(clMaxEntries) === 0 ? -1 : Number(clMaxEntries),
+                        clMaxAge: Number(clMaxAge) === 0 ? -1 : Number(clMaxAge),
+                        clMaxAgeUnit,
+                        clTrimInt: Number(clTrimInt) === 0 ? -1 : Number(clTrimInt),
+                        clEncrypt,
                         // Preserve original settings
-                        _clMaxEntries: Number(clMaxEntries) == 0 ? -1 : Number(clMaxEntries),
-                        _clMaxAge: Number(clMaxAge) == 0 ? -1 : Number(clMaxAge),
+                        _clMaxEntries: Number(clMaxEntries) === 0 ? -1 : Number(clMaxEntries),
+                        _clMaxAge: Number(clMaxAge) === 0 ? -1 : Number(clMaxAge),
                         _clMaxAgeUnit: clMaxAgeUnit,
-                        _clTrimInt: Number(clTrimInt) == 0 ? -1 : Number(clTrimInt),
+                        _clTrimInt: Number(clTrimInt) === 0 ? -1 : Number(clTrimInt),
                         _clEncrypt: clEncrypt,
                         saveBtnDisabled: true,
                         loading: false,
@@ -205,7 +207,7 @@ export class Changelog extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Failed to reload changelog for "${this.props.suffix}" - ${errMsg.desc}`
+                        cockpit.format(_("Failed to reload changelog for \"$0\" - $1"), this.props.suffix, errMsg.desc)
                     );
                     this.setState({
                         loading: false,
@@ -216,31 +218,32 @@ export class Changelog extends React.Component {
 
     render() {
         let clPage;
-        let saveBtnName = "Save Settings";
+        let saveBtnName = _("Save Settings");
         const extraPrimaryProps = {};
 
         if (this.state.saving) {
-            saveBtnName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            saveBtnName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         } else if (this.loading) {
-            clPage =
+            clPage = (
                 <div className="ds-margin-top-xlg ds-center">
                     <TextContent>
                         <Text component={TextVariants.h3}>
-                            Loading Changelog Configuration ...
+                            {_("Loading Changelog Configuration ...")}
                         </Text>
                     </TextContent>
                     <Spinner className="ds-margin-top-lg" size="md" />
-                </div>;
+                </div>
+            );
         } else {
-            clPage =
+            clPage = (
                 <div className="ds-margin-top-lg">
                     <Form isHorizontal>
                         <Grid
-                            title="Changelog trimming parameter.  Set the maximum number of changelog entries allowed in the database (nsslapd-changelogmaxentries)."
+                            title={_("Changelog trimming parameter.  Set the maximum number of changelog entries allowed in the database (nsslapd-changelogmaxentries).")}
                         >
                             <GridItem className="ds-label" span={3}>
-                                Changelog Maximum Entries
+                                {_("Changelog Maximum Entries")}
                             </GridItem>
                             <GridItem span={2}>
                                 <NumberInput
@@ -259,10 +262,10 @@ export class Changelog extends React.Component {
                             </GridItem>
                         </Grid>
                         <Grid
-                            title="Changelog trimming parameter.  This set the maximum age of a changelog entry (nsslapd-changelogmaxage)."
+                            title={_("Changelog trimming parameter.  This set the maximum age of a changelog entry (nsslapd-changelogmaxage).")}
                         >
                             <GridItem className="ds-label" span={3}>
-                                Changelog Maximum Age
+                                {_("Changelog Maximum Age")}
                             </GridItem>
                             <GridItem span={2}>
                                 <NumberInput
@@ -288,19 +291,19 @@ export class Changelog extends React.Component {
                                     aria-label="FormSelect Input"
                                     isDisabled={this.state.clMaxAge < 1}
                                 >
-                                    <FormSelectOption key="s" value="s" label="Seconds" />
-                                    <FormSelectOption key="m" value="m" label="Minutes" />
-                                    <FormSelectOption key="h" value="h" label="Hours" />
-                                    <FormSelectOption key="d" value="d" label="Days" />
-                                    <FormSelectOption key="w" value="w" label="Weeks" />
+                                    <FormSelectOption key="s" value="s" label={_("Seconds")} />
+                                    <FormSelectOption key="m" value="m" label={_("Minutes")} />
+                                    <FormSelectOption key="h" value="h" label={_("Hours")} />
+                                    <FormSelectOption key="d" value="d" label={_("Days")} />
+                                    <FormSelectOption key="w" value="w" label={_("Weeks")} />
                                 </FormSelect>
                             </GridItem>
                         </Grid>
                         <Grid
-                            title="The changelog trimming interval.  Set how often the changelog checks if there are entries that can be purged from the changelog based on the trimming parameters (nsslapd-changelogtrim-interval)."
+                            title={_("The changelog trimming interval.  Set how often the changelog checks if there are entries that can be purged from the changelog based on the trimming parameters (nsslapd-changelogtrim-interval).")}
                         >
                             <GridItem className="ds-label" span={3}>
-                                Changelog Trimming Interval
+                                {_("Changelog Trimming Interval")}
                             </GridItem>
                             <GridItem span={2}>
                                 <NumberInput
@@ -320,19 +323,13 @@ export class Changelog extends React.Component {
                         </Grid>
                         <Grid>
                             <GridItem className="ds-label" span={3}>
-                                Changelog Encryption
+                                {_("Changelog Encryption")}
                                 <Tooltip
                                     id='CLtooltip'
                                     position="bottom"
                                     content={
                                         <div>
-                                            Changelog encryption requires that the server must already be
-                                            configured for security/TLS.  This setting also requires
-                                            that you export and import the changelog which must be done
-                                            while the database is in read-only mode.  So first put the
-                                            database into read-only mode, then export the changelog, enable
-                                            changelog encryption, restart the server, import the changelog,
-                                            and finally unset the database read-only mode.
+                                            {_("Changelog encryption requires that the server must already be configured for security/TLS.  This setting also requires that you export and import the changelog which must be done while the database is in read-only mode.  So first put the database into read-only mode, then export the changelog, enable changelog encryption, restart the server, import the changelog, and finally unset the database read-only mode.")}
                                         </div>
                                     }
                                 >
@@ -353,15 +350,16 @@ export class Changelog extends React.Component {
                     <Button
                         className="ds-margin-top-xlg"
                         variant="primary"
-                        onClick={this.saveSettings}
+                        onClick={this.handleSaveSettings}
                         isDisabled={this.state.saveBtnDisabled || this.state.saving}
                         isLoading={this.state.saving}
-                        spinnerAriaValueText={this.state.saving ? "Saving" : undefined}
+                        spinnerAriaValueText={this.state.saving ? _("Saving") : undefined}
                         {...extraPrimaryProps}
                     >
                         {saveBtnName}
                     </Button>
-                </div>;
+                </div>
+            );
         }
 
         return (
