@@ -20,6 +20,8 @@ import {
 } from '@fortawesome/free-solid-svg-icons';
 import '@fortawesome/fontawesome-svg-core/styles.css';
 
+const _ = cockpit.gettext;
+
 export class ReplRUV extends React.Component {
     constructor(props) {
         super(props);
@@ -43,16 +45,16 @@ export class ReplRUV extends React.Component {
         };
         this.showConfirmCleanRUV = this.showConfirmCleanRUV.bind(this);
         this.closeConfirmCleanRUV = this.closeConfirmCleanRUV.bind(this);
-        this.showConfirmCLImport = this.showConfirmCLImport.bind(this);
+        this.handleShowConfirmCLImport = this.handleShowConfirmCLImport.bind(this);
         this.closeConfirmCLImport = this.closeConfirmCLImport.bind(this);
-        this.showCLExport = this.showCLExport.bind(this);
+        this.handleShowCLExport = this.handleShowCLExport.bind(this);
         this.closeCLExport = this.closeCLExport.bind(this);
         this.showConfirmExport = this.showConfirmExport.bind(this);
         this.closeConfirmExport = this.closeConfirmExport.bind(this);
         this.handleLDIFChange = this.handleLDIFChange.bind(this);
-        this.handleCLLDIFChange = this.handleCLLDIFChange.bind(this);
-        this.handleRadioChange = this.handleRadioChange.bind(this);
-        this.handleChange = this.handleChange.bind(this);
+        this.onCLLDIFChange = this.onCLLDIFChange.bind(this);
+        this.onRadioChange = this.onRadioChange.bind(this);
+        this.onChange = this.onChange.bind(this);
         this.cleanRUV = this.cleanRUV.bind(this);
         this.exportChangelog = this.exportChangelog.bind(this);
         this.importChangelog = this.importChangelog.bind(this);
@@ -60,7 +62,7 @@ export class ReplRUV extends React.Component {
 
     showConfirmCleanRUV (rid) {
         this.setState({
-            rid: rid,
+            rid,
             showConfirmCleanRUV: true,
             modalChecked: false,
             modalSpinning: false,
@@ -75,7 +77,7 @@ export class ReplRUV extends React.Component {
         });
     }
 
-    showConfirmCLImport () {
+    handleShowConfirmCLImport () {
         this.setState({
             showConfirmCLImport: true,
             modalChecked: false,
@@ -91,7 +93,7 @@ export class ReplRUV extends React.Component {
         });
     }
 
-    showCLExport () {
+    handleShowCLExport () {
         this.setState({
             saveOK: true,
             showCLExport: true,
@@ -123,18 +125,18 @@ export class ReplRUV extends React.Component {
         });
     }
 
-    handleRadioChange(_, e) {
+    onRadioChange(_, e) {
         // Handle the changelog export options
         let defaultCL = false;
         let debugCL = false;
-        if (e.target.id == "defaultCL") {
+        if (e.target.id === "defaultCL") {
             defaultCL = true;
-        } else if (e.target.id == "debugCL") {
+        } else if (e.target.id === "debugCL") {
             debugCL = true;
         }
         this.setState({
-            defaultCL: defaultCL,
-            debugCL: debugCL,
+            defaultCL,
+            debugCL,
         });
     }
 
@@ -151,14 +153,14 @@ export class ReplRUV extends React.Component {
                     this.props.reload(this.props.suffix);
                     this.props.addNotification(
                         'success',
-                        'Successfully started CleanAllRUV task');
+                        _("Successfully started CleanAllRUV task"));
                     this.closeConfirmCleanRUV();
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Failed to start CleanAllRUV task - ${errMsg.desc}`
+                        cockpit.format(_("Failed to start CleanAllRUV task - $0"), errMsg.desc)
                     );
                     this.closeConfirmCleanRUV();
                 });
@@ -167,28 +169,28 @@ export class ReplRUV extends React.Component {
     handleLDIFChange (e) {
         const value = e.target.value;
         let saveOK = true;
-        if (value == "" || bad_file_name(value)) {
+        if (value === "" || bad_file_name(value)) {
             saveOK = false;
         }
         this.setState({
             [e.target.id]: value,
-            saveOK: saveOK
+            saveOK
         });
     }
 
-    handleCLLDIFChange (e) {
+    onCLLDIFChange (e) {
         const value = e.target.value;
         let saveOK = true;
-        if (value == "" || value.indexOf(' ') >= 0) {
+        if (value === "" || value.indexOf(' ') >= 0) {
             saveOK = false;
         }
         this.setState({
             [e.target.id]: value,
-            saveOK: saveOK
+            saveOK
         });
     }
 
-    handleChange (e) {
+    onChange (e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         this.setState({
             [e.target.id]: value,
@@ -212,7 +214,7 @@ export class ReplRUV extends React.Component {
                 .done(content => {
                     this.props.addNotification(
                         "success",
-                        `Changelog was successfully initialized`
+                        _("Changelog was successfully initialized")
                     );
                     this.setState({
                         showConfirmCLImport: false,
@@ -223,7 +225,7 @@ export class ReplRUV extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error importing changelog LDIF - ${errMsg.desc}`
+                        cockpit.format(_("Error importing changelog LDIF - $0"), errMsg.desc)
                     );
                     this.setState({
                         showConfirmCLImport: false,
@@ -265,7 +267,7 @@ export class ReplRUV extends React.Component {
                 .done(content => {
                     this.props.addNotification(
                         "success",
-                        `Changelog was successfully exported`
+                        _("Changelog was successfully exported")
                     );
                     this.setState({
                         showCLExport: false,
@@ -276,7 +278,7 @@ export class ReplRUV extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error importing changelog LDIF - ${errMsg.desc}`
+                        cockpit.format(_("Error importing changelog LDIF - $0"), errMsg.desc)
                     );
                     this.setState({
                         showCLExport: false,
@@ -296,7 +298,7 @@ export class ReplRUV extends React.Component {
         let localMinCSN = "";
         let localRawMinCSN = "";
         for (const row of this.props.rows) {
-            if (row.rid == this.props.localRID) {
+            if (row.rid === this.props.localRID) {
                 localRID = row.rid;
                 localURL = row.url;
                 localCSN = row.maxcsn;
@@ -307,11 +309,11 @@ export class ReplRUV extends React.Component {
                 remote_rows.push(row);
             }
         }
-        let localRUV =
+        let localRUV = (
             <div className="ds-left-indent-md">
                 <Grid className="ds-margin-top-med">
                     <GridItem span={2}>
-                        Replica ID
+                        {_("Replica ID")}
                     </GridItem>
                     <GridItem span={10}>
                         <b>{localRID}</b>
@@ -319,7 +321,7 @@ export class ReplRUV extends React.Component {
                 </Grid>
                 <Grid>
                     <GridItem span={2}>
-                        LDAP URL
+                        {_("LDAP URL")}
                     </GridItem>
                     <GridItem span={10}>
                         <b>{localURL}</b>
@@ -327,7 +329,7 @@ export class ReplRUV extends React.Component {
                 </Grid>
                 <Grid>
                     <GridItem span={2}>
-                        Min CSN
+                        {_("Min CSN")}
                     </GridItem>
                     <GridItem span={10}>
                         <b>{localMinCSN}</b> ({localRawMinCSN})
@@ -335,32 +337,35 @@ export class ReplRUV extends React.Component {
                 </Grid>
                 <Grid>
                     <GridItem span={2}>
-                        Max CSN
+                        {_("Max CSN")}
                     </GridItem>
                     <GridItem span={10}>
                         <b>{localCSN}</b> ({localRawCSN})
                     </GridItem>
                 </Grid>
-            </div>;
+            </div>
+        );
 
-        if (localRID == "") {
-            localRUV =
-                <div className="ds-indent">
+        if (localRID === "") {
+            localRUV = (
+                <div className="ds-indent ds-margin-top">
                     <i>
-                        There is no local RUV, the database might not have been initialized yet.
+                        {_("There is no local RUV, the database might not have been initialized yet.")}
                     </i>
-                </div>;
+                </div>
+            );
         }
 
         return (
             <div className="ds-margin-top-xlg ds-indent">
                 <TextContent>
                     <Text component={TextVariants.h3}>
-                        Local RUV <FontAwesomeIcon
+                        {_("Local RUV")}
+                        <FontAwesomeIcon
                             size="lg"
                             className="ds-left-margin ds-refresh"
                             icon={faSyncAlt}
-                            title="RRefresh the RUV for this suffixs"
+                            title={_("RRefresh the RUV for this suffixs")}
                             onClick={() => {
                                 this.props.reload(this.props.suffix);
                             }}
@@ -370,11 +375,12 @@ export class ReplRUV extends React.Component {
                 {localRUV}
                 <TextContent className="ds-margin-top-xlg">
                     <Text component={TextVariants.h3}>
-                        Remote RUV's <FontAwesomeIcon
+                        {_("Remote RUV's")}
+                        <FontAwesomeIcon
                             size="lg"
                             className="ds-left-margin ds-refresh"
                             icon={faSyncAlt}
-                            title="Refresh the remote RUVs for this suffixs"
+                            title={_("Refresh the remote RUVs for this suffixs")}
                             onClick={() => {
                                 this.props.reload(this.props.suffix);
                             }}
@@ -389,43 +395,43 @@ export class ReplRUV extends React.Component {
                 </div>
                 <TextContent className="ds-margin-top-xlg">
                     <Text component={TextVariants.h3}>
-                        Replication Change Log Tasks
+                        {_("Replication Change Log Tasks")}
                     </Text>
                 </TextContent>
                 <Form className="ds-margin-top-lg ds-left-indent-md" isHorizontal autoComplete="off">
                     <Grid>
                         <GridItem
                             span={3}
-                            title="Export the changelog to an LDIF file.  Typically used for changelog encryption purposes, or debugging."
+                            title={_("Export the changelog to an LDIF file.  Typically used for changelog encryption purposes, or debugging.")}
                         >
                             <Button
                                 variant="primary"
-                                onClick={this.showCLExport}
+                                onClick={this.handleShowCLExport}
                             >
-                                Export Changelog
+                                {_("Export Changelog")}
                             </Button>
                         </GridItem>
                         <GridItem span={9}>
                             <p className="ds-margin-top">
-                                Export the replication changelog to a LDIF file.  Used for preparing to encrypt the changelog, or simply for debugging.
+                                {_("Export the replication changelog to a LDIF file.  Used for preparing to encrypt the changelog, or simply for debugging.")}
                             </p>
                         </GridItem>
                     </Grid>
                     <Grid className="ds-margin-top-lg">
                         <GridItem
                             span={3}
-                            title="Initialize the changelog with an LDIF file for changelog encryption purposes."
+                            title={_("Initialize the changelog with an LDIF file for changelog encryption purposes.")}
                         >
                             <Button
                                 variant="primary"
-                                onClick={this.showConfirmCLImport}
+                                onClick={this.handleShowConfirmCLImport}
                             >
-                                Import Changelog
+                                {_("Import Changelog")}
                             </Button>
                         </GridItem>
                         <GridItem span={9}>
                             <p className="ds-margin-top">
-                                Initialize the replication changelog from an LDIF file.  Used to initialize the change log after encryption has been enabled.
+                                {_("Initialize the replication changelog from an LDIF file.  Used to initialize the change log after encryption has been enabled.")}
                             </p>
                         </GridItem>
                     </Grid>
@@ -434,35 +440,35 @@ export class ReplRUV extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmCleanRUV}
                     closeHandler={this.closeConfirmCleanRUV}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.cleanRUV}
                     spinning={this.state.modalSpinning}
                     item={"Replica ID " + this.state.rid}
                     checked={this.state.modalChecked}
-                    mTitle="Remove RUV Element (CleanAllRUV)"
-                    mMsg="Are you sure you want to attempt to clean this Replica ID from the suffix?"
-                    mSpinningMsg="Starting cleaning task (CleanAllRUV) ..."
-                    mBtnName="Remove RUV Element"
+                    mTitle={_("Remove RUV Element (CleanAllRUV)")}
+                    mMsg={_("Are you sure you want to attempt to clean this Replica ID from the suffix?")}
+                    mSpinningMsg={_("Starting cleaning task (CleanAllRUV) ...")}
+                    mBtnName={_("Remove RUV Element")}
                 />
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmCLImport}
                     closeHandler={this.closeConfirmCLImport}
-                    handleChange={this.handleChange}
+                    handleChange={this.onChange}
                     actionHandler={this.importChangelog}
                     spinning={this.state.modalSpinning}
                     item={"Replicated Suffix " + this.props.suffix}
                     checked={this.state.modalChecked}
-                    mTitle="Initialize Replication Changelog From LDIF"
-                    mMsg="Are you sure you want to attempt to initialize the changelog from LDIF?  This will reject all operations during during the initialization."
-                    mSpinningMsg="Initialzing Replication Change Log ..."
-                    mBtnName="Import Changelog LDIF"
+                    mTitle={_("Initialize Replication Changelog From LDIF")}
+                    mMsg={_("Are you sure you want to attempt to initialize the changelog from LDIF?  This will reject all operations during during the initialization.")}
+                    mSpinningMsg={_("Initialzing Replication Change Log ...")}
+                    mBtnName={_("Import Changelog LDIF")}
                 />
                 <ExportCLModal
                     showModal={this.state.showCLExport}
                     closeHandler={this.closeCLExport}
-                    handleChange={this.handleChange}
-                    handleLDIFChange={this.handleCLLDIFChange}
-                    handleRadioChange={this.handleRadioChange}
+                    handleChange={this.onChange}
+                    handleLDIFChange={this.onCLLDIFChange}
+                    handleRadioChange={this.onRadioChange}
                     saveHandler={this.exportChangelog}
                     defaultCL={this.state.defaultCL}
                     debugCL={this.state.debugCL}
