@@ -1,3 +1,4 @@
+import cockpit from "cockpit";
 import React from "react";
 import {
     Grid,
@@ -18,6 +19,8 @@ import {
 } from '@patternfly/react-table';
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 class KeyTable extends React.Component {
     constructor(props) {
         super(props);
@@ -30,21 +33,21 @@ class KeyTable extends React.Component {
             rows: [],
             hasRows: false,
             columns: [
-                { title: 'Cipher', transforms: [sortable] },
-                { title: 'Key Identifier', transforms: [sortable] },
-                { title: 'State', transforms: [sortable] },
+                { title: _("Cipher"), transforms: [sortable] },
+                { title: _("Key Identifier"), transforms: [sortable] },
+                { title: _("State"), transforms: [sortable] },
             ],
         };
 
-        this.onSetPage = (_event, pageNumber) => {
+        this.handleSetPage = (_event, pageNumber) => {
             this.setState({
                 page: pageNumber
             });
         };
 
-        this.onPerPageSelect = (_event, perPage) => {
+        this.handlePerPageSelect = (_event, perPage) => {
             this.setState({
-                perPage: perPage
+                perPage
             });
         };
     }
@@ -63,15 +66,15 @@ class KeyTable extends React.Component {
             );
         }
 
-        if (rows.length == 0) {
-            rows = [{ cells: ['No Orphan keys'] }];
-            columns = [{ title: 'Orphan keys' }];
+        if (rows.length === 0) {
+            rows = [{ cells: [_("No Orphan keys")] }];
+            columns = [{ title: _("Orphan keys") }];
             hasRows = false;
         }
 
         this.setState({
-            rows: rows,
-            columns: columns,
+            rows,
+            columns,
             hasRows
         });
     }
@@ -79,10 +82,10 @@ class KeyTable extends React.Component {
     actions() {
         return [
             {
-                title: 'Delete Key',
+                title: _("Delete Key"),
                 onClick: (event, rowId, rowData, extra) => {
                     if (rowData.cells[1]) {
-                        this.props.delKey(rowData.cells[1])
+                        this.props.delKey(rowData.cells[1]);
                     }
                 }
             }
@@ -96,19 +99,16 @@ class KeyTable extends React.Component {
             <div className="ds-margin-top-lg">
                 <Tooltip
                         content={
-                        <div>
-                            <p align="justify">
-                            An orphan key is a private key in the NSS DB for which there is NO cert
-                            with the corresponding public key. An orphan key is created during CSR creation,
-                            when the certificate associated with a CSR has been imported into the NSS DB its
-                            orphan state will be removed.
-                            <br /><br />
-                            Make sure an orphan key is not associated with a submitted CSR before you delete it.
-                            </p>
-                        </div>
+                            <div>
+                                <p>
+                                    {_("An orphan key is a private key in the NSS DB for which there is NO cert with the corresponding public key. An orphan key is created during CSR creation, when the certificate associated with a CSR has been imported into the NSS DB its orphan state will be removed.")}
+                                    <br /><br />
+                                    {_("Make sure an orphan key is not associated with a submitted CSR before you delete it.")}
+                                </p>
+                            </div>
                         }
-                    >
-                        <a className="ds-font-size-sm">What is an orphan key?</a>
+                >
+                    <a className="ds-font-size-sm">{_("What is an orphan key?")}</a>
                 </Tooltip>
                 <Table
                     className="ds-margin-top"
@@ -118,8 +118,8 @@ class KeyTable extends React.Component {
                     rows={rows}
                     variant={TableVariant.compact}
                     sortBy={sortBy}
-                    onSort={this.onSort}
-                    actions={hasRows? this.actions() : null}
+                    onSort={this.handleSort}
+                    actions={hasRows ? this.actions() : null}
                     dropdownPosition="right"
                     dropdownDirection="bottom"
                 >
@@ -130,13 +130,12 @@ class KeyTable extends React.Component {
                     <Pagination
                         itemCount={this.state.rows.length}
                         widgetId="pagination-options-menu-bottom"
-                        perPage={this.state.perPage}
+                        perPage={perPage}
                         page={page}
                         variant={PaginationVariant.bottom}
-                        onSetPage={this.onSetPage}
-                        onPerPageSelect={this.onPerPageSelect}
-                    />
-                }
+                        onSetPage={this.handleSetPage}
+                        onPerPageSelect={this.handlePerPageSelect}
+                    />}
             </div>
         );
     }
@@ -153,32 +152,31 @@ class CSRTable extends React.Component {
             sortBy: {},
             rows: [],
             columns: [
-                { title: 'Name', transforms: [sortable] },
-                { title: 'Subject DN', transforms: [sortable] },
-                { title: 'Subject Alternative Names', transforms: [sortable] },
-                { title: 'Modification Date', transforms: [sortable] },
+                { title: _("Name"), transforms: [sortable] },
+                { title: _("Subject DN"), transforms: [sortable] },
+                { title: _("Subject Alternative Names"), transforms: [sortable] },
+                { title: _("Modification Date"), transforms: [sortable] },
             ],
         };
 
-        this.onSetPage = (_event, pageNumber) => {
+        this.handleSetPage = (_event, pageNumber) => {
             this.setState({
                 page: pageNumber
             });
         };
 
-        this.onPerPageSelect = (_event, perPage) => {
+        this.handlePerPageSelect = (_event, perPage) => {
             this.setState({
-                perPage: perPage,
+                perPage,
                 page: 1
             });
         };
 
-        this.onSort = this.onSort.bind(this);
-        this.onSearchChange = this.onSearchChange.bind(this);
+        this.handleSort = this.handleSort.bind(this);
+        this.handleSearchChange = this.handleSearchChange.bind(this);
     }
 
-
-    onSort(_event, index, direction) {
+    handleSort(_event, index, direction) {
         const sortedRows = this.state.rows.sort((a, b) => (a[index] < b[index] ? -1 : a[index] > b[index] ? 1 : 0));
         this.setState({
             sortBy: {
@@ -205,30 +203,30 @@ class CSRTable extends React.Component {
                 },
             );
         }
-        if (rows.length == 0) {
-            rows = [{ cells: ['No Certificate Signing Requests'] }];
-            columns = [{ title: 'Certificate Signing Requests' }];
+        if (rows.length === 0) {
+            rows = [{ cells: [_("No Certificate Signing Requests")] }];
+            columns = [{ title: _("Certificate Signing Requests") }];
             hasRows = false;
         }
         this.setState({
-            rows: rows,
-            columns: columns,
+            rows,
+            columns,
             hasRows,
         });
     }
 
-    onSearchChange(value, event) {
+    handleSearchChange(event, value) {
         const rows = [];
-        let count = 0;
 
         for (const cert of this.props.ServerCSRs) {
             const val = value.toLowerCase();
 
             // Check for matches of all the parts
-            if (val != "" && cert.attrs.name.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.subject.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.subject_alt_names.join().toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.modified.toLowerCase().indexOf(val) == -1) {
+            if (val !== "" && cert.attrs.name.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.subject.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.subject_alt_names.join().toLowerCase()
+                        .indexOf(val) === -1 &&
+                cert.attrs.modified.toLowerCase().indexOf(val) === -1) {
                 // Not a match
                 continue;
             }
@@ -247,8 +245,8 @@ class CSRTable extends React.Component {
         }
 
         this.setState({
-            rows: rows,
-            value: value,
+            rows,
+            value,
             page: 1,
         });
     }
@@ -256,18 +254,18 @@ class CSRTable extends React.Component {
     actions() {
         return [
             {
-                title: 'Delete CSR',
+                title: _("Delete CSR"),
                 onClick: (event, rowId, rowData, extra) => {
                     if (rowData.cells.length > 1) {
-                        this.props.delCSR(rowData.cells[0])
+                        this.props.delCSR(rowData.cells[0]);
                     }
                 }
             },
             {
-                title: 'View CSR',
+                title: _("View CSR"),
                 onClick: (event, rowId, rowData, extra) => {
                     if (rowData.cells.length > 1) {
-                        this.props.viewCSR(rowData.cells[0])
+                        this.props.viewCSR(rowData.cells[0]);
                     }
                 }
             }
@@ -281,12 +279,11 @@ class CSRTable extends React.Component {
             <div className="ds-margin-top-lg">
                 {hasRows &&
                     <SearchInput
-                        placeholder='Search CSRs'
+                        placeholder={_("Search CSRs")}
                         value={this.state.value}
-                        onChange={this.onSearchChange}
-                        onClear={(evt) => this.onSearchChange('', evt)}
-                    />
-                }
+                        onChange={this.handleSearchChange}
+                        onClear={(evt) => this.handleSearchChange(evt, '')}
+                    />}
                 <Table
                     className="ds-margin-top"
                     aria-label="csr table"
@@ -295,7 +292,7 @@ class CSRTable extends React.Component {
                     rows={rows}
                     variant={TableVariant.compact}
                     sortBy={sortBy}
-                    onSort={this.onSort}
+                    onSort={this.handleSort}
                     actions={hasRows ? this.actions() : null}
                     dropdownPosition="right"
                     dropdownDirection="bottom"
@@ -310,10 +307,9 @@ class CSRTable extends React.Component {
                         perPage={perPage}
                         page={page}
                         variant={PaginationVariant.bottom}
-                        onSetPage={this.onSetPage}
-                        onPerPageSelect={this.onPerPageSelect}
-                    />
-                }
+                        onSetPage={this.handleSetPage}
+                        onPerPageSelect={this.handlePerPageSelect}
+                    />}
             </div>
         );
     }
@@ -333,34 +329,34 @@ class CertTable extends React.Component {
             hasRows: false,
             columns: [
                 {
-                    title: 'Nickname',
+                    title: _("Nickname"),
                     transforms: [sortable],
                     cellFormatters: [expandable]
                 },
-                { title: 'Subject DN', transforms: [sortable] },
-                { title: 'Expiration Date', transforms: [sortable] },
+                { title: _("Subject DN"), transforms: [sortable] },
+                { title: _("Expiration Date"), transforms: [sortable] },
             ],
         };
 
-        this.onSetPage = (_event, pageNumber) => {
+        this.handleSetPage = (_event, pageNumber) => {
             this.setState({
                 page: pageNumber
             });
         };
 
-        this.onPerPageSelect = (_event, perPage) => {
+        this.handlePerPageSelect = (_event, perPage) => {
             this.setState({
-                perPage: perPage,
+                perPage,
                 page: 1
             });
         };
 
-        this.onSort = this.onSort.bind(this);
-        this.onCollapse = this.onCollapse.bind(this);
-        this.onSearchChange = this.onSearchChange.bind(this);
+        this.handleSort = this.handleSort.bind(this);
+        this.handleCollapse = this.handleCollapse.bind(this);
+        this.handleSearchChange = this.handleSearchChange.bind(this);
     }
 
-    onSort(_event, index, direction) {
+    handleSort(_event, index, direction) {
         const sorted_rows = [];
         const rows = [];
         let count = 0;
@@ -401,7 +397,7 @@ class CertTable extends React.Component {
                 index,
                 direction
             },
-            rows: rows,
+            rows,
             page: 1,
         });
     }
@@ -409,9 +405,9 @@ class CertTable extends React.Component {
     getExpandedRow(issuer, flags) {
         return (
             <Grid className="ds-left-indent-lg">
-                <GridItem span={3}>Issuer DN:</GridItem>
+                <GridItem span={3}>{_("Issuer DN:")}</GridItem>
                 <GridItem span={9}><b>{issuer}</b></GridItem>
-                <GridItem span={3}>Trust Flags:</GridItem>
+                <GridItem span={3}>{_("Trust Flags:")}</GridItem>
                 <GridItem span={9}><b>{flags}</b></GridItem>
 
             </Grid>
@@ -441,19 +437,19 @@ class CertTable extends React.Component {
             );
             count += 2;
         }
-        if (rows.length == 0) {
-            rows = [{ cells: ['No Certificates'] }];
-            columns = [{ title: 'Certificates' }];
+        if (rows.length === 0) {
+            rows = [{ cells: [_("No Certificates")] }];
+            columns = [{ title: _("Certificates") }];
             hasRows = false;
         }
         this.setState({
-            rows: rows,
-            columns: columns,
+            rows,
+            columns,
             hasRows,
         });
     }
 
-    onCollapse(event, rowKey, isOpen) {
+    handleCollapse(event, rowKey, isOpen) {
         const { rows, perPage, page } = this.state;
         const index = (perPage * (page - 1) * 2) + rowKey; // Adjust for page set
         rows[index].isOpen = isOpen;
@@ -462,7 +458,7 @@ class CertTable extends React.Component {
         });
     }
 
-    onSearchChange(value, event) {
+    handleSearchChange(event, value) {
         const rows = [];
         let count = 0;
 
@@ -470,10 +466,10 @@ class CertTable extends React.Component {
             const val = value.toLowerCase();
 
             // Check for matches of all the parts
-            if (val != "" && cert.attrs.nickname.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.subject.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.issuer.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.expires.toLowerCase().indexOf(val) == -1) {
+            if (val !== "" && cert.attrs.nickname.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.subject.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.issuer.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.expires.toLowerCase().indexOf(val) === -1) {
                 // Not a match
                 continue;
             }
@@ -496,8 +492,8 @@ class CertTable extends React.Component {
         }
 
         this.setState({
-            rows: rows,
-            value: value,
+            rows,
+            value,
             page: 1,
         });
     }
@@ -505,12 +501,12 @@ class CertTable extends React.Component {
     actions() {
         return [
             {
-                title: 'Edit Trust Flags',
+                title: _("Edit Trust Flags"),
                 onClick: (event, rowId, rowData, extra) =>
                     this.props.editCert(rowData.cells[0], rowData.flags)
             },
             {
-                title: 'Export Certificate',
+                title: _("Export Certificate"),
                 onClick: (event, rowId, rowData, extra) =>
                     this.props.exportCert(rowData.cells[0])
             },
@@ -518,7 +514,7 @@ class CertTable extends React.Component {
                 isSeparator: true
             },
             {
-                title: 'Delete Certificate',
+                title: _("Delete Certificate"),
                 onClick: (event, rowId, rowData, extra) =>
                     this.props.delCert(rowData.cells[0])
             }
@@ -540,12 +536,11 @@ class CertTable extends React.Component {
             <div className="ds-margin-top-lg">
                 {hasRows &&
                     <SearchInput
-                        placeholder='Search Certificates'
+                        placeholder={_("Search Certificates")}
                         value={this.state.value}
-                        onChange={this.onSearchChange}
-                        onClear={(evt) => this.onSearchChange('', evt)}
-                    />
-                }
+                        onChange={this.handleSearchChange}
+                        onClear={(evt) => this.handleSearchChange(evt, '')}
+                    />}
                 <Table
                     className="ds-margin-top"
                     aria-label="cert table"
@@ -554,8 +549,8 @@ class CertTable extends React.Component {
                     rows={tableRows}
                     variant={TableVariant.compact}
                     sortBy={sortBy}
-                    onSort={this.onSort}
-                    onCollapse={this.onCollapse}
+                    onSort={this.handleSort}
+                    onCollapse={this.handleCollapse}
                     actions={hasRows ? this.actions() : null}
                     dropdownPosition="right"
                     dropdownDirection="bottom"
@@ -570,10 +565,9 @@ class CertTable extends React.Component {
                         perPage={perPage}
                         page={page}
                         variant={PaginationVariant.bottom}
-                        onSetPage={this.onSetPage}
-                        onPerPageSelect={this.onPerPageSelect}
-                    />
-                }
+                        onSetPage={this.handleSetPage}
+                        onPerPageSelect={this.handlePerPageSelect}
+                    />}
             </div>
         );
     }
@@ -593,30 +587,30 @@ class CRLTable extends React.Component {
             dropdownIsOpen: false,
             hasRows: false,
             columns: [
-                { title: 'Issued By', transforms: [sortable] },
-                { title: 'Effective Date', transforms: [sortable] },
-                { title: 'Next Update', transforms: [sortable] },
-                { title: 'Type', transforms: [sortable] },
+                { title: _("Issued By"), transforms: [sortable] },
+                { title: _("Effective Date"), transforms: [sortable] },
+                { title: _("Next Update"), transforms: [sortable] },
+                { title: _("Type"), transforms: [sortable] },
             ],
         };
 
-        this.onSetPage = (_event, pageNumber) => {
+        this.handleSetPage = (_event, pageNumber) => {
             this.setState({
                 page: pageNumber
             });
         };
 
-        this.onPerPageSelect = (_event, perPage) => {
+        this.handlePerPageSelect = (_event, perPage) => {
             this.setState({
-                perPage: perPage
+                perPage
             });
         };
 
-        this.onSort = this.onSort.bind(this);
-        this.onSearchChange = this.onSearchChange.bind(this);
+        this.handleSort = this.handleSort.bind(this);
+        this.handleSearchChange = this.handleSearchChange.bind(this);
     }
 
-    onSort(_event, index, direction) {
+    handleSort(_event, index, direction) {
         const sorted_rows = [];
         const rows = [];
         let count = 0;
@@ -656,12 +650,12 @@ class CRLTable extends React.Component {
                 index,
                 direction
             },
-            rows: rows,
+            rows,
             page: 1,
         });
     }
 
-    onSearchChange(value, event) {
+    handleSearchChange(event, value) {
         const rows = [];
         let count = 0;
 
@@ -669,10 +663,10 @@ class CRLTable extends React.Component {
             const val = value.toLowerCase();
 
             // Check for matches of all the parts
-            if (val != "" && cert.attrs.nickname.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.subject.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.issuer.toLowerCase().indexOf(val) == -1 &&
-                cert.attrs.expires.toLowerCase().indexOf(val) == -1) {
+            if (val !== "" && cert.attrs.nickname.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.subject.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.issuer.toLowerCase().indexOf(val) === -1 &&
+                cert.attrs.expires.toLowerCase().indexOf(val) === -1) {
                 // Not a match
                 continue;
             }
@@ -695,22 +689,22 @@ class CRLTable extends React.Component {
         }
 
         this.setState({
-            rows: rows,
-            value: value,
+            rows,
+            value,
             page: 1,
-            hasRows: rows.length === 0 ? false : true,
+            hasRows: rows.length !== 0,
         });
     }
 
     actions() {
         return [
             {
-                title: 'View CRL',
+                title: _("View CRL"),
                 onClick: (event, rowId, rowData, extra) =>
                     this.props.editConfig(rowData.cells[0], rowData.cells[1], rowData.credsBindpw, rowData.pwInteractive)
             },
             {
-                title: 'Delete CRL',
+                title: _("Delete CRL"),
                 onClick: (event, rowId, rowData, extra) =>
                     this.props.deleteConfig(rowData.cells[0])
             }
@@ -721,16 +715,16 @@ class CRLTable extends React.Component {
         return (
             <div className="ds-margin-top">
                 <SearchInput
-                    placeholder="Search CRL's"
+                    placeholder={_("Search CRL's")}
                     value={this.state.value}
-                    onChange={this.onSearchChange}
-                    onClear={(evt) => this.onSearchChange('', evt)}
+                    onChange={this.handleSearchChange}
+                    onClear={(evt) => this.handleSearchChange(evt, '')}
                 />
                 <Table
                     variant={TableVariant.compact} aria-label="Cred Table"
-                    sortBy={this.sortBy} onSort={this.onSort} cells={this.state.columns}
+                    sortBy={this.sortBy} onSort={this.handleSort} cells={this.state.columns}
                     rows={this.state.rows}
-                    actions={has_rows ? this.actions() : null}
+                    actions={this.state.hasRows ? this.actions() : null}
                     dropdownPosition="right"
                     dropdownDirection="bottom"
                 >
@@ -744,10 +738,9 @@ class CRLTable extends React.Component {
                         perPage={this.state.perPage}
                         page={this.state.page}
                         variant={PaginationVariant.bottom}
-                        onSetPage={this.onSetPage}
-                        onPerPageSelect={this.onPerPageSelect}
-                    />
-                }
+                        onSetPage={this.handleSetPage}
+                        onPerPageSelect={this.handlePerPageSelect}
+                    />}
             </div>
         );
     }
