@@ -70,13 +70,15 @@ const exp_attrs = [
     'nsslapd-accesslog-logminfreediskspace',
 ];
 
+const _ = cockpit.gettext;
+
 export class ServerAccessLog extends React.Component {
     constructor(props) {
         super(props);
 
-        this.defaultLevel = <>Default Logging <font size="1" className="ds-info-color">(level 256)</font></>;
-        this.internalOpLevel = <>Internal Operations <font size="1" className="ds-info-color">(level 4)</font></>;
-        this.refLevel = <>Entry Access and Referrals <font size="1" className="ds-info-color">(level 512)</font></>;
+        this.defaultLevel = <>{_("Default Logging")} <font size="1" className="ds-info-color">(level 256)</font></>;
+        this.internalOpLevel = <>{_("Internal Operations")} <font size="1" className="ds-info-color">(level 4)</font></>;
+        this.refLevel = <>{_("Entry Access and Referrals")} <font size="1" className="ds-info-color">(level 512)</font></>;
 
         this.state = {
             loading: true,
@@ -89,12 +91,12 @@ export class ServerAccessLog extends React.Component {
             canSelectAll: false,
             isExpanded: false,
             rows: [
-                { cells: [{ title: this.defaultLevel}], level: 256, selected: true },
-                { cells: [{ title: this.internalOpLevel}], level: 4, selected: false },
-                { cells: [{ title: this.refLevel}], level: 512, selected: false }
+                { cells: [{ title: this.defaultLevel }], level: 256, selected: true },
+                { cells: [{ title: this.internalOpLevel }], level: 4, selected: false },
+                { cells: [{ title: this.refLevel }], level: 512, selected: false }
             ],
             columns: [
-                { title: 'Logging Level' },
+                { title: _("Logging Level") },
             ],
         };
 
@@ -105,7 +107,7 @@ export class ServerAccessLog extends React.Component {
             });
         };
 
-        this.onToggle = isExpanded => {
+        this.handleOnToggle = isExpanded => {
             this.setState({
                 isExpanded
             });
@@ -117,7 +119,7 @@ export class ServerAccessLog extends React.Component {
         this.loadConfig = this.loadConfig.bind(this);
         this.refreshConfig = this.refreshConfig.bind(this);
         this.saveConfig = this.saveConfig.bind(this);
-        this.onSelect = this.onSelect.bind(this);
+        this.handleOnSelect = this.handleOnSelect.bind(this);
         this.onMinusConfig = (id, nav_tab) => {
             this.setState({
                 [id]: Number(this.state[id]) - 1
@@ -129,7 +131,7 @@ export class ServerAccessLog extends React.Component {
                 maxValue = max;
             }
             let newValue = isNaN(event.target.value) ? min : Number(event.target.value);
-            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue
+            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue;
             this.setState({
                 [id]: newValue
             }, () => { this.validateSaveBtn(nav_tab, id, newValue) });
@@ -138,7 +140,7 @@ export class ServerAccessLog extends React.Component {
             this.setState({
                 [id]: Number(this.state[id]) + 1
             }, () => { this.validateSaveBtn(nav_tab, id, Number(this.state[id])) });
-        }
+        };
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
     }
 
@@ -204,7 +206,7 @@ export class ServerAccessLog extends React.Component {
 
         this.setState({
             [attr]: value,
-        }, () => { this.validateSaveBtn(nav_tab, attr, value) } );
+        }, () => { this.validateSaveBtn(nav_tab, attr, value) });
     }
 
     handleSwitchChange(value) {
@@ -262,7 +264,7 @@ export class ServerAccessLog extends React.Component {
             config_attrs = exp_attrs;
         }
 
-        let cmd = [
+        const cmd = [
             'dsconf', '-j', "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             'config', 'replace'
         ];
@@ -305,7 +307,7 @@ export class ServerAccessLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "success",
-                        "Successfully updated Access Log settings"
+                        _("Successfully updated Access Log settings")
                     );
                 })
                 .fail(err => {
@@ -313,7 +315,7 @@ export class ServerAccessLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "error",
-                        `Error saving Access Log settings - ${errMsg.desc}`
+                        cockpit.format(_("Error saving Access Log settings - $0"), errMsg.desc)
                     );
                 });
     }
@@ -379,7 +381,7 @@ export class ServerAccessLog extends React.Component {
                         'nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
                         'nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
                         'nsslapd-accesslog-compress': compress,
-                        rows: rows,
+                        rows,
                         // Record original values
                         _rows:  JSON.parse(JSON.stringify(rows)),
                         '_nsslapd-accesslog': attrs['nsslapd-accesslog'][0],
@@ -404,7 +406,7 @@ export class ServerAccessLog extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading Access Log configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading Access Log configuration - $0"), errMsg.desc)
                     );
                     this.setState({
                         loading: false,
@@ -460,7 +462,7 @@ export class ServerAccessLog extends React.Component {
             'nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
             'nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
             'nsslapd-accesslog-compress': compress,
-            rows: rows,
+            rows,
             // Record original values
             _rows: JSON.parse(JSON.stringify(rows)),
             '_nsslapd-accesslog': attrs['nsslapd-accesslog'][0],
@@ -482,9 +484,9 @@ export class ServerAccessLog extends React.Component {
         }, this.props.enableTree);
     }
 
-    onSelect(event, isSelected, rowId) {
+    handleOnSelect(event, isSelected, rowId) {
         let disableSaveBtn = true;
-        let rows = [...this.state.rows];
+        const rows = [...this.state.rows];
 
         // Update the row
         rows[rowId].selected = isSelected;
@@ -516,19 +518,19 @@ export class ServerAccessLog extends React.Component {
     }
 
     render() {
-        let saveSettingsName = "Save Log Settings";
-        let saveRotationName = "Save Rotation Settings";
-        let saveDeletionName = "Save Deletion Settings";
+        let saveSettingsName = _("Save Log Settings");
+        let saveRotationName = _("Save Rotation Settings");
+        let saveDeletionName = _("Save Deletion Settings");
         const extraPrimaryProps = {};
         let rotationTime = "";
         let hour = this.state['nsslapd-accesslog-logrotationsynchour'] ? this.state['nsslapd-accesslog-logrotationsynchour'] : "00";
         let min = this.state['nsslapd-accesslog-logrotationsyncmin'] ? this.state['nsslapd-accesslog-logrotationsyncmin'] : "00";
 
         if (this.state.loading) {
-            saveSettingsName = "Saving settings ...";
-            saveRotationName = "Saving settings ...";
-            saveDeletionName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Loading";
+            saveSettingsName = _("Saving settings ...");
+            saveRotationName = _("Saving settings ...");
+            saveDeletionName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Loading");
         }
 
         // Adjust time string for TimePicket
@@ -540,10 +542,10 @@ export class ServerAccessLog extends React.Component {
         }
         rotationTime = hour + ":" + min;
 
-        let body =
+        let body = (
             <div className="ds-margin-top-lg ds-left-margin">
                 <Tabs className="ds-margin-top-xlg" activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
-                    <Tab eventKey={0} title={<TabTitleText>Settings</TabTitleText>}>
+                    <Tab eventKey={0} title={<TabTitleText>{_("Settings")}</TabTitleText>}>
                         <Checkbox
                             className="ds-margin-top-xlg"
                             id="nsslapd-accesslog-logging-enabled"
@@ -551,14 +553,14 @@ export class ServerAccessLog extends React.Component {
                             onChange={(checked, e) => {
                                 this.handleChange(e, "settings");
                             }}
-                            title="Enable access logging (nsslapd-accesslog-logging-enabled)."
-                            label="Enable Access Logging"
+                            title={_("Enable access logging (nsslapd-accesslog-logging-enabled).")}
+                            label={_("Enable Access Logging")}
                         />
                         <Form className="ds-margin-top-lg ds-left-margin-md" isHorizontal autoComplete="off">
                             <FormGroup
-                                label="Access Log Location"
+                                label={_("Access Log Location")}
                                 fieldId="nsslapd-accesslog"
-                                title="Enable access logging (nsslapd-accesslog)."
+                                title={_("Enable access logging (nsslapd-accesslog).")}
                             >
                                 <TextInput
                                     value={this.state['nsslapd-accesslog']}
@@ -579,20 +581,19 @@ export class ServerAccessLog extends React.Component {
                             onChange={(checked, e) => {
                                 this.handleChange(e, "settings");
                             }}
-                            title="Disable access log buffering for faster troubleshooting, but this will impact server performance (nsslapd-accesslog-logbuffering)."
-                            label="Access Log Buffering Enabled"
+                            title={_("Disable access log buffering for faster troubleshooting, but this will impact server performance (nsslapd-accesslog-logbuffering).")}
+                            label={_("Access Log Buffering Enabled")}
                         />
 
-
                         <ExpandableSection
                             className="ds-left-margin-md ds-margin-top-lg ds-font-size-md"
-                            toggleText={this.state.isExpanded ? 'Hide Logging Levels' : 'Show Logging Levels'}
-                            onToggle={this.onToggle}
+                            toggleText={this.state.isExpanded ? _("Hide Logging Levels") : _("Show Logging Levels")}
+                            onToggle={this.handleOnToggle}
                             isExpanded={this.state.isExpanded}
                         >
                             <Table
                                 className="ds-left-margin"
-                                onSelect={this.onSelect}
+                                onSelect={this.handleOnSelect}
                                 canSelectAll={this.state.canSelectAll}
                                 variant={TableVariant.compact}
                                 aria-label="Selectable Table"
@@ -613,20 +614,20 @@ export class ServerAccessLog extends React.Component {
                                 this.saveConfig("settings");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveSettingsName}
                         </Button>
                     </Tab>
-                    <Tab eventKey={1} title={<TabTitleText>Rotation Policy</TabTitleText>}>
+                    <Tab eventKey={1} title={<TabTitleText>{_("Rotation Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The maximum number of logs that are archived (nsslapd-accesslog-maxlogsperdir)."
+                                title={_("The maximum number of logs that are archived (nsslapd-accesslog-maxlogsperdir).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Number Of Logs
+                                    {_("Maximum Number Of Logs")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -644,9 +645,9 @@ export class ServerAccessLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="The maximum size of each log file in megabytes (nsslapd-accesslog-maxlogsize).">
+                            <Grid title={_("The maximum size of each log file in megabytes (nsslapd-accesslog-maxlogsize).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Log Size (in MB)
+                                    {_("Maximum Log Size (in MB)")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -665,9 +666,9 @@ export class ServerAccessLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <hr />
-                            <Grid title="Rotate the log based this number of time units (nsslapd-accesslog-logrotationtime).">
+                            <Grid title={_("Rotate the log based this number of time units (nsslapd-accesslog-logrotationtime).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Create New Log Every ...
+                                    {_("Create New Log Every ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -693,19 +694,19 @@ export class ServerAccessLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="0" value="minute" label="minute" />
-                                                <FormSelectOption key="1" value="hour" label="hour" />
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="0" value="minute" label={_("minute")} />
+                                                <FormSelectOption key="1" value="hour" label={_("hour")} />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
                                 </GridItem>
                             </Grid>
-                            <Grid title="The time when the log should be rotated (nsslapd-accesslog-logrotationsynchour, nsslapd-accesslog-logrotationsyncmin).">
+                            <Grid title={_("The time when the log should be rotated (nsslapd-accesslog-logrotationsynchour, nsslapd-accesslog-logrotationsyncmin).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Time Of Day
+                                    {_("Time Of Day")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <TimePicker
@@ -715,9 +716,9 @@ export class ServerAccessLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="Compress (gzip) the log after it's rotated.">
+                            <Grid title={_("Compress (gzip) the log after it's rotated.")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Compress Rotated Logs
+                                    {_("Compress Rotated Logs")}
                                 </GridItem>
                                 <GridItem className="ds-label" span={8}>
                                     <Switch
@@ -738,21 +739,21 @@ export class ServerAccessLog extends React.Component {
                                 this.saveConfig("rotation");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveRotationName}
                         </Button>
                     </Tab>
 
-                    <Tab eventKey={2} title={<TabTitleText>Deletion Policy</TabTitleText>}>
+                    <Tab eventKey={2} title={<TabTitleText>{_("Deletion Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-accesslog-logmaxdiskspace)."
+                                title={_("The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-accesslog-logmaxdiskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log Archive Exceeds (in MB)
+                                    {_("Log Archive Exceeds (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -771,10 +772,10 @@ export class ServerAccessLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-accesslog-logminfreediskspace)."
+                                title={_("The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-accesslog-logminfreediskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Free Disk Space (in MB)
+                                    {_("Free Disk Space (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -793,10 +794,10 @@ export class ServerAccessLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="Server deletes an old archived log file when it is older than the specified age. (nsslapd-accesslog-logexpirationtime)."
+                                title={_("Server deletes an old archived log file when it is older than the specified age. (nsslapd-accesslog-logexpirationtime).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log File is Older Than ...
+                                    {_("Log File is Older Than ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -822,9 +823,9 @@ export class ServerAccessLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
@@ -840,23 +841,25 @@ export class ServerAccessLog extends React.Component {
                                 this.saveConfig("exp");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveDeletionName}
                         </Button>
                     </Tab>
                 </Tabs>
-            </div>;
+            </div>
+        );
 
         if (!this.state.loaded) {
-            body =
+            body = (
                 <div className="ds-margin-top-xlg ds-center">
                     <TextContent>
-                        <Text component={TextVariants.h3}>Loading Access Log Settings ...</Text>
+                        <Text component={TextVariants.h3}>{_("Loading Access Log Settings ...")}</Text>
                     </TextContent>
                     <Spinner size="xl" />
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -865,11 +868,12 @@ export class ServerAccessLog extends React.Component {
                     <GridItem span={12}>
                         <TextContent>
                             <Text component={TextVariants.h3}>
-                                Access Log Settings <FontAwesomeIcon
+                                {_("Access Log Settings")}
+                                <FontAwesomeIcon
                                     size="lg"
                                     className="ds-left-margin ds-refresh"
                                     icon={faSyncAlt}
-                                    title="Refresh log settings"
+                                    title={_("Refresh log settings")}
                                     onClick={() => {
                                         this.refreshConfig();
                                     }}
