@@ -64,6 +64,8 @@ const exp_attrs = [
     'nsslapd-auditlog-logminfreediskspace',
 ];
 
+const _ = cockpit.gettext;
+
 export class ServerAuditLog extends React.Component {
     constructor(props) {
         super(props);
@@ -88,7 +90,7 @@ export class ServerAuditLog extends React.Component {
             });
         };
 
-        this.onDisplayAttrSelect = (event, selection) => {
+        this.handleOnDisplayAttrSelect = (event, selection) => {
             if (this.state.displayAttrs.includes(selection)) {
                 this.setState(
                     (prevState) => ({
@@ -105,12 +107,12 @@ export class ServerAuditLog extends React.Component {
                 );
             }
         };
-        this.onDisplayAttrToggle = isDisplayAttrOpen => {
+        this.handleOnDisplayAttrToggle = isDisplayAttrOpen => {
             this.setState({
                 isDisplayAttrOpen
             });
         };
-        this.onDisplayAttrClear = () => {
+        this.handleOnDisplayAttrClear = () => {
             this.setState({
                 displayAttrs: [],
                 isDisplayAttrOpen: false
@@ -134,7 +136,7 @@ export class ServerAuditLog extends React.Component {
                 maxValue = max;
             }
             let newValue = isNaN(event.target.value) ? min : Number(event.target.value);
-            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue
+            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue;
             this.setState({
                 [id]: newValue
             }, () => { this.validateSaveBtn(nav_tab, id, newValue) });
@@ -143,7 +145,7 @@ export class ServerAuditLog extends React.Component {
             this.setState({
                 [id]: Number(this.state[id]) + 1
             }, () => { this.validateSaveBtn(nav_tab, id, Number(this.state[id])) });
-        }
+        };
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
     }
 
@@ -229,7 +231,7 @@ export class ServerAuditLog extends React.Component {
 
         this.setState({
             [attr]: value,
-        }, () => { this.validateSaveBtn(nav_tab, attr, value) } );
+        }, () => { this.validateSaveBtn(nav_tab, attr, value) });
     }
 
     handleSwitchChange(value) {
@@ -286,7 +288,7 @@ export class ServerAuditLog extends React.Component {
             config_attrs = exp_attrs;
         }
 
-        let cmd = [
+        const cmd = [
             'dsconf', '-j', "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             'config', 'replace'
         ];
@@ -307,7 +309,7 @@ export class ServerAuditLog extends React.Component {
 
         if (!this.state.displayAllAttrs && !listsEqual(this.state.displayAttrs, this.state._displayAttrs)) {
             if (this.state.displayAttrs.length > 0) {
-                let val = this.state.displayAttrs.join(' ');
+                const val = this.state.displayAttrs.join(' ');
                 cmd.push('nsslapd-auditlog-display-attrs=' + val);
             } else {
                 cmd.push('nsslapd-auditlog-display-attrs=');
@@ -333,7 +335,7 @@ export class ServerAuditLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "success",
-                        "Successfully updated Audit Log settings"
+                        _("Successfully updated Audit Log settings")
                     );
                 })
                 .fail(err => {
@@ -341,7 +343,7 @@ export class ServerAuditLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "error",
-                        `Error saving Audit Log settings - ${errMsg.desc}`
+                        cockpit.format(_("Error saving Audit Log settings - $0"), errMsg.desc)
                     );
                 });
     }
@@ -402,7 +404,7 @@ export class ServerAuditLog extends React.Component {
                         'nsslapd-auditlog-maxlogsperdir': attrs['nsslapd-auditlog-maxlogsperdir'][0],
                         'nsslapd-auditlog-compress': compressed,
                         displayAttrs: display_attrs,
-                        displayAllAttrs: displayAllAttrs,
+                        displayAllAttrs,
                         // Record original values
                         '_nsslapd-auditlog': attrs['nsslapd-auditlog'][0],
                         '_nsslapd-auditlog-logexpirationtime': attrs['nsslapd-auditlog-logexpirationtime'][0],
@@ -426,7 +428,7 @@ export class ServerAuditLog extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading Audit Log configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading Audit Log configuration - $0"), errMsg.desc)
                     );
                     this.setState({
                         loading: false,
@@ -478,7 +480,7 @@ export class ServerAuditLog extends React.Component {
             'nsslapd-auditlog-maxlogsperdir': attrs['nsslapd-auditlog-maxlogsperdir'][0],
             'nsslapd-auditlog-compress': compressed,
             displayAttrs: display_attrs,
-            displayAllAttrs: displayAllAttrs,
+            displayAllAttrs,
             // Record original values,
             '_nsslapd-auditlog': attrs['nsslapd-auditlog'][0],
             '_nsslapd-auditlog-logexpirationtime': attrs['nsslapd-auditlog-logexpirationtime'][0],
@@ -500,19 +502,19 @@ export class ServerAuditLog extends React.Component {
     }
 
     render() {
-        let saveSettingsName = "Save Log Settings";
-        let saveRotationName = "Save Rotation Settings";
-        let saveDeletionName = "Save Deletion Settings";
+        let saveSettingsName = _("Save Log Settings");
+        let saveRotationName = _("Save Rotation Settings");
+        let saveDeletionName = _("Save Deletion Settings");
         const extraPrimaryProps = {};
         let rotationTime = "";
         let hour = this.state['nsslapd-auditlog-logrotationsynchour'] ? this.state['nsslapd-auditlog-logrotationsynchour'] : "00";
         let min = this.state['nsslapd-auditlog-logrotationsyncmin'] ? this.state['nsslapd-auditlog-logrotationsyncmin'] : "00";
 
         if (this.state.loading) {
-            saveSettingsName = "Saving settings ...";
-            saveRotationName = "Saving settings ...";
-            saveDeletionName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Loading";
+            saveSettingsName = _("Saving settings ...");
+            saveRotationName = _("Saving settings ...");
+            saveDeletionName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Loading");
         }
 
         // Adjust time string for TimePicket
@@ -524,10 +526,10 @@ export class ServerAuditLog extends React.Component {
         }
         rotationTime = hour + ":" + min;
 
-        let body =
+        let body = (
             <div className="ds-margin-top-lg ds-left-margin">
                 <Tabs className="ds-margin-top-xlg" activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
-                    <Tab eventKey={0} title={<TabTitleText>Settings</TabTitleText>}>
+                    <Tab eventKey={0} title={<TabTitleText>{_("Settings")}</TabTitleText>}>
                         <Checkbox
                             className="ds-margin-top-xlg"
                             id="nsslapd-auditlog-logging-enabled"
@@ -535,14 +537,14 @@ export class ServerAuditLog extends React.Component {
                             onChange={(checked, e) => {
                                 this.handleChange(e, "settings");
                             }}
-                            title="Enable audit logging (nsslapd-auditlog-logging-enabled)."
-                            label="Enable Audit Logging"
+                            title={_("Enable audit logging (nsslapd-auditlog-logging-enabled).")}
+                            label={_("Enable Audit Logging")}
                         />
                         <Form className="ds-margin-top-xlg ds-margin-left" isHorizontal autoComplete="off">
                             <FormGroup
-                                label="Audit Log Location"
+                                label={_("Audit Log Location")}
                                 fieldId="nsslapd-auditlog"
-                                title="Enable audit logging (nsslapd-auditlog)."
+                                title={_("Enable audit logging (nsslapd-auditlog).")}
                             >
                                 <TextInput
                                     value={this.state['nsslapd-auditlog']}
@@ -558,22 +560,22 @@ export class ServerAuditLog extends React.Component {
                         </Form>
                         <Form className="ds-margin-top-lg ds-margin-left" isHorizontal autoComplete="off">
                             <FormGroup
-                                label="Display Attributes"
+                                label={_("Display Attributes")}
                                 fieldId="nsslapd-auditlog-display-attrs"
-                                title="Display attributes from the entry in the audit log (nsslapd-auditlog-display-attrs)."
+                                title={_("Display attributes from the entry in the audit log (nsslapd-auditlog-display-attrs).")}
                             >
                                 <div className={this.state.displayAllAttrs ? "ds-hidden" : "ds-margin-bottom"}>
                                     <Select
                                         variant={SelectVariant.typeaheadMulti}
                                         typeAheadAriaLabel="Type an attribute"
-                                        onToggle={this.onDisplayAttrToggle}
-                                        onSelect={this.onDisplayAttrSelect}
-                                        onClear={this.onDisplayAttrClear}
+                                        onToggle={this.handleOnDisplayAttrToggle}
+                                        onSelect={this.handleOnDisplayAttrSelect}
+                                        onClear={this.handleOnDisplayAttrClear}
                                         selections={this.state.displayAttrs}
                                         isOpen={this.state.isDisplayAttrOpen}
                                         aria-labelledby="typeAhead-audit-display-attr"
-                                        placeholderText="Type an attribute..."
-                                        noResultsFoundText="There are no matching attributes"
+                                        placeholderText={_("Type an attribute...")}
+                                        noResultsFoundText={_("There are no matching attributes")}
                                     >
                                         {this.state.attributes.map((attr, index) => (
                                             <SelectOption
@@ -590,8 +592,8 @@ export class ServerAuditLog extends React.Component {
                                     onChange={(checked, e) => {
                                         this.handleChange(e, "settings");
                                     }}
-                                    title="Display all attributes from the entry in the audit log (nsslapd-auditlog-display-attrs)."
-                                    label="All Attributes"
+                                    title={_("Display all attributes from the entry in the audit log (nsslapd-auditlog-display-attrs).")}
+                                    label={_("All Attributes")}
                                 />
                             </FormGroup>
                         </Form>
@@ -604,20 +606,20 @@ export class ServerAuditLog extends React.Component {
                                 this.saveConfig("settings");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveSettingsName}
                         </Button>
                     </Tab>
-                    <Tab eventKey={1} title={<TabTitleText>Rotation Policy</TabTitleText>}>
+                    <Tab eventKey={1} title={<TabTitleText>{_("Rotation Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The maximum number of logs that are archived (nsslapd-auditlog-maxlogsperdir)."
+                                title={_("The maximum number of logs that are archived (nsslapd-auditlog-maxlogsperdir).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Number Of Logs
+                                    {_("Maximum Number Of Logs")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -635,9 +637,9 @@ export class ServerAuditLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="The maximum size of each log file in megabytes (nsslapd-auditlog-maxlogsize).">
+                            <Grid title={_("The maximum size of each log file in megabytes (nsslapd-auditlog-maxlogsize).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Log Size (in MB)
+                                    {_("Maximum Log Size (in MB)")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -656,9 +658,9 @@ export class ServerAuditLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <hr />
-                            <Grid title="Rotate the log based this number of time units (nsslapd-auditlog-logrotationtime).">
+                            <Grid title={_("Rotate the log based this number of time units (nsslapd-auditlog-logrotationtime).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Create New Log Every ...
+                                    {_("Create New Log Every ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -684,19 +686,19 @@ export class ServerAuditLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="0" value="minute" label="minute" />
-                                                <FormSelectOption key="1" value="hour" label="hour" />
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="0" value="minute" label={_("minute")} />
+                                                <FormSelectOption key="1" value="hour" label={_("hour")} />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
                                 </GridItem>
                             </Grid>
-                            <Grid title="The time when the log should be rotated (nsslapd-auditlog-logrotationsynchour, nsslapd-auditlog-logrotationsyncmin).">
+                            <Grid title={_("The time when the log should be rotated (nsslapd-auditlog-logrotationsynchour, nsslapd-auditlog-logrotationsyncmin).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Time Of Day
+                                    {_("Time Of Day")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <TimePicker
@@ -706,9 +708,9 @@ export class ServerAuditLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="Compress (gzip) the log after it's rotated.">
+                            <Grid title={_("Compress (gzip) the log after it's rotated.")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Compress Rotated Logs
+                                    {_("Compress Rotated Logs")}
                                 </GridItem>
                                 <GridItem span={8}>
                                     <Switch
@@ -729,21 +731,21 @@ export class ServerAuditLog extends React.Component {
                                 this.saveConfig("rotation");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveRotationName}
                         </Button>
                     </Tab>
 
-                    <Tab eventKey={2} title={<TabTitleText>Deletion Policy</TabTitleText>}>
+                    <Tab eventKey={2} title={<TabTitleText>{_("Deletion Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-auditlog-logmaxdiskspace)."
+                                title={_("The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-auditlog-logmaxdiskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log Archive Exceeds (in MB)
+                                    {_("Log Archive Exceeds (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -762,10 +764,10 @@ export class ServerAuditLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-auditlog-logminfreediskspace)."
+                                title={_("The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-auditlog-logminfreediskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Free Disk Space (in MB)
+                                    {_("Free Disk Space (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -784,10 +786,10 @@ export class ServerAuditLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="Server deletes an old archived log file when it is older than the specified age. (nsslapd-auditlog-logexpirationtime)."
+                                title={_("Server deletes an old archived log file when it is older than the specified age. (nsslapd-auditlog-logexpirationtime).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log File is Older Than ...
+                                    {_("Log File is Older Than ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -813,9 +815,9 @@ export class ServerAuditLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
@@ -831,23 +833,25 @@ export class ServerAuditLog extends React.Component {
                                 this.saveConfig("exp");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveDeletionName}
                         </Button>
                     </Tab>
                 </Tabs>
-            </div>;
+            </div>
+        );
 
         if (!this.state.loaded) {
-            body =
+            body = (
                 <div className="ds-loading-spinner ds-margin-top-xlg ds-center">
                     <TextContent>
-                        <Text component={TextVariants.h3}>Loading Audit Log settings ...</Text>
+                        <Text component={TextVariants.h3}>{_("Loading Audit Log settings ...")}</Text>
                     </TextContent>
                     <Spinner className="ds-margin-top" size="lg" />
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -856,11 +860,12 @@ export class ServerAuditLog extends React.Component {
                     <GridItem span={12}>
                         <TextContent>
                             <Text component={TextVariants.h3}>
-                                Audit Log Settings <FontAwesomeIcon
+                                {_("Audit Log Settings")}
+                                <FontAwesomeIcon
                                     size="lg"
                                     className="ds-left-margin ds-refresh"
                                     icon={faSyncAlt}
-                                    title="Refresh log settings"
+                                    title={_("Refresh log settings")}
                                     onClick={() => {
                                         this.refreshConfig();
                                     }}
