@@ -31,6 +31,8 @@ const ldapi_attrs = [
     'nsslapd-ldapiuidnumbertype',
 ];
 
+const _ = cockpit.gettext;
+
 export class ServerLDAPI extends React.Component {
     constructor(props) {
         super(props);
@@ -44,26 +46,26 @@ export class ServerLDAPI extends React.Component {
             isGIDOpen: false,
         };
 
-        this.onUIDToggle = isUIDOpen => {
+        this.handleUIDToggle = isUIDOpen => {
             this.setState({
                 isUIDOpen
             });
         };
 
-        this.onUIDSelect = (event, selection, isPlaceholder) => {
+        this.handleUIDSelect = (event, selection, isPlaceholder) => {
             this.setState({
                 'nsslapd-ldapiuidnumbertype': selection,
                 isUIDOpen: false
             }, () => { this.validateSaveBtn() });
         };
 
-        this.onGIDToggle = isGIDOpen => {
+        this.handleGIDToggle = isGIDOpen => {
             this.setState({
                 isGIDOpen
             });
         };
 
-        this.onGIDSelect = (event, selection, isPlaceholder) => {
+        this.handleGIDSelect = (event, selection, isPlaceholder) => {
             this.setState({
                 'nsslapd-ldapigidnumbertype': selection,
                 isGIDOpen: false
@@ -72,8 +74,8 @@ export class ServerLDAPI extends React.Component {
 
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
         this.handleChange = this.handleChange.bind(this);
-        this.loadConfig = this.loadConfig.bind(this);
-        this.saveConfig = this.saveConfig.bind(this);
+        this.handleLoadConfig = this.handleLoadConfig.bind(this);
+        this.handleSaveConfig = this.handleSaveConfig.bind(this);
         this.getAttributes = this.getAttributes.bind(this);
         this.reloadConfig = this.reloadConfig.bind(this);
     }
@@ -81,7 +83,7 @@ export class ServerLDAPI extends React.Component {
     componentDidMount() {
         // Loading config
         if (!this.state.loaded) {
-            this.loadConfig();
+            this.handleLoadConfig();
         } else {
             this.props.enableTree();
         }
@@ -140,12 +142,12 @@ export class ServerLDAPI extends React.Component {
         }, () => { this.validateSaveBtn() });
     }
 
-    loadConfig() {
+    handleLoadConfig() {
         const attrs = this.state.attrs;
         let mapToEntries = false;
 
         if ('nsslapd-ldapimaptoentries' in attrs) {
-            if (attrs['nsslapd-ldapimaptoentries'][0] == "on") {
+            if (attrs['nsslapd-ldapimaptoentries'][0] === "on") {
                 mapToEntries = true;
             }
         }
@@ -181,8 +183,8 @@ export class ServerLDAPI extends React.Component {
                     const config = JSON.parse(content);
                     const attrs = config.attrs;
                     this.setState({
-                        attrs: attrs
-                    }, this.loadConfig);
+                        attrs
+                    }, this.handleLoadConfig);
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
@@ -191,23 +193,23 @@ export class ServerLDAPI extends React.Component {
                     });
                     this.props.addNotification(
                         "error",
-                        `Error loading server configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading server configuration - $0"), errMsg.desc)
                     );
                 });
     }
 
-    saveConfig() {
+    handleSaveConfig() {
         this.setState({
             loading: true
         });
 
-        let cmd = [
+        const cmd = [
             'dsconf', '-j', "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             'config', 'replace'
         ];
 
         for (const attr of [...ldapi_attrs, 'nsslapd-ldapimaptoentries']) {
-            if (this.state['_' + attr] != this.state[attr]) {
+            if (this.state['_' + attr] !== this.state[attr]) {
                 let val = this.state[attr];
                 if (typeof val === "boolean") {
                     if (val) {
@@ -220,7 +222,7 @@ export class ServerLDAPI extends React.Component {
             }
         }
 
-        log_cmd("saveConfig", "Saving LDAPI settings", cmd);
+        log_cmd("handleSaveConfig", "Saving LDAPI settings", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
@@ -229,7 +231,7 @@ export class ServerLDAPI extends React.Component {
                     }, this.reloadConfig);
                     this.props.addNotification(
                         "success",
-                        "Successfully updated LDAPI configuration"
+                        _("Successfully updated LDAPI configuration")
                     );
                 })
                 .fail(err => {
@@ -239,7 +241,7 @@ export class ServerLDAPI extends React.Component {
                     }, this.reloadConfig);
                     this.props.addNotification(
                         "error",
-                        `Error updating LDAPI configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error updating LDAPI configuration - $0"), errMsg.desc)
                     );
                 });
     }
@@ -247,31 +249,31 @@ export class ServerLDAPI extends React.Component {
     render() {
         let mapUserAttrs = "";
         const extraPrimaryProps = {};
-        let saveBtnName = "Save Settings";
+        let saveBtnName = _("Save Settings");
         if (this.state.loading) {
-            saveBtnName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Loading";
+            saveBtnName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Loading");
         }
 
         if (this.state['nsslapd-ldapimaptoentries']) {
             const attributes = this.state.attributes.map((option, index) => (
                 <SelectOption key={index} value={option} />
             ));
-            mapUserAttrs =
+            mapUserAttrs = (
                 <div className="ds-margin-left">
                     <Grid
                         className="ds-margin-top"
-                        title="The Directory Server attribute to map system UIDs to user entries (nsslapd-ldapiuidnumbertype)."
+                        title={_("The Directory Server attribute to map system UIDs to user entries (nsslapd-ldapiuidnumbertype).")}
                     >
                         <GridItem className="ds-label" span={3}>
-                            LDAPI UID Number Attribute
+                            {_("LDAPI UID Number Attribute")}
                         </GridItem>
                         <GridItem span={9}>
                             <Select
                                 variant={SelectVariant.single}
                                 aria-label="Select UID Input"
-                                onToggle={this.onUIDToggle}
-                                onSelect={this.onUIDSelect}
+                                onToggle={this.handleUIDToggle}
+                                onSelect={this.handleUIDSelect}
                                 selections={this.state['nsslapd-ldapiuidnumbertype']}
                                 isOpen={this.state.isUIDOpen}
                                 aria-labelledby="UID"
@@ -282,17 +284,17 @@ export class ServerLDAPI extends React.Component {
                     </Grid>
                     <Grid
                         className="ds-margin-top"
-                        title="The Directory Server attribute to map system GUIDs to user entries (nsslapd-ldapigidnumbertype)."
+                        title={_("The Directory Server attribute to map system GUIDs to user entries (nsslapd-ldapigidnumbertype).")}
                     >
                         <GridItem className="ds-label" span={3}>
-                            LDAPI GID Number Attribute
+                            {_("LDAPI GID Number Attribute")}
                         </GridItem>
                         <GridItem span={9}>
                             <Select
                                 variant={SelectVariant.single}
                                 aria-label="Select GID Input"
-                                onToggle={this.onGIDToggle}
-                                onSelect={this.onGIDSelect}
+                                onToggle={this.handleGIDToggle}
+                                onSelect={this.handleGIDSelect}
                                 selections={this.state['nsslapd-ldapigidnumbertype']}
                                 isOpen={this.state.isGIDOpen}
                                 aria-labelledby="GID"
@@ -302,11 +304,11 @@ export class ServerLDAPI extends React.Component {
                         </GridItem>
                     </Grid>
                     <Grid
-                        title="The subtree to search for user entries to use for autobind. (nsslapd-ldapientrysearchbase)."
+                        title={_("The subtree to search for user entries to use for autobind. (nsslapd-ldapientrysearchbase).")}
                         className="ds-margin-top"
                     >
                         <GridItem className="ds-label" span={3}>
-                            LDAPI Entry Search Base
+                            {_("LDAPI Entry Search Base")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -320,15 +322,16 @@ export class ServerLDAPI extends React.Component {
                             />
                         </GridItem>
                     </Grid>
-                </div>;
+                </div>
+            );
         }
 
-        let body =
+        let body = (
             <div>
                 <Form className="ds-margin-top-xlg ds-left-margin" autoComplete="off" isHorizontal>
-                    <Grid title="The Unix socket file (nsslapd-ldapifilepath).  The UI requires this exact path so it is a read-only setting.">
+                    <Grid title={_("The Unix socket file (nsslapd-ldapifilepath).  The UI requires this exact path so it is a read-only setting.")}>
                         <GridItem className="ds-label" span={3}>
-                            LDAPI Socket File Path
+                            {_("LDAPI Socket File Path")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -340,9 +343,9 @@ export class ServerLDAPI extends React.Component {
                             />
                         </GridItem>
                     </Grid>
-                    <Grid title="Map the Unix root entry to this Directory Manager DN (nsslapd-ldapimaprootdn).  The UI requires this to be set to the current root DN so it is a read-only setting. The attribute is obsolete. Current root DN is used.">
+                    <Grid title={_("Map the Unix root entry to this Directory Manager DN (nsslapd-ldapimaprootdn).  The UI requires this to be set to the current root DN so it is a read-only setting. The attribute is obsolete. Current root DN is used.")}>
                         <GridItem className="ds-label" span={3}>
-                            LDAPI Map To Root DN
+                            {_("LDAPI Map To Root DN")}
                         </GridItem>
                         <GridItem span={9}>
                             <TextInput
@@ -355,7 +358,7 @@ export class ServerLDAPI extends React.Component {
                         </GridItem>
                     </Grid>
                     <Grid
-                        title="Map regular system users to Directory Server entries (nsslapd-ldapimaptoentries)."
+                        title={_("Map regular system users to Directory Server entries (nsslapd-ldapimaptoentries).")}
                         className="ds-margin-top"
                     >
                         <GridItem span={5}>
@@ -366,7 +369,7 @@ export class ServerLDAPI extends React.Component {
                                     this.handleChange(e);
                                 }}
                                 aria-label="uncontrolled checkbox example"
-                                label="Map System Users to Database Entries"
+                                label={_("Map System Users to Database Entries")}
                             />
                         </GridItem>
                     </Grid>
@@ -376,23 +379,25 @@ export class ServerLDAPI extends React.Component {
                     isDisabled={this.state.saveDisabled || this.state.loading}
                     variant="primary"
                     className="ds-margin-top-xlg"
-                    onClick={this.saveConfig}
+                    onClick={this.handleSaveConfig}
                     isLoading={this.state.loading}
-                    spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                    spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                     {...extraPrimaryProps}
                 >
                     {saveBtnName}
                 </Button>
-            </div>;
+            </div>
+        );
 
         if (!this.state.loaded) {
-            body =
+            body = (
                 <div className="ds-margin-top-xlg ds-center">
                     <TextContent>
-                        <Text component={TextVariants.h3}>Loading LDAPI configuration ...</Text>
+                        <Text component={TextVariants.h3}>{_("Loading LDAPI configuration ...")}</Text>
                     </TextContent>
                     <Spinner className="ds-margin-top" size="lg" />
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -401,12 +406,13 @@ export class ServerLDAPI extends React.Component {
                     <GridItem span={5}>
                         <TextContent>
                             <Text component={TextVariants.h3}>
-                                LDAPI & AutoBind Settings <FontAwesomeIcon
+                                {_("LDAPI & AutoBind Settings")}
+                                <FontAwesomeIcon
                                     size="lg"
                                     className="ds-left-margin ds-refresh"
                                     icon={faSyncAlt}
-                                    title="Refresh LDAPI settings"
-                                    onClick={this.loadConfig}
+                                    title={_("Refresh LDAPI settings")}
+                                    onClick={this.handleLoadConfig}
                                 />
                             </Text>
                         </TextContent>
