@@ -25,6 +25,8 @@ import {
 } from '@fortawesome/free-solid-svg-icons';
 import '@fortawesome/fontawesome-svg-core/styles.css';
 
+const _ = cockpit.gettext;
+
 export class ServerSASL extends React.Component {
     constructor(props) {
         super(props);
@@ -53,19 +55,19 @@ export class ServerSASL extends React.Component {
             saslBase: "",
             saslFilter: "",
             saslPriority: "100",
-            saslModalType: "Create",
+            saslModalType: _("Create"),
             saslErrObj: {},
             showConfirmDelete: false,
             modalChecked: false,
             isAllowedMechOpen: false,
         };
         // Allowed SASL Mechanisms
-        this.onAllowedMechToggle = isAllowedMechOpen => {
+        this.handleOnAllowedMechToggle = isAllowedMechOpen => {
             this.setState({
                 isAllowedMechOpen,
             });
         };
-        this.onSelect = (event, selection) => {
+        this.handleOnSelect = (event, selection) => {
             const { allowedMechs } = this.state;
             if (allowedMechs.includes(selection)) {
                 this.setState(
@@ -83,7 +85,7 @@ export class ServerSASL extends React.Component {
                 );
             }
         };
-        this.onAllowedMechClear = () => {
+        this.handleOnAllowedMechClear = () => {
             this.setState({
                 allowedMechs: [],
                 isAllowedMechOpen: false
@@ -94,13 +96,13 @@ export class ServerSASL extends React.Component {
         this.validateModal = this.validateModal.bind(this);
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
         this.handleChange = this.handleChange.bind(this);
-        this.handleModalChange = this.handleModalChange.bind(this);
-        this.handleTestRegex = this.handleTestRegex.bind(this);
-        this.loadConfig = this.loadConfig.bind(this);
+        this.onModalChange = this.onModalChange.bind(this);
+        this.onTestRegex = this.onTestRegex.bind(this);
+        this.handleLoadConfig = this.handleLoadConfig.bind(this);
         this.loadMechs = this.loadMechs.bind(this);
         this.loadSASLMappings = this.loadSASLMappings.bind(this);
-        this.saveConfig = this.saveConfig.bind(this);
-        this.showCreateMapping = this.showCreateMapping.bind(this);
+        this.handleSaveConfig = this.handleSaveConfig.bind(this);
+        this.handleShowCreateMapping = this.handleShowCreateMapping.bind(this);
         this.showEditMapping = this.showEditMapping.bind(this);
         this.closeMapping = this.closeMapping.bind(this);
         this.showConfirmDelete = this.showConfirmDelete.bind(this);
@@ -113,7 +115,7 @@ export class ServerSASL extends React.Component {
     componentDidMount() {
         // Loading config
         if (!this.state.loaded) {
-            this.loadConfig();
+            this.handleLoadConfig();
         } else {
             this.props.enableTree();
         }
@@ -125,7 +127,7 @@ export class ServerSASL extends React.Component {
 
     validateRegex(regex) {
         // Just check that the regex itself is valid
-        let errObj = this.state.saslErrObj;
+        const errObj = this.state.saslErrObj;
         let saveMappingDisabled = this.state.saveMappingDisabled;
         if (this.state.saslMapRegex === "") {
             errObj.saslMapRegex = true;
@@ -144,13 +146,13 @@ export class ServerSASL extends React.Component {
         }
         this.setState({
             saslErrObj: errObj,
-            saveMappingDisabled: saveMappingDisabled
+            saveMappingDisabled
 
         });
         return !errObj.saslMapRegex;
     }
 
-    handleTestRegex() {
+    onTestRegex() {
         const test_string = this.state.saslTestText;
         if (this.validateRegex()) {
             const cleaned_regex = this.normalizeRegex(this.state.saslMapRegex);
@@ -158,18 +160,18 @@ export class ServerSASL extends React.Component {
             if (sasl_regex.test(test_string)) {
                 this.props.addNotification(
                     "success",
-                    "The test string matches the Regular Expression"
+                    _("The test string matches the Regular Expression")
                 );
             } else {
                 this.props.addNotification(
                     "warning",
-                    "The test string does not match the Regular Expression"
+                    _("The test string does not match the Regular Expression")
                 );
             }
         } else {
             this.props.addNotification(
                 "error",
-                "Invalid regular expression"
+                _("Invalid regular expression")
             );
         }
     }
@@ -212,13 +214,12 @@ export class ServerSASL extends React.Component {
     validateModal() {
         let disableSaveBtn = true;
         let disableRegexTestBtn = true;
-        const valueErr = false;
         const errObj = this.state.saslErrObj;
         let error = false;
 
         const attrs = ['saslMapName', 'saslMapRegex', 'saslBase', 'saslPriority', 'saslFilter'];
         for (const attr of attrs) {
-            if (this.state[attr] === "" || (attr === 'saslPriority' && this.state[attr] == "0")) {
+            if (this.state[attr] === "" || (attr === 'saslPriority' && this.state[attr] === "0")) {
                 errObj[attr] = true;
                 error = true;
             } else {
@@ -238,7 +239,7 @@ export class ServerSASL extends React.Component {
         }
 
         // Handle Test Text field and buttons
-        if (this.state.saslMapRegex != "" && this.state.saslTestText != "") {
+        if (this.state.saslMapRegex !== "" && this.state.saslTestText !== "") {
             disableRegexTestBtn = false;
         }
 
@@ -249,7 +250,7 @@ export class ServerSASL extends React.Component {
         }, () => { this.validateRegex() });
     }
 
-    handleModalChange(e) {
+    onModalChange(e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         const attr = e.target.id;
 
@@ -258,12 +259,12 @@ export class ServerSASL extends React.Component {
         }, () => { this.validateModal() });
     }
 
-    loadConfig() {
+    handleLoadConfig() {
         const cmd = [
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "config", 'get'
         ];
-        log_cmd("loadConfig", "Get SASL settings", cmd);
+        log_cmd("handleLoadConfig", "Get SASL settings", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
@@ -273,7 +274,7 @@ export class ServerSASL extends React.Component {
                     let allowedMechs = [];
                     let fallback = false;
 
-                    if (attrs['nsslapd-sasl-mapping-fallback'][0] == "on") {
+                    if (attrs['nsslapd-sasl-mapping-fallback'][0] === "on") {
                         fallback = true;
                     }
                     if (allowedMechsVal !== "") {
@@ -288,7 +289,7 @@ export class ServerSASL extends React.Component {
 
                     this.setState({
                         maxBufSize: attrs['nsslapd-sasl-max-buffer-size'][0],
-                        allowedMechs: allowedMechs,
+                        allowedMechs,
                         mappingFallback: fallback,
                         saveDisabled: true,
                         // Store original values
@@ -323,14 +324,14 @@ export class ServerSASL extends React.Component {
                     const saslMapObj = JSON.parse(content);
                     const mappings = [];
                     for (const mapping of saslMapObj.items) {
-                        if (!mapping.attrs.hasOwnProperty('nssaslmappriority')) {
+                        if (!('nssaslmappriority' in mapping.attrs)) {
                             mapping.attrs.nssaslmappriority = ['100'];
                         }
                         mappings.push(mapping.attrs);
                     }
                     const key = this.state.mappingKey + 1;
                     this.setState({
-                        mappings: mappings,
+                        mappings,
                         mappingKey: key,
                         loaded: true,
                         tableLoading: false,
@@ -341,12 +342,12 @@ export class ServerSASL extends React.Component {
                 });
     }
 
-    showCreateMapping() {
+    handleShowCreateMapping() {
         this.setState({
             showMappingModal: true,
             saveMappingDisabled: true,
             testRegexDisabled: true,
-            saslModalType: "Create",
+            saslModalType: _("Create"),
             saslMapName: "",
             saslMapRegex: "",
             saslTestText: "",
@@ -368,7 +369,7 @@ export class ServerSASL extends React.Component {
             showMappingModal: true,
             saveMappingDisabled: true,
             testRegexDisabled: true,
-            saslModalType: "Edit",
+            saslModalType: _("Edit"),
             saslMapName: name,
             saslMapRegex: regex,
             saslTestText: "",
@@ -419,18 +420,18 @@ export class ServerSASL extends React.Component {
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.props.addNotification(
                         "success",
-                        "Successfully create new SASL Mapping"
+                        _("Successfully create new SASL Mapping")
                     );
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.props.addNotification(
                         "error",
-                        `Error creating new SASL Mapping - ${errMsg.desc}`
+                        cockpit.format(_("Error creating new SASL Mapping - $0"), errMsg.desc)
                     );
                 });
     }
@@ -439,7 +440,7 @@ export class ServerSASL extends React.Component {
         // Start spinning
         const new_mappings = this.state.mappings;
         for (const saslMap of new_mappings) {
-            if (saslMap.cn[0] == name) {
+            if (saslMap.cn[0] === name) {
                 saslMap.nssaslmapregexstring = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapregexstring[0]} loading size="sm" />];
                 saslMap.nssaslmapbasedntemplate = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapbasedntemplate[0]} loading size="sm" />];
                 saslMap.nssaslmapfiltertemplate = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapfiltertemplate[0]} loading size="sm" />];
@@ -475,29 +476,29 @@ export class ServerSASL extends React.Component {
                     cockpit
                             .spawn(create_cmd, { superuser: true, err: "message" })
                             .done(content => {
-                                this.loadConfig();
+                                this.handleLoadConfig();
                                 this.props.addNotification(
                                     "success",
-                                    "Successfully updated SASL Mapping"
+                                    _("Successfully updated SASL Mapping")
                                 );
                             })
                             .fail(err => {
                                 const errMsg = JSON.parse(err);
                                 this.closeMapping();
-                                this.loadConfig();
+                                this.handleLoadConfig();
                                 this.props.addNotification(
                                     "error",
-                                    `Error updating SASL Mapping - ${errMsg.desc}`
+                                    cockpit.format(_("Error updating SASL Mapping - $0"), errMsg.desc)
                                 );
                             });
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.closeMapping();
                     this.props.addNotification(
                         "error",
-                        `Error replacing SASL Mapping - ${errMsg.desc}`
+                        cockpit.format(_("Error replacing SASL Mapping - $0"), errMsg.desc)
                     );
                 });
     }
@@ -506,7 +507,7 @@ export class ServerSASL extends React.Component {
         // Start spinning
         const new_mappings = this.state.mappings;
         for (const saslMap of new_mappings) {
-            if (saslMap.cn[0] == this.state.saslMapName) {
+            if (saslMap.cn[0] === this.state.saslMapName) {
                 saslMap.nssaslmapregexstring = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapregexstring[0]} loading size="sm" />];
                 saslMap.nssaslmapbasedntemplate = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapbasedntemplate[0]} loading size="sm" />];
                 saslMap.nssaslmapfiltertemplate = [<Spinner className="ds-lower-field" key={new_mappings[0].nssaslmapfiltertemplate[0]} loading size="sm" />];
@@ -526,119 +527,120 @@ export class ServerSASL extends React.Component {
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.props.addNotification(
                         "success",
-                        "Successfully deleted SASL Mapping"
+                        _("Successfully deleted SASL Mapping")
                     );
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.closeConfirmDelete();
                     this.props.addNotification(
                         "error",
-                        `Error deleting SASL Mapping - ${errMsg.desc}`
+                        cockpit.format(_("Error deleting SASL Mapping - $0"), errMsg.desc)
                     );
                 });
     }
 
-    saveConfig() {
+    handleSaveConfig() {
         // Start spinning
         this.setState({
             configLoading: true,
         });
 
         // Build up the command list
-        let cmd = [
+        const cmd = [
             'dsconf', '-j', "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket", 'config'
         ];
 
         const mech_str_new = this.state.allowedMechs.join(' ');
         const mech_str_orig = this.state._allowedMechs.join(' ');
-        if (mech_str_orig != mech_str_new) {
+        if (mech_str_orig !== mech_str_new) {
             if (mech_str_new.length === 0) {
-                cmd.push('delete')
+                cmd.push('delete');
                 cmd.push("nsslapd-allowed-sasl-mechanisms");
             } else {
-                cmd.push('replace')
+                cmd.push('replace');
                 cmd.push("nsslapd-allowed-sasl-mechanisms=" + mech_str_new);
             }
         } else {
             // The rest of the settings always have values to replace
-            cmd.push('replace')
+            cmd.push('replace');
         }
-        if (this.state._mappingFallback != this.state.mappingFallback) {
+        if (this.state._mappingFallback !== this.state.mappingFallback) {
             let value = "off";
             if (this.state.mappingFallback) {
                 value = "on";
             }
             cmd.push("nsslapd-sasl-mapping-fallback=" + value);
         }
-        if (this.state._maxBufSize != this.state.maxBufSize) {
+        if (this.state._maxBufSize !== this.state.maxBufSize) {
             cmd.push("nsslapd-sasl-max-buffer-size=" + this.state.maxBufSize);
         }
 
-        log_cmd("saveConfig", "Applying SASL config change", cmd);
+        log_cmd("handleSaveConfig", "Applying SASL config change", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.props.addNotification(
                         "warning",
-                        "Successfully updated SASL configuration.  These " +
-                            "changes require the server to be restarted to take effect."
+                        _("Successfully updated SASL configuration.  These changes require the server to be restarted to take effect.")
                     );
                 })
                 .fail(err => {
                     const errMsg = JSON.parse(err);
-                    this.loadConfig();
+                    this.handleLoadConfig();
                     this.props.addNotification(
                         "error",
-                        `Error updating SASL configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error updating SASL configuration - $0"), errMsg.desc)
                     );
                 });
     }
 
     render() {
         let body = "";
-        let saveBtnName = "Save Settings";
+        let saveBtnName = _("Save Settings");
         const extraPrimaryProps = {};
         if (this.state.configLoading) {
-            saveBtnName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Saving";
+            saveBtnName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Saving");
         }
 
         if (!this.state.loaded) {
-            body =
+            body = (
                 <div className="ds-loading-spinner ds-margin-top-xlg ds-center">
                     <TextContent>
-                        <Text component={TextVariants.h3}>Loading SASL Configuration ...</Text>
+                        <Text component={TextVariants.h3}>{_("Loading SASL Configuration ...")}</Text>
                     </TextContent>
                     <Spinner className="ds-margin-top" size="lg" />
-                </div>;
+                </div>
+            );
         } else {
-            body =
+            body = (
                 <div className={this.state.configLoading ? "ds-disabled ds-margin-bottom-md" : "ds-margin-bottom-md"}>
                     <Grid>
                         <GridItem span={3}>
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    SASL Settings <FontAwesomeIcon
+                                    {_("SASL Settings")}
+                                    <FontAwesomeIcon
                                         size="lg"
                                         className="ds-left-margin ds-refresh"
                                         icon={faSyncAlt}
-                                        title="Refresh SASL settings"
-                                        onClick={this.loadConfig}
+                                        title={_("Refresh SASL settings")}
+                                        onClick={this.handleLoadConfig}
                                     />
                                 </Text>
                             </TextContent>
                         </GridItem>
                     </Grid>
                     <Form isHorizontal autoComplete="off" className="ds-left-margin">
-                        <Grid title="The maximum SASL buffer size in bytes (nsslapd-sasl-max-buffer-size)." className="ds-margin-top-xlg">
+                        <Grid title={_("The maximum SASL buffer size in bytes (nsslapd-sasl-max-buffer-size).")} className="ds-margin-top-xlg">
                             <GridItem className="ds-label" span={3}>
-                                Max SASL Buffer Size
+                                {_("Max SASL Buffer Size")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -654,22 +656,22 @@ export class ServerSASL extends React.Component {
                             </GridItem>
                         </Grid>
                         <Grid
-                            title="A list of SASL mechanisms the server will only accept (nsslapd-allowed-sasl-mechanisms).  The default is all mechanisms are allowed."
+                            title={_("A list of SASL mechanisms the server will only accept (nsslapd-allowed-sasl-mechanisms).  The default is all mechanisms are allowed.")}
                         >
                             <GridItem className="ds-label" span={3}>
-                                Allowed SASL Mechanisms
+                                {_("Allowed SASL Mechanisms")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
                                     variant={SelectVariant.typeaheadMulti}
                                     typeAheadAriaLabel="Type SASL mechanism to allow"
-                                    onToggle={this.onAllowedMechToggle}
-                                    onSelect={this.onSelect}
-                                    onClear={this.onAllowedMechClear}
+                                    onToggle={this.handleOnAllowedMechToggle}
+                                    onSelect={this.handleOnSelect}
+                                    onClear={this.handleOnAllowedMechClear}
                                     selections={this.state.allowedMechs}
                                     isOpen={this.state.isAllowedMechOpen}
                                     aria-labelledby="typeAhead-sasl-mechs"
-                                    placeholderText="Type SASL mechanism to allow..."
+                                    placeholderText={_("Type SASL mechanism to allow...")}
                                     noResultsFoundText="There are no matching entries"
                                 >
                                     {this.state.supportedMechs.map((attr, index) => (
@@ -682,7 +684,7 @@ export class ServerSASL extends React.Component {
                             </GridItem>
                         </Grid>
                         <Grid
-                            title="Check all sasl mappings until one succeeds or they all fail (nsslapd-sasl-mapping-fallback)."
+                            title={_("Check all sasl mappings until one succeeds or they all fail (nsslapd-sasl-mapping-fallback).")}
                         >
                             <Checkbox
                                 isChecked={this.state.mappingFallback}
@@ -690,7 +692,7 @@ export class ServerSASL extends React.Component {
                                 onChange={(checked, e) => {
                                     this.handleChange(e);
                                 }}
-                                label="Allow SASL Mapping Fallback"
+                                label={_("Allow SASL Mapping Fallback")}
                             />
                         </Grid>
                     </Form>
@@ -698,21 +700,21 @@ export class ServerSASL extends React.Component {
                         isDisabled={this.state.saveDisabled || this.state.configLoading}
                         variant="primary"
                         className="ds-margin-top-xlg"
-                        onClick={this.saveConfig}
+                        onClick={this.handleSaveConfig}
                         isLoading={this.state.configLoading}
-                        spinnerAriaValueText={this.state.configLoading ? "Saving" : undefined}
+                        spinnerAriaValueText={this.state.configLoading ? _("Saving") : undefined}
                         {...extraPrimaryProps}
                     >
                         {saveBtnName}
                     </Button>
                     <hr />
                     <Grid
-                        title="A list of SASL mechanisms the server will only accept (nsslapd-allowed-sasl-mechanisms).  The default is all mechanisms are allowed."
+                        title={_("A list of SASL mechanisms the server will only accept (nsslapd-allowed-sasl-mechanisms).  The default is all mechanisms are allowed.")}
                         className="ds-margin-top"
                     >
                         <TextContent>
                             <Text className="ds-center ds-margin-top" component={TextVariants.h3}>
-                                SASL Mappings
+                                {_("SASL Mappings")}
                             </Text>
                         </TextContent>
                     </Grid>
@@ -725,11 +727,12 @@ export class ServerSASL extends React.Component {
                     />
                     <Button
                         variant="primary"
-                        onClick={this.showCreateMapping}
+                        onClick={this.handleShowCreateMapping}
                     >
-                        Create New Mapping
+                        {_("Create New Mapping")}
                     </Button>
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -739,10 +742,10 @@ export class ServerSASL extends React.Component {
                     showModal={this.state.showMappingModal}
                     testBtnDisabled={this.state.testBtnDisabled}
                     saveDisabled={this.state.saveMappingDisabled}
-                    closeHandler={this.closeMapping}
-                    handleChange={this.handleModalChange}
-                    handleTestRegex={this.handleTestRegex}
-                    saveHandler={this.state.saslModalType == "Create" ? this.createMapping : this.editMapping}
+                    handleClose={this.closeMapping}
+                    handleChange={this.onModalChange}
+                    handleTestRegex={this.onTestRegex}
+                    saveHandler={this.state.saslModalType === "Create" ? this.createMapping : this.editMapping}
                     error={this.state.saslErrObj}
                     type={this.state.saslModalType}
                     name={this.state.saslMapName}
@@ -756,15 +759,15 @@ export class ServerSASL extends React.Component {
                 <DoubleConfirmModal
                     showModal={this.state.showConfirmDelete}
                     closeHandler={this.closeConfirmDelete}
-                    handleChange={this.handleModalChange}
+                    handleChange={this.onModalChange}
                     actionHandler={this.deleteMapping}
                     item={this.state.saslMapName}
                     checked={this.state.modalChecked}
                     spinning={this.state.tableLoading}
-                    mTitle="Delete SASL Mapping"
-                    mMsg="Are you sure you want to delete this SASL mapping?"
-                    mSpinningMsg="Deleting SASL Mapping ..."
-                    mBtnName="Delete Mapping"
+                    mTitle={_("Delete SASL Mapping")}
+                    mMsg={_("Are you sure you want to delete this SASL mapping?")}
+                    mSpinningMsg={_("Deleting SASL Mapping ...")}
+                    mBtnName={_("Delete Mapping")}
                 />
             </div>
         );
