@@ -36,6 +36,8 @@ import {
 import '@fortawesome/fontawesome-svg-core/styles.css';
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 const settings_attrs = [
     'nsslapd-securitylog',
     'nsslapd-securitylog-level',
@@ -89,7 +91,7 @@ export class ServerSecurityLog extends React.Component {
                 { cells: ['Entry Security and Referrals'], level: 512, selected: false }
             ],
             columns: [
-                { title: 'Logging Level' },
+                { title: _("Logging Level") },
             ],
         };
 
@@ -100,7 +102,7 @@ export class ServerSecurityLog extends React.Component {
             });
         };
 
-        this.onToggle = isExpanded => {
+        this.handleOnToggle = isExpanded => {
             this.setState({
                 isExpanded
             });
@@ -112,7 +114,7 @@ export class ServerSecurityLog extends React.Component {
         this.loadConfig = this.loadConfig.bind(this);
         this.refreshConfig = this.refreshConfig.bind(this);
         this.saveConfig = this.saveConfig.bind(this);
-        this.onSelect = this.onSelect.bind(this);
+        this.handleOnSelect = this.handleOnSelect.bind(this);
         this.onMinusConfig = (id, nav_tab) => {
             this.setState({
                 [id]: Number(this.state[id]) - 1
@@ -124,7 +126,7 @@ export class ServerSecurityLog extends React.Component {
                 maxValue = max;
             }
             let newValue = isNaN(event.target.value) ? min : Number(event.target.value);
-            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue
+            newValue = newValue > maxValue ? maxValue : newValue < min ? min : newValue;
             this.setState({
                 [id]: newValue
             }, () => { this.validateSaveBtn(nav_tab, id, newValue) });
@@ -133,7 +135,7 @@ export class ServerSecurityLog extends React.Component {
             this.setState({
                 [id]: Number(this.state[id]) + 1
             }, () => { this.validateSaveBtn(nav_tab, id, Number(this.state[id])) });
-        }
+        };
         this.validateSaveBtn = this.validateSaveBtn.bind(this);
     }
 
@@ -150,21 +152,21 @@ export class ServerSecurityLog extends React.Component {
         let disableSaveBtn = true;
         let disableBtnName = "";
         let config_attrs = [];
-        if (nav_tab == "settings") {
+        if (nav_tab === "settings") {
             config_attrs = settings_attrs;
             disableBtnName = "saveSettingsDisabled";
             // Handle the table contents check now
             for (const row of this.state.rows) {
                 for (const orig_row of this.state._rows) {
-                    if (orig_row.cells[0] == row.cells[0]) {
-                        if (orig_row.selected != row.selected) {
+                    if (orig_row.cells[0] === row.cells[0]) {
+                        if (orig_row.selected !== row.selected) {
                             disableSaveBtn = false;
                             break;
                         }
                     }
                 }
             }
-        } else if (nav_tab == "rotation") {
+        } else if (nav_tab === "rotation") {
             disableBtnName = "saveRotationDisabled";
             config_attrs = rotation_attrs;
         } else {
@@ -174,7 +176,7 @@ export class ServerSecurityLog extends React.Component {
 
         // Check if a setting was changed, if so enable the save button
         for (const config_attr of config_attrs) {
-            if (attr == config_attr && this.state['_' + config_attr] != value) {
+            if (attr === config_attr && this.state['_' + config_attr] !== value) {
                 disableSaveBtn = false;
                 break;
             }
@@ -182,7 +184,7 @@ export class ServerSecurityLog extends React.Component {
 
         // Now check for differences in values that we did not touch
         for (const config_attr of config_attrs) {
-            if (attr != config_attr && this.state['_' + config_attr] != this.state[config_attr]) {
+            if (attr !== config_attr && this.state['_' + config_attr] !== this.state[config_attr]) {
                 disableSaveBtn = false;
                 break;
             }
@@ -199,7 +201,7 @@ export class ServerSecurityLog extends React.Component {
 
         this.setState({
             [attr]: value,
-        }, () => { this.validateSaveBtn(nav_tab, attr, value) } );
+        }, () => { this.validateSaveBtn(nav_tab, attr, value) });
     }
 
     handleSwitchChange(value) {
@@ -216,22 +218,22 @@ export class ServerSecurityLog extends React.Component {
         const time_parts = time_str.split(":");
         let hour = time_parts[0];
         let min = time_parts[1];
-        if (hour.length == 2 && hour[0] == "0") {
+        if (hour.length === 2 && hour[0] === "0") {
             hour = hour[1];
         }
-        if (min.length == 2 && min[0] == "0") {
+        if (min.length === 2 && min[0] === "0") {
             min = min[1];
         }
 
         // Start doing the Save button checking
         for (const config_attr of rotation_attrs_no_time) {
-            if (this.state[config_attr] != this.state['_' + config_attr]) {
+            if (this.state[config_attr] !== this.state['_' + config_attr]) {
                 disableSaveBtn = false;
                 break;
             }
         }
-        if (hour != this.state['_nsslapd-securitylog-logrotationsynchour'] ||
-            min != this.state['_nsslapd-securitylog-logrotationsyncmin']) {
+        if (hour !== this.state['_nsslapd-securitylog-logrotationsynchour'] ||
+            min !== this.state['_nsslapd-securitylog-logrotationsyncmin']) {
             disableSaveBtn = false;
         }
 
@@ -249,9 +251,9 @@ export class ServerSecurityLog extends React.Component {
         });
 
         let config_attrs = [];
-        if (nav_tab == "settings") {
+        if (nav_tab === "settings") {
             config_attrs = settings_attrs;
-        } else if (nav_tab == "rotation") {
+        } else if (nav_tab === "rotation") {
             config_attrs = rotation_attrs;
         } else {
             config_attrs = exp_attrs;
@@ -263,7 +265,7 @@ export class ServerSecurityLog extends React.Component {
         ];
 
         for (const attr of config_attrs) {
-            if (this.state['_' + attr] != this.state[attr]) {
+            if (this.state['_' + attr] !== this.state[attr]) {
                 let val = this.state[attr];
                 if (typeof val === "boolean") {
                     if (val) {
@@ -281,14 +283,14 @@ export class ServerSecurityLog extends React.Component {
                 new_level += row.level;
             }
         }
-        if (new_level.toString() != this.state['_nsslapd-securitylog-level']) {
-            if (new_level == 0) {
+        if (new_level.toString() !== this.state['_nsslapd-securitylog-level']) {
+            if (new_level === 0) {
                 new_level = 256; // default
             }
             cmd.push("nsslapd-securitylog-level" + "=" + new_level.toString());
         }
 
-        if (cmd.length == 5) {
+        if (cmd.length === 5) {
             // Nothing to save, just return
             return;
         }
@@ -300,7 +302,7 @@ export class ServerSecurityLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "success",
-                        "Successfully updated Security Log settings"
+                        _("Successfully updated Security Log settings")
                     );
                 })
                 .fail(err => {
@@ -308,7 +310,7 @@ export class ServerSecurityLog extends React.Component {
                     this.refreshConfig();
                     this.props.addNotification(
                         "error",
-                        `Error saving Security Log settings - ${errMsg.desc}`
+                        cockpit.format(_("Error saving Security Log settings - $0"), errMsg.desc)
                     );
                 });
     }
@@ -335,13 +337,13 @@ export class ServerSecurityLog extends React.Component {
                     const level_val = parseInt(attrs['nsslapd-securitylog-level'][0]);
                     const rows = [...this.state.rows];
 
-                    if (attrs['nsslapd-securitylog-logging-enabled'][0] == "on") {
+                    if (attrs['nsslapd-securitylog-logging-enabled'][0] === "on") {
                         enabled = true;
                     }
-                    if (attrs['nsslapd-securitylog-logbuffering'][0] == "on") {
+                    if (attrs['nsslapd-securitylog-logbuffering'][0] === "on") {
                         buffering = true;
                     }
-                    if (attrs['nsslapd-securitylog-compress'][0] == "on") {
+                    if (attrs['nsslapd-securitylog-compress'][0] === "on") {
                         compress = true;
                     }
                     for (const row in rows) {
@@ -374,7 +376,7 @@ export class ServerSecurityLog extends React.Component {
                         'nsslapd-securitylog-maxlogsize': attrs['nsslapd-securitylog-maxlogsize'][0],
                         'nsslapd-securitylog-maxlogsperdir': attrs['nsslapd-securitylog-maxlogsperdir'][0],
                         'nsslapd-securitylog-compress': compress,
-                        rows: rows,
+                        rows,
                         // Record original values
                         _rows:  JSON.parse(JSON.stringify(rows)),
                         '_nsslapd-securitylog': attrs['nsslapd-securitylog'][0],
@@ -399,7 +401,7 @@ export class ServerSecurityLog extends React.Component {
                     const errMsg = JSON.parse(err);
                     this.props.addNotification(
                         "error",
-                        `Error loading Security Log configuration - ${errMsg.desc}`
+                        cockpit.format(_("Error loading Security Log configuration - $0"), errMsg.desc)
                     );
                     this.setState({
                         loading: false,
@@ -416,13 +418,13 @@ export class ServerSecurityLog extends React.Component {
         const level_val = parseInt(attrs['nsslapd-securitylog-level'][0]);
         const rows = [...this.state.rows];
 
-        if (attrs['nsslapd-securitylog-logging-enabled'][0] == "on") {
+        if (attrs['nsslapd-securitylog-logging-enabled'][0] === "on") {
             enabled = true;
         }
-        if (attrs['nsslapd-securitylog-logbuffering'][0] == "on") {
+        if (attrs['nsslapd-securitylog-logbuffering'][0] === "on") {
             buffering = true;
         }
-        if (attrs['nsslapd-securitylog-compress'][0] == "on") {
+        if (attrs['nsslapd-securitylog-compress'][0] === "on") {
             compress = true;
         }
         for (const row in rows) {
@@ -455,7 +457,7 @@ export class ServerSecurityLog extends React.Component {
             'nsslapd-securitylog-maxlogsize': attrs['nsslapd-securitylog-maxlogsize'][0],
             'nsslapd-securitylog-maxlogsperdir': attrs['nsslapd-securitylog-maxlogsperdir'][0],
             'nsslapd-securitylog-compress': compress,
-            rows: rows,
+            rows,
             // Record original values
             _rows: JSON.parse(JSON.stringify(rows)),
             '_nsslapd-securitylog': attrs['nsslapd-securitylog'][0],
@@ -477,7 +479,7 @@ export class ServerSecurityLog extends React.Component {
         }, this.props.enableTree);
     }
 
-    onSelect(event, isSelected, rowId) {
+    handleOnSelect(event, isSelected, rowId) {
         let disableSaveBtn = true;
         const rows = JSON.parse(JSON.stringify(this.state.rows));
 
@@ -486,7 +488,7 @@ export class ServerSecurityLog extends React.Component {
 
         // Handle "save button" state, first check the other config settings
         for (const config_attr of settings_attrs) {
-            if (this.state['_' + config_attr] != this.state[config_attr]) {
+            if (this.state['_' + config_attr] !== this.state[config_attr]) {
                 disableSaveBtn = false;
                 break;
             }
@@ -495,8 +497,8 @@ export class ServerSecurityLog extends React.Component {
         // Handle the table contents
         for (const row of rows) {
             for (const orig_row of this.state._rows) {
-                if (orig_row.cells[0] == row.cells[0]) {
-                    if (orig_row.selected != row.selected) {
+                if (orig_row.cells[0] === row.cells[0]) {
+                    if (orig_row.selected !== row.selected) {
                         disableSaveBtn = false;
                         break;
                     }
@@ -511,34 +513,34 @@ export class ServerSecurityLog extends React.Component {
     }
 
     render() {
-        let saveSettingsName = "Save Log Settings";
-        let saveRotationName = "Save Rotation Settings";
-        let saveDeletionName = "Save Deletion Settings";
+        let saveSettingsName = _("Save Log Settings");
+        let saveRotationName = _("Save Rotation Settings");
+        let saveDeletionName = _("Save Deletion Settings");
         const extraPrimaryProps = {};
         let rotationTime = "";
         let hour = this.state['nsslapd-securitylog-logrotationsynchour'] ? this.state['nsslapd-securitylog-logrotationsynchour'] : "00";
         let min = this.state['nsslapd-securitylog-logrotationsyncmin'] ? this.state['nsslapd-securitylog-logrotationsyncmin'] : "00";
 
         if (this.state.loading) {
-            saveSettingsName = "Saving settings ...";
-            saveRotationName = "Saving settings ...";
-            saveDeletionName = "Saving settings ...";
-            extraPrimaryProps.spinnerAriaValueText = "Loading";
+            saveSettingsName = _("Saving settings ...");
+            saveRotationName = _("Saving settings ...");
+            saveDeletionName = _("Saving settings ...");
+            extraPrimaryProps.spinnerAriaValueText = _("Loading");
         }
 
         // Adjust time string for TimePicket
-        if (hour.length == 1) {
+        if (hour.length === 1) {
             hour = "0" + hour;
         }
-        if (min.length == 1) {
+        if (min.length === 1) {
             min = "0" + min;
         }
         rotationTime = hour + ":" + min;
 
-        let body =
+        let body = (
             <div className="ds-margin-top-lg ds-left-margin">
                 <Tabs className="ds-margin-top-xlg" activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
-                    <Tab eventKey={0} title={<TabTitleText>Settings</TabTitleText>}>
+                    <Tab eventKey={0} title={<TabTitleText>{_("Settings")}</TabTitleText>}>
                         <Checkbox
                             className="ds-margin-top-xlg"
                             id="nsslapd-securitylog-logging-enabled"
@@ -546,14 +548,14 @@ export class ServerSecurityLog extends React.Component {
                             onChange={(checked, e) => {
                                 this.handleChange(e, "settings");
                             }}
-                            title="Enable security logging (nsslapd-securitylog-logging-enabled)."
-                            label="Enable Security Logging"
+                            title={_("Enable security logging (nsslapd-securitylog-logging-enabled).")}
+                            label={_("Enable Security Logging")}
                         />
                         <Form className="ds-margin-top-lg ds-left-margin-md" isHorizontal autoComplete="off">
                             <FormGroup
-                                label="Security Log Location"
+                                label={_("Security Log Location")}
                                 fieldId="nsslapd-securitylog"
-                                title="Enable security logging (nsslapd-securitylog)."
+                                title={_("Enable security logging (nsslapd-securitylog).")}
                             >
                                 <TextInput
                                     value={this.state['nsslapd-securitylog']}
@@ -574,20 +576,19 @@ export class ServerSecurityLog extends React.Component {
                             onChange={(checked, e) => {
                                 this.handleChange(e, "settings");
                             }}
-                            title="Disable security log buffering for faster troubleshooting, but this will impact server performance (nsslapd-securitylog-logbuffering)."
-                            label="Security Log Buffering Enabled"
+                            title={_("Disable security log buffering for faster troubleshooting, but this will impact server performance (nsslapd-securitylog-logbuffering).")}
+                            label={_("Security Log Buffering Enabled")}
                         />
 
-
                         <ExpandableSection
                             className="ds-hidden ds-left-margin-md ds-margin-top-lg ds-font-size-md"
-                            toggleText={this.state.isExpanded ? 'Hide Logging Levels' : 'Show Logging Levels'}
-                            onToggle={this.onToggle}
+                            toggleText={this.state.isExpanded ? _("Hide Logging Levels") : _("Show Logging Levels")}
+                            onToggle={this.handleOnToggle}
                             isExpanded={this.state.isExpanded}
                         >
                             <Table
                                 className="ds-left-margin"
-                                onSelect={this.onSelect}
+                                onSelect={this.handleOnSelect}
                                 canSelectAll={this.state.canSelectAll}
                                 variant={TableVariant.compact}
                                 aria-label="Selectable Table"
@@ -608,20 +609,20 @@ export class ServerSecurityLog extends React.Component {
                                 this.saveConfig("settings");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveSettingsName}
                         </Button>
                     </Tab>
-                    <Tab eventKey={1} title={<TabTitleText>Rotation Policy</TabTitleText>}>
+                    <Tab eventKey={1} title={<TabTitleText>{_("Rotation Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The maximum number of logs that are archived (nsslapd-securitylog-maxlogsperdir)."
+                                title={_("The maximum number of logs that are archived (nsslapd-securitylog-maxlogsperdir).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Number Of Logs
+                                    {_("Maximum Number Of Logs")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -639,9 +640,9 @@ export class ServerSecurityLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="The maximum size of each log file in megabytes (nsslapd-securitylog-maxlogsize).">
+                            <Grid title={_("The maximum size of each log file in megabytes (nsslapd-securitylog-maxlogsize).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Maximum Log Size (in MB)
+                                    {_("Maximum Log Size (in MB)")}
                                 </GridItem>
                                 <GridItem span={3}>
                                     <NumberInput
@@ -660,9 +661,9 @@ export class ServerSecurityLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <hr />
-                            <Grid title="Rotate the log based this number of time units (nsslapd-securitylog-logrotationtime).">
+                            <Grid title={_("Rotate the log based this number of time units (nsslapd-securitylog-logrotationtime).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Create New Log Every ...
+                                    {_("Create New Log Every ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -688,19 +689,19 @@ export class ServerSecurityLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="0" value="minute" label="minute" />
-                                                <FormSelectOption key="1" value="hour" label="hour" />
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="0" value="minute" label={_("minute")} />
+                                                <FormSelectOption key="1" value="hour" label={_("hour")} />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
                                 </GridItem>
                             </Grid>
-                            <Grid title="The time when the log should be rotated (nsslapd-securitylog-logrotationsynchour, nsslapd-securitylog-logrotationsyncmin).">
+                            <Grid title={_("The time when the log should be rotated (nsslapd-securitylog-logrotationsynchour, nsslapd-securitylog-logrotationsyncmin).")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Time Of Day
+                                    {_("Time Of Day")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <TimePicker
@@ -710,9 +711,9 @@ export class ServerSecurityLog extends React.Component {
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title="Compress (gzip) the log after it's rotated.">
+                            <Grid title={_("Compress (gzip) the log after it's rotated.")}>
                                 <GridItem className="ds-label" span={3}>
-                                    Compress Rotated Logs
+                                    {_("Compress Rotated Logs")}
                                 </GridItem>
                                 <GridItem className="ds-label" span={8}>
                                     <Switch
@@ -732,21 +733,21 @@ export class ServerSecurityLog extends React.Component {
                                 this.saveConfig("rotation");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveRotationName}
                         </Button>
                     </Tab>
 
-                    <Tab eventKey={2} title={<TabTitleText>Deletion Policy</TabTitleText>}>
+                    <Tab eventKey={2} title={<TabTitleText>{_("Deletion Policy")}</TabTitleText>}>
                         <Form className="ds-margin-top-lg" isHorizontal autoComplete="off">
                             <Grid
                                 className="ds-margin-top"
-                                title="The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-securitylog-logmaxdiskspace)."
+                                title={_("The server deletes the oldest archived log when the total of all the logs reaches this amount (nsslapd-securitylog-logmaxdiskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log Archive Exceeds (in MB)
+                                    {_("Log Archive Exceeds (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -765,10 +766,10 @@ export class ServerSecurityLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-securitylog-logminfreediskspace)."
+                                title={_("The server deletes the oldest archived log file when available disk space is less than this amount. (nsslapd-securitylog-logminfreediskspace).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Free Disk Space (in MB)
+                                    {_("Free Disk Space (in MB)")}
                                 </GridItem>
                                 <GridItem span={1}>
                                     <NumberInput
@@ -787,10 +788,10 @@ export class ServerSecurityLog extends React.Component {
                                 </GridItem>
                             </Grid>
                             <Grid
-                                title="Server deletes an old archived log file when it is older than the specified age. (nsslapd-securitylog-logexpirationtime)."
+                                title={_("Server deletes an old archived log file when it is older than the specified age. (nsslapd-securitylog-logexpirationtime).")}
                             >
                                 <GridItem className="ds-label" span={3}>
-                                    Log File is Older Than ...
+                                    {_("Log File is Older Than ...")}
                                 </GridItem>
                                 <GridItem span={9}>
                                     <div className="ds-container">
@@ -816,9 +817,9 @@ export class ServerSecurityLog extends React.Component {
                                                 }}
                                                 aria-label="FormSelect Input"
                                             >
-                                                <FormSelectOption key="2" value="day" label="day" />
-                                                <FormSelectOption key="3" value="week" label="week" />
-                                                <FormSelectOption key="4" value="month" label="month" />
+                                                <FormSelectOption key="2" value="day" label={_("day")} />
+                                                <FormSelectOption key="3" value="week" label={_("week")} />
+                                                <FormSelectOption key="4" value="month" label={_("month")} />
                                             </FormSelect>
                                         </GridItem>
                                     </div>
@@ -834,23 +835,25 @@ export class ServerSecurityLog extends React.Component {
                                 this.saveConfig("exp");
                             }}
                             isLoading={this.state.loading}
-                            spinnerAriaValueText={this.state.loading ? "Saving" : undefined}
+                            spinnerAriaValueText={this.state.loading ? _("Saving") : undefined}
                             {...extraPrimaryProps}
                         >
                             {saveDeletionName}
                         </Button>
                     </Tab>
                 </Tabs>
-            </div>;
+            </div>
+        );
 
         if (!this.state.loaded) {
-            body =
+            body = (
                 <div className="ds-margin-top-xlg ds-center">
                     <TextContent>
-                        <Text component={TextVariants.h3}>Loading Security Log Settings ...</Text>
+                        <Text component={TextVariants.h3}>{_("Loading Security Log Settings ...")}</Text>
                     </TextContent>
                     <Spinner size="xl" />
-                </div>;
+                </div>
+            );
         }
 
         return (
@@ -859,11 +862,12 @@ export class ServerSecurityLog extends React.Component {
                     <GridItem span={12}>
                         <TextContent>
                             <Text component={TextVariants.h3}>
-                                Security Log Settings <FontAwesomeIcon
+                                {_("Security Log Settings")}
+                                <FontAwesomeIcon
                                     size="lg"
                                     className="ds-left-margin ds-refresh"
                                     icon={faSyncAlt}
-                                    title="Refresh log settings"
+                                    title={_("Refresh log settings")}
                                     onClick={() => {
                                         this.refreshConfig();
                                     }}
