@@ -38,6 +38,8 @@ import {
     MonitoringIcon,
 } from '@patternfly/react-icons';
 
+const _ = cockpit.gettext;
+
 export class Monitor extends React.Component {
     constructor(props) {
         super(props);
@@ -154,36 +156,36 @@ export class Monitor extends React.Component {
                 defaultExpanded: false,
                 children: [
                     {
-                        name: "Agreements",
+                        name: _("Agreements"),
                         icon: <MonitoringIcon />,
                         id: suffix + "-agmts",
                         item: "agmt-mon",
                         type: "repl-mon",
-                        suffix: suffix
+                        suffix
                     },
                     {
-                        name: "Winsync Agreements",
+                        name: _("Winsync Agreements"),
                         icon: <MonitoringIcon />,
                         id: suffix + "-winsync",
                         item: "winsync-mon",
                         type: "repl-mon",
-                        suffix: suffix
+                        suffix
                     },
                     {
-                        name: "Tasks",
+                        name: _("Tasks"),
                         icon: <MonitoringIcon />,
                         id: suffix + "-tasks",
                         item: "task-mon",
                         type: "repl-mon",
-                        suffix: suffix
+                        suffix
                     },
                     {
-                        name: "Conflict Entries",
+                        name: _("Conflict Entries"),
                         icon: <MonitoringIcon />,
                         id: suffix + "-conflict",
                         item: "conflict-mon",
                         type: "repl-mon",
-                        suffix: suffix
+                        suffix
                     },
                 ],
             });
@@ -203,20 +205,20 @@ export class Monitor extends React.Component {
                     this.processTree(treeData);
                     const basicData = [
                         {
-                            name: "Server Statistics",
+                            name: _("Server Statistics"),
                             icon: <ClusterIcon />,
                             id: "server-monitor",
                             type: "server",
                         },
                         {
-                            name: "Replication",
+                            name: _("Replication"),
                             icon: <TopologyIcon />,
                             id: "replication-monitor",
                             type: "replication",
                             defaultExpanded: true,
                             children: [
                                 {
-                                    name: "Synchronization Report",
+                                    name: _("Synchronization Report"),
                                     icon: <MonitoringIcon />,
                                     id: "sync-report",
                                     item: "sync-report",
@@ -225,7 +227,7 @@ export class Monitor extends React.Component {
                             ],
                         },
                         {
-                            name: "Database",
+                            name: _("Database"),
                             icon: <DatabaseIcon />,
                             id: "database-monitor",
                             type: "database",
@@ -233,37 +235,37 @@ export class Monitor extends React.Component {
                             defaultExpanded: true,
                         },
                         {
-                            name: "Logging",
+                            name: _("Logging"),
                             icon: <CatalogIcon />,
                             id: "log-monitor",
                             defaultExpanded: true,
                             children: [
                                 {
-                                    name: "Access Log",
+                                    name: _("Access Log"),
                                     icon: <FontAwesomeIcon size="sm" icon={faBook} />,
                                     id: "access-log-monitor",
                                     type: "log",
                                 },
                                 {
-                                    name: "Audit Log",
+                                    name: _("Audit Log"),
                                     icon: <FontAwesomeIcon size="sm" icon={faBook} />,
                                     id: "audit-log-monitor",
                                     type: "log",
                                 },
                                 {
-                                    name: "Audit Failure Log",
+                                    name: _("Audit Failure Log"),
                                     icon: <FontAwesomeIcon size="sm" icon={faBook} />,
                                     id: "auditfail-log-monitor",
                                     type: "log",
                                 },
                                 {
-                                    name: "Errors Log",
+                                    name: _("Errors Log"),
                                     icon: <FontAwesomeIcon size="sm" icon={faBook} />,
                                     id: "error-log-monitor",
                                     type: "log",
                                 },
                                 {
-                                    name: "Security Log",
+                                    name: _("Security Log"),
                                     icon: <FontAwesomeIcon size="sm" icon={faBook} />,
                                     id: "security-log-monitor",
                                     type: "log",
@@ -464,7 +466,7 @@ export class Monitor extends React.Component {
                     }
                     this.setState({
                         replicatedSuffixes: config.items,
-                        replSuffix: replSuffix,
+                        replSuffix,
                     });
                 }, this.loadDiskSpace());
     }
@@ -713,8 +715,8 @@ export class Monitor extends React.Component {
                             glues: config.items,
 
                         },
+                        replInitLoaded: true,
                         replLoading: false,
-                        replInitLoaded: true
                     });
                 })
                 .fail(() => {
@@ -756,16 +758,13 @@ export class Monitor extends React.Component {
                     this.setState({
                         credRows,
                         aliasRows,
-                        replLoading: false,
                         replInitLoaded: true
                     });
                 })
                 .fail(err => {
+                    // No dsrc file, thats ok
                     const errMsg = JSON.parse(err);
-                    this.props.addNotification(
-                        "error",
-                        `Failed to get .dsrc information: ${errMsg.desc}`
-                    );
+                    console.log(`loadDSRC: Could not load .dsrc file: ${errMsg.desc}`);
                     this.setState({
                         replLoading: false,
                     });
@@ -862,6 +861,7 @@ export class Monitor extends React.Component {
                     .spawn(cmd, { superuser: true, err: "message" })
                     .done(content => {
                         const config = JSON.parse(content);
+                        this.loadDSRC();
                         this.setState({
                             [treeViewItem.suffix]: {
                                 ...this.state[treeViewItem.suffix],
@@ -883,7 +883,7 @@ export class Monitor extends React.Component {
                         // Notification of failure (could only be server down)
                         this.setState({
                             replLoading: false,
-                        });
+                        }, this.loadDSRC);
                     });
         } else {
             // We should enable it here because ReplMonitor never will be mounted
@@ -943,91 +943,101 @@ export class Monitor extends React.Component {
         if (this.state.loaded) {
             if (this.state.node_name === "database-monitor" || this.state.node_name === "") {
                 if (this.state.ldbmLoading) {
-                    monitor_element =
+                    monitor_element = (
                         <div className="ds-margin-top-xlg ds-center">
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    Loading Database Monitor Information ...
+                                    {_("Loading Database Monitor Information ...")}
                                 </Text>
                             </TextContent>
                             <Spinner className="ds-margin-top-lg" size="xl" />
-                        </div>;
+                        </div>
+                    );
                 } else {
-                    monitor_element =
+                    monitor_element = (
                         <DatabaseMonitor
                             data={this.state.ldbmData}
                             enableTree={this.enableTree}
                             serverId={this.props.serverId}
-                        />;
+                        />
+                    );
                 }
             } else if (this.state.node_name === "server-monitor") {
                 if (this.state.serverLoading) {
-                    monitor_element =
+                    monitor_element = (
                         <div className="ds-margin-top-xlg ds-center">
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    Loading Server Monitor Information ...
+                                    {_("Loading Server Monitor Information ...")}
                                 </Text>
                             </TextContent>
                             <Spinner className="ds-margin-top-lg" size="xl" />
-                        </div>;
+                        </div>
+                    );
                 } else {
-                    monitor_element =
+                    monitor_element = (
                         <ServerMonitor
                             data={this.state.serverData}
-                            reload={this.reloadServer}
+                            handleReload={this.reloadServer}
                             serverId={this.props.serverId}
                             disks={this.state.disks}
-                            reloadDisks={this.reloadDisks}
+                            handleReloadDisks={this.reloadDisks}
                             snmpData={this.state.snmpData}
                             snmpReload={this.reloadSNMP}
                             enableTree={this.enableTree}
-                        />;
+                        />
+                    );
                 }
             } else if (this.state.node_name === "access-log-monitor") {
-                monitor_element =
+                monitor_element = (
                     <AccessLogMonitor
                         logLocation={this.state.accesslogLocation}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === "audit-log-monitor") {
-                monitor_element =
+                monitor_element = (
                     <AuditLogMonitor
                         logLocation={this.state.auditlogLocation}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === "auditfail-log-monitor") {
-                monitor_element =
+                monitor_element = (
                     <AuditFailLogMonitor
                         logLocation={this.state.auditfaillogLocation}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === "error-log-monitor") {
-                monitor_element =
+                monitor_element = (
                     <ErrorLogMonitor
                         logLocation={this.state.errorlogLocation}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_name === "security-log-monitor") {
-                monitor_element =
+                monitor_element = (
                     <SecurityLogMonitor
                         logLocation={this.state.securitylogLocation}
                         enableTree={this.enableTree}
-                    />;
+                    />
+                );
             } else if (this.state.node_type === "repl-mon") {
                 if (this.state.replLoading) {
-                    monitor_element =
+                    monitor_element = (
                         <div className="ds-margin-top-xlg ds-center">
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    Loading Replication Monitor Information ...
+                                    {_("Loading Replication Monitor Information ...")}
                                 </Text>
                             </TextContent>
                             <Spinner className="ds-margin-top-lg" size="xl" />
-                        </div>;
+                        </div>
+                    );
                 } else {
                     if (this.state.node_name === "sync-report") {
-                        monitor_element =
+                        monitor_element = (
                             <div>
                                 <ReplMonitor
                                     serverId={this.props.serverId}
@@ -1036,12 +1046,13 @@ export class Monitor extends React.Component {
                                     aliasRows={this.state.aliasRows}
                                     addNotification={this.props.addNotification}
                                     enableTree={this.enableTree}
-                                    reload={this.onHandleLoadMonitorReplication}
+                                    handleReload={this.onHandleLoadMonitorReplication}
                                     key={this.state.node_name}
                                 />
-                            </div>;
+                            </div>
+                        );
                     } else if (this.state.node_item === "agmt-mon") {
-                        monitor_element =
+                        monitor_element = (
                             <div>
                                 <ReplAgmtMonitor
                                     suffix={this.state.replSuffix}
@@ -1050,12 +1061,13 @@ export class Monitor extends React.Component {
                                     addNotification={this.props.addNotification}
                                     reloadAgmts={this.reloadReplAgmts}
                                     enableTree={this.enableTree}
-                                    reload={this.onHandleLoadMonitorReplication}
+                                    handelReload={this.onHandleLoadMonitorReplication}
                                     key={this.state.node_name}
                                 />
-                            </div>;
+                            </div>
+                        );
                     } else if (this.state.node_item === "winsync-mon") {
-                        monitor_element =
+                        monitor_element = (
                             <div>
                                 <ReplAgmtWinsync
                                     suffix={this.state.replSuffix}
@@ -1064,12 +1076,13 @@ export class Monitor extends React.Component {
                                     addNotification={this.props.addNotification}
                                     reloadAgmts={this.reloadReplWinsyncAgmts}
                                     enableTree={this.enableTree}
-                                    reload={this.onHandleLoadMonitorReplication}
+                                    handleReload={this.onHandleLoadMonitorReplication}
                                     key={this.state.node_name}
                                 />
-                            </div>;
+                            </div>
+                        );
                     } else if (this.state.node_item === "task-mon") {
-                        monitor_element =
+                        monitor_element = (
                             <div>
                                 <ReplMonTasks
                                     suffix={this.state.replSuffix}
@@ -1077,12 +1090,13 @@ export class Monitor extends React.Component {
                                     data={this.state[this.state.replSuffix]}
                                     addNotification={this.props.addNotification}
                                     enableTree={this.enableTree}
-                                    reload={this.onHandleLoadMonitorReplication}
+                                    handleReload={this.onHandleLoadMonitorReplication}
                                     key={this.state.node_name}
                                 />
-                            </div>;
+                            </div>
+                        );
                     } else if (this.state.node_item === "conflict-mon") {
-                        monitor_element =
+                        monitor_element = (
                             <div>
                                 <ReplMonConflict
                                     suffix={this.state.replSuffix}
@@ -1091,27 +1105,29 @@ export class Monitor extends React.Component {
                                     addNotification={this.props.addNotification}
                                     reloadConflicts={this.loadConflicts}
                                     enableTree={this.enableTree}
-                                    reload={this.onHandleLoadMonitorReplication}
+                                    handleReload={this.onHandleLoadMonitorReplication}
                                     key={this.state.node_name}
                                 />
-                            </div>;
+                            </div>
+                        );
                     }
                 }
             } else if (this.state.node_name !== "") {
                 // suffixes (example)
                 if (this.state.chainingLoading) {
-                    monitor_element =
+                    monitor_element = (
                         <div className="ds-margin-top-xlg ds-center">
                             <TextContent>
                                 <Text component={TextVariants.h3}>
-                                    Loading Chaining Monitor Information For <b>{this.state.node_text} ...</b>
+                                    cockpit.format(_("Loading Chaining Monitor Information For <b>$0 ...</b>"), this.state.node_text)
                                 </Text>
                             </TextContent>
                             <Spinner className="ds-margin-top-lg" size="xl" />
-                        </div>;
+                        </div>
+                    );
                 } else {
                     if (this.state.node_type === "dblink") {
-                        monitor_element =
+                        monitor_element = (
                             <ChainingMonitor
                                 suffix={this.state.node_text}
                                 bename={this.state.bename}
@@ -1119,10 +1135,11 @@ export class Monitor extends React.Component {
                                 data={this.state[this.state.node_text].chainingData}
                                 enableTree={this.enableTree}
                                 key={this.state.node_text}
-                            />;
+                            />
+                        );
                     } else {
                         // Suffix
-                        monitor_element =
+                        monitor_element = (
                             <SuffixMonitor
                                 serverId={this.props.serverId}
                                 suffix={this.state.node_text}
@@ -1130,11 +1147,12 @@ export class Monitor extends React.Component {
                                 enableTree={this.enableTree}
                                 key={this.state.node_text}
                                 addNotification={this.props.addNotification}
-                            />;
+                            />
+                        );
                     }
                 }
             }
-            monitorPage =
+            monitorPage = (
                 <div className="container-fluid">
                     <div className="ds-container">
                         <div>
@@ -1153,17 +1171,19 @@ export class Monitor extends React.Component {
                             {monitor_element}
                         </div>
                     </div>
-                </div>;
+                </div>
+            );
         } else {
-            monitorPage =
+            monitorPage = (
                 <div className="ds-margin-top-xlg ds-center">
                     <TextContent>
                         <Text component={TextVariants.h3}>
-                            Loading Monitor Information ...
+                            {_("Loading Monitor Information ...")}
                         </Text>
                     </TextContent>
                     <Spinner className="ds-margin-top-lg" size="xl" />
-                </div>;
+                </div>
+            );
         }
 
         return (
