@@ -27,6 +27,7 @@ SER_LDAPI_ENABLED = 'ldapi_enabled'
 SER_LDAPI_SOCKET = 'ldapi_socket'
 SER_LDAPI_AUTOBIND = 'ldapi_autobind'
 SER_INST_SCRIPTS_ENABLED = 'InstScriptsEnabled'
+SER_DB_LIB = 'db_lib'
 
 SER_PROPNAME_TO_ATTRNAME = {SER_HOST: 'nsslapd-localhost',
                             SER_PORT: 'nsslapd-port',
@@ -38,6 +39,7 @@ SER_PROPNAME_TO_ATTRNAME = {SER_HOST: 'nsslapd-localhost',
                             SER_LDAPI_ENABLED: 'nsslapd-ldapilisten',
                             SER_LDAPI_SOCKET: 'nsslapd-ldapifilepath',
                             SER_LDAPI_AUTOBIND: 'nsslapd-ldapiautobind',
+                            SER_DB_LIB: 'nsslapd-backend-implement',
                             }
 #
 # Those WITHOUT related attribute name
