@@ -128,10 +128,10 @@ class Schema(DSLdapObject):
             for obj in results:
                 obj_i = vars(object_model(obj))
                 if len(obj_i["names"]) == 1:
-                    obj_i['name'] = obj_i['names'][0].lower()
+                    obj_i['name'] = obj_i['names'][0]
                     obj_i['aliases'] = None
                 elif len(obj_i["names"]) > 1:
-                    obj_i['name'] = obj_i['names'][0].lower()
+                    obj_i['name'] = obj_i['names'][0]
                     obj_i['aliases'] = obj_i['names'][1:]
                 else:
                     obj_i['name'] = ""
@@ -275,7 +275,11 @@ class Schema(DSLdapObject):
             raise ValueError('Schema is already in the required state. Nothing to change')
 
         self.remove(attr_name, schema_object_str_old)
-        return self.add(attr_name, schema_object_str)
+        try:
+            return self.add(attr_name, schema_object_str)
+        except ldap.LDAPError:
+            self.add(attr_name, schema_object_str_old)
+            raise
 
     def reload(self, schema_dir=None):
         """Reload the schema"""
@@ -295,7 +299,7 @@ class Schema(DSLdapObject):
 
         file_list = []
         file_list += glob.glob(os.path.join(self.conn.schemadir, "*.ldif"))
-        if ds_is_newer('1.3.6.0'):
+        if ds_is_newer('1.3.6.0', instance=self._instance):
             file_list += glob.glob(os.path.join(self.conn.ds_paths.system_schema_dir, "*.ldif"))
         return file_list
 
@@ -567,7 +571,7 @@ class SchemaLegacy(object):
         """return a list of the schema files in the instance schemadir"""
         file_list = []
         file_list += glob.glob(self.conn.schemadir + "/*.ldif")
-        if ds_is_newer('1.3.6.0'):
+        if ds_is_newer('1.3.6.0', instance=self.conn):
             file_list += glob.glob(self.conn.ds_paths.system_schema_dir + "/*.ldif")
         return file_list
 
@@ -641,7 +645,7 @@ class SchemaLegacy(object):
                 results.getValues('objectClasses')]
             for oc in objectclasses:
                 # Add normalized name for sorting
-                oc['name'] = oc['names'][0].lower()
+                oc['name'] = oc['names'][0]
             objectclasses = sorted(objectclasses, key=itemgetter('name'))
             result = {'type': 'list', 'items': objectclasses}
             return dump_json(result)
@@ -663,7 +667,7 @@ class SchemaLegacy(object):
                 results.getValues('attributeTypes')]
             for attr in attributetypes:
                 # Add normalized name for sorting
-                attr['name'] = attr['names'][0].lower()
+                attr['name'] = attr['names'][0]
             attributetypes = sorted(attributetypes, key=itemgetter('name'))
             result = {'type': 'list', 'items': attributetypes}
             return dump_json(result)
@@ -683,7 +687,7 @@ class SchemaLegacy(object):
             for mr in matchingRules:
                 # Add normalized name for sorting
                 if mr['names']:
-                    mr['name'] = mr['names'][0].lower()
+                    mr['name'] = mr['names'][0]
                 else:
                     mr['name'] = ""
             matchingRules = sorted(matchingRules, key=itemgetter('name'))
@@ -768,7 +772,6 @@ class SchemaLegacy(object):
         # filter our set of all attribute types.
         objectclasses = self.get_objectclasses()
         attributetypes = self.get_attributetypes()
-        attributetypename = attributetypename.lower()
 
         attributetype = [at for at in attributetypes
                          if attributetypename.lower() in
@@ -795,9 +798,9 @@ class SchemaLegacy(object):
             must = [vars(oc) for oc in must]
             # Add normalized 'name' for sorting
             for oc in may:
-                oc['name'] = oc['names'][0].lower()
+                oc['name'] = oc['names'][0]
             for oc in must:
-                oc['name'] = oc['names'][0].lower()
+                oc['name'] = oc['names'][0]
             may = sorted(may, key=itemgetter('name'))
             must = sorted(must, key=itemgetter('name'))
             result = {'type': 'schema',
