@@ -41,23 +41,21 @@ import shlex
 import operator
 import subprocess
 import math
-# Setuptools ships with 'packaging' module, let's use it from there
-try:
-    from pkg_resources.extern.packaging.version import LegacyVersion
-# Fallback to a normal 'packaging' module in case 'setuptools' is stripped
-except:
-    from packaging.version import LegacyVersion
+import errno
 from socket import getfqdn
 from ldapurl import LDAPUrl
 from contextlib import closing
-
+from cryptography import x509
+from cryptography.hazmat.backends import default_backend
 import lib389
 from pathlib import Path
+from subprocess import check_output
 from lib389.paths import ( Paths, DEFAULTS_PATH )
 from lib389.dseldif import DSEldif
 from lib389._constants import (
         DEFAULT_USER, VALGRIND_WRAPPER, DN_CONFIG, CFGSUFFIX, LOCALHOST,
-        ReplicaRole, CONSUMER_REPLICAID, SENSITIVE_ATTRS, DEFAULT_DB_LIB
+        ReplicaRole, CONSUMER_REPLICAID, SENSITIVE_ATTRS, DEFAULT_DB_LIB,
+        DEFAULT_LMDB_SIZE
     )
 from lib389.properties import (
         SER_HOST, SER_USER_ID, SER_GROUP_ID, SER_STRICT_HOSTNAME_CHECKING, SER_PORT,
@@ -183,6 +181,12 @@ _chars = {
     "~": u"\u02de",
 }
 
+#
+# Size parser constants
+#
+SIZE_UNITS = { 't': 2**40, 'g': 2**30, 'm': 2**20, 'k': 2**10, '': 1, }
+SIZE_PATTERN = r'\s*(\d*\.?\d*)\s*([tgmk]?)b?\s*'
+
 #
 # Utilities
 #
@@ -274,7 +278,7 @@ def _get_selinux_fcontext_info():
 
 
 def resolve_selinux_path(path):
-    '''Return the path as expected by semanage fcontext'''
+    """Return the path as expected by semanage fcontext"""
     path = str(Path(path).resolve())
     if selinux_present():
         _get_selinux_fcontext_info()
@@ -313,20 +317,34 @@ def selinux_label_file(path, label):
             return
         raise ValueError(f'Cannot change file context for {path} because it is defined in SELinux policy. Please choose another path.')
     if label:
-        try:
-            log.debug(f"Setting label {label} in SELinux file context {path}.")
-            result = subprocess.run(["semanage", "fcontext", "-a", "-t", label, path],
-                                     stdout=subprocess.PIPE,
-                                     stderr=subprocess.PIPE)
-            args = ' '.join(ensure_list_str(result.args))
-            stdout = ensure_str(result.stdout)
-            stderr = ensure_str(result.stderr)
-            if result.returncode != 0:
-                log.error(f"ERROR CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}")
+        rc = 0
+        for i in range(5):
+            try:
+                log.debug(f"Setting label {label} in SELinux file context {path}.  Attempt {i}")
+                result = subprocess.run(["semanage", "fcontext", "-a", "-t", label, path],
+                                         stdout=subprocess.PIPE,
+                                         stderr=subprocess.PIPE)
+                args = ' '.join(ensure_list_str(result.args))
+                stdout = ensure_str(result.stdout)
+                stderr = ensure_str(result.stderr)
+                rc = result.returncode
+                if rc == 0:
+                    local[path] = label
+                    break
+                else:
+                    log.debug(f"Failure setting label {label} for context {path}: Result code {rc}, retrying...")
+                    time.sleep(2)
+            except (OSError, subprocess.CalledProcessError) as e:
+                log.debug(f"Failure setting label {label} for context {path}: Exception {str(e)}, retrying...")
+                time.sleep(2)
+
+        if rc != 0:
+            log.error(f"ERROR CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}")
+            try:
                 result.check_returncode()
-            local[path] = label
-        except (OSError, subprocess.CalledProcessError) as e:
-            raise ValueError(f"Failed to set SElinux label {label} on {path}: {str(e)}")
+            except (OSError, subprocess.CalledProcessError) as e:
+                raise ValueError(f"Failed to set SElinux label {label} on {path}: {str(e)}")
+
     if os.path.exists(path):
         # pytest fails if I use selinux_restorecon(path)
         subprocess.run(["restorecon", "-R", path])
@@ -500,7 +518,10 @@ def is_dn_parent(parent_dn, child_dn, ):
 def normalizeDN(dn, usespace=False):
     # not great, but will do until we use a newer version of python-ldap
     # that has DN utilities
-    ary = ldap.explode_dn(dn.lower())
+    try:
+        ary = ldap.explode_dn(dn.lower())
+    except ldap.DECODING_ERROR:
+        raise ValueError(f"Unable to normalize DN '{dn}'")
     joinstr = ","
     if usespace:
         joinstr = ", "
@@ -508,10 +529,11 @@ def normalizeDN(dn, usespace=False):
 
 
 def escapeDNValue(dn):
-    '''convert special characters in a DN into LDAPv3 escapes.
+    """convert special characters in a DN into LDAPv3 escapes.
 
      e.g.
-    "dc=example,dc=com" -> \"dc\=example\,\ dc\=com\"'''
+    "dc=example,dc=com" -> \\"dc\\=example\\,\\ dc\\=com\\"
+    """
     for cc in (' ', '"', '+', ',', ';', '<', '>', '='):
         dn = dn.replace(cc, '\\' + cc)
     return dn
@@ -750,7 +772,7 @@ def valgrind_get_results_file(dirsrv_inst):
     We need to extract the "--log-file" value
     """
     cmd = ("ps -ef | grep valgrind | grep 'slapd-" + dirsrv_inst.serverid +
-           " ' | awk '{ print $14 }' | sed -e 's/\-\-log\-file=//'")
+           " ' | awk '{ print $14 }' | sed -e 's/\\-\\-log\\-file=//'")
 
     # Run the command and grab the output
     p = os.popen(cmd)
@@ -1214,6 +1236,76 @@ def generate_ds_params(inst_num, role=ReplicaRole.STANDALONE):
 
     return instance_data
 
+class DSVersion():
+    def __init__(self, version):
+        self._version = str(version)
+        self._key = _cmpkey(self._version)
+
+    def __str__(self):
+        return self._version
+
+    def __repr__(self):
+        return f"<DSVersion('{self}')>"
+
+    def __hash__(self):
+        return hash(self._key)
+
+    def __lt__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key < other._key
+
+    def __le__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key <= other._key
+
+    def __eq__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key == other._key
+
+    def __ge__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key >= other._key
+
+    def __gt__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key > other._key
+
+    def __ne__(self, other):
+        if not isinstance(other, DSVersion):
+            return NotImplemented
+
+        return self._key != other._key
+
+
+def _parse_version_parts(s):
+    for part in re.compile(r"(\d+ | [a-z]+ | \. | -)", re.VERBOSE).split(s):
+
+        if not part or part == ".":
+            continue
+
+        if part[:1] in "0123456789":
+            # pad for numeric comparison
+            yield part.zfill(8)
+        else:
+            yield "*" + part
+
+def _cmpkey(version):
+    parts = []
+    for part in _parse_version_parts(version.lower()):
+        parts.append(part)
+
+    return tuple(parts)
+
 
 def get_ds_version(paths=None):
     """
@@ -1241,9 +1333,9 @@ def ds_is_related(relation, *ver, instance=None):
     if len(ver) > 1:
         for cmp_ver in ver:
             if cmp_ver.startswith(ds_ver[:3]):
-                return ops[relation](LegacyVersion(ds_ver),LegacyVersion(cmp_ver))
+                return ops[relation](DSVersion(ds_ver), DSVersion(cmp_ver))
     else:
-        return ops[relation](LegacyVersion(ds_ver), LegacyVersion(ver[0]))
+        return ops[relation](DSVersion(ds_ver), DSVersion(ver[0]))
 
 
 def ds_is_older(*ver, instance=None):
@@ -1329,6 +1421,32 @@ def socket_check_open(host, port):
                 return False
 
 
+def socket_check_bind(port):
+    """
+    Check if a socket can be bound.  Need to handle cases where IPv6 is
+    completely disabled.
+    """
+    # Trying IPv6 first ...
+    host = "::1"
+    family = socket.AF_INET6
+    try:
+        with closing(socket.socket(family, socket.SOCK_STREAM)) as sock:
+            sock.bind((host, port))
+            return True
+    except OSError as e:
+        if e.errno == errno.EACCES or  e.errno == errno.EADDRINUSE:
+            return False
+    # Maybe there is no IPv6, adjust hostname, and try IPv4 ...
+    host = "127.0.0.1"
+    family = socket.AF_INET
+    try:
+        with closing(socket.socket(family, socket.SOCK_STREAM)) as sock:
+            sock.bind((host, port))
+            return True
+    except OSError as e:
+        return False
+
+
 def ensure_bytes(val):
     if val is not None and type(val) != bytes:
         return val.encode()
@@ -1586,14 +1704,79 @@ def is_valid_hostname(hostname):
         return False
     if hostname[-1] == ".":
         hostname = hostname[:-1] # strip exactly one dot from the right, if present
-    allowed = re.compile("(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
+    allowed = re.compile(r"(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
     return all(allowed.match(x) for x in hostname.split("."))
 
 
+def parse_size(size):
+    """
+    Parse a string representing a size (like "5 kb" or "2.5Gb") and
+    return the size in bytes.
+    :param size: The size to parse
+    :type size: str:
+    :return int:
+    :raise ValueError: if the string cannot be parsed.
+    """
+    try:
+        val,unit = re.fullmatch(SIZE_PATTERN, size, flags=re.IGNORECASE).groups()
+        return round(float(val) * SIZE_UNITS[unit.lower()])
+    except AttributeError:
+        raise ValueError(f'Unable to parse "{size}" as a size.')
+
+
+def format_size(size):
+    """
+    Return a string representing a size (like "5 kb" or "2.5Gb")
+    :param size: The size int bytes to format
+    :type size: int:
+    :return str:
+    """
+    for unit in ["B", "KB", "MB", "GB",]:
+        if (size < 1024):
+            return f"{size:3.1f} {unit}"
+        size /= 1024
+    return f"{size:.1f} TB"
+
+
 def get_default_db_lib():
+    """
+    Get the default value for the database implementation
+    :return str:  Should be either 'bdb' or 'mdb'
+    """
     return os.getenv('NSSLAPD_DB_LIB', default=DEFAULT_DB_LIB)
 
 
+def get_default_mdb_max_size(paths):
+    """
+    Get the default maximum size for the lmdb database.
+    :return str:  A size that can be parsed with parse_size()
+    """
+    if paths is None:
+        paths = Paths()
+    mdb_max_size = DEFAULT_LMDB_SIZE
+    size = parse_size(mdb_max_size)
+    # Make sure that there is enough available disk space
+    # otherwise decrease the value
+    dbdir = paths.db_dir
+    # dbdir may not exists because:
+    #  - paths instance name has not been expanded 
+    #  - dscreate has not yet created it.
+    # so let use the first existing parent in that case.
+    while not os.path.exists(dbdir):
+        dbdir = os.path.dirname(dbdir)
+    try:
+        statvfs = os.statvfs(dbdir)
+        avail = statvfs.f_frsize * statvfs.f_bavail
+        avail *= 0.8 # Reserve 20% as margin
+        if size > avail:
+            mdb_max_size = str(avail)
+    except (TimeoutError, InterruptedError) as e:
+        raise e
+    except OSError as e:
+        log.warning(f'Cannot determine the free space in the file system containing {dbdir} because of {e}')
+    return mdb_max_size
+
+
 def is_fips():
     if os.path.exists('/proc/sys/crypto/fips_enabled'):
         with open('/proc/sys/crypto/fips_enabled', 'r') as f:
@@ -1740,3 +1923,64 @@ def get_task_status(inst, log, taskObj, dn=None, show_log=False, watch=False, us
         elif not use_json:
             log.info("Refreshing status ...")
         time.sleep(2)
+
+
+def is_cert_der(file_name):
+    try:
+        with open(file_name, 'tr') as check_file:
+            check_file.read()
+            # PEM cert
+            return False
+    except UnicodeDecodeError:
+        # DER cert
+        return True
+
+
+def check_cert_info(cert_file_name, search_text):
+    # Use openssl to get cert details
+    cmd = [
+        'openssl',
+        'x509',
+        '-in', cert_file_name,
+        '-text',
+        '-noout',
+    ]
+    log.debug("get_cert_details cmd: %s", format_cmd_list(cmd))
+    try:
+        result = check_output(cmd, stderr=subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        raise ValueError(e.output.decode('utf-8').rstrip())
+
+    cert_text = ensure_str(result)
+    return search_text.lower() in cert_text.lower()
+
+
+def cert_is_ca(cert_file_name):
+    with open(cert_file_name, "rb") as f:
+        if is_cert_der(cert_file_name):
+            cert = x509.load_der_x509_certificate(f.read(), default_backend())
+        else:
+            cert = x509.load_pem_x509_certificate(f.read(), default_backend())
+
+    try:
+        key_usage = cert.extensions.get_extension_for_oid(x509.oid.ExtensionOID.KEY_USAGE)
+        if not key_usage.value.key_cert_sign:
+            return False
+        basic_constraints = cert.extensions.get_extension_for_oid(
+            x509.oid.ExtensionOID.BASIC_CONSTRAINTS
+        )
+        if not basic_constraints.value.ca:
+            return False
+        else:
+            return True
+    except x509.ExtensionNotFound:
+        # No extensions, check the cert info directly
+        return check_cert_info(cert_file_name, "CA:TRUE")
+
+
+def get_passwd_from_file(passwd_file):
+    if os.path.exists(passwd_file):
+        with open(passwd_file, 'r') as f:
+            passwd = f.readline().strip()
+            return passwd
+    raise ValueError(f"The password file '{passwd_file}' does not exist, or can not be read.")
